#N Stamp collection
#C A collection of 650 oscillators of 83 different periods from 1
#C to 40894. 
#C
#C The oscillators included here were found/built by many people over
#C many years.  I finished putting the collection together in August 1995,
#C and have worked on this header file off and on since then.  It's still
#C incomplete and probably inaccurate, but I've decided to make it public
#C anyway; if you find any errors or can fill in any of the blanks, please
#C let me know. 
#C
#C Since this collection was built, many new oscillators have been found.
#C Most notably, in 1996 David Buckingham showed how to create tracks
#C built from still-lifes through which Herschels can move.  (See
#C  http://www.radicaleye.com/lifepage/patterns/bhept/bhept.html
#C for Buckingham's description of this, and
#C  http://www.radicaleye.com/lifepage/patterns/p1/p1.html
#C for Paul Callahan's discussion of using such conduits to build a stable
#C glider reflector.)  Using Herschel tracks, Buckingham obtained glider
#C guns of all periods >= 62 and oscillators of all periods >= 61.  Further
#C work on Herschel tracks has been done by Buckingham, Paul Callahan,
#C Dieter Leithner, and me; such tracks now give oscillators of all periods
#C >=54, and guns of periods 54, 55, and 56.
#C
#C In addition, oscillators of several new smaller periods have been found,
#C namely 17 (by me), 22 (by Noam Elkies, me, and Jason Summers), 27 (by
#C Elkies), 33 (by Elkies and Jason Summers), 37 (by Nicolay Beluchenko),
#C 39 (by Elkies), 49 (by Elkies), and 51 (by Beluchenko).  (See
#C  http://www.radicaleye.com/DRH/nbt.html
#C for many oscillators of small periods, including the only known p17s
#C and the smallest known p22s.)  There are 8 periods for which oscillators
#C are still unknown as of early 2009: 19, 23, 31, 34, 38, 41, 43, and 53.
#C (For period 34, we could use a noninteracting combination of p2 and p17
#C oscillators, but that's considered trivial.)
#C
#C Some new guns of smaller periods have also been found, namely 22 (by
#C David Eppstein, based on Jason Summers's p22 oscillator), 24 and 48 (by
#C Elkies) and 50 (by me, based on a p44 gun by Buckingham and a p50
#C oscillator by Elkies).  These are shown (among others) at
#C  http://home.mieweb.com/jason/life/guns/ .
#C Also see http://www.radicaleye.com/lifepage/patterns/p24gun/p24gun.html
#C for discussion of the p24 gun, and
#C  <a href="gun.44.50.html">http://www.radicaleye.com/DRH/gun44.50.html</a>
#C for the p50 gun and Buckingham's p44 gun.
#C
#C Building this collection would have been impossible without the help
#C of many people.  In addition to those who found the oscillators, I'd
#C like to thank Alan Hensel, Bill Gosper, Robert Wainwright,
#C Rich Schroeppel, and Jonathan Cooley for helpful suggestions, and
#C Andrew Trevorrow for writing LifeLab, an excellent Macintosh program
#C for building and running Life patterns.  LifeLab's cross-platform
#C successor, Golly, is available as freeware at http://golly.sf.net .
#C
#CO Dean Hickerson, dean.hickerson@yahoo.com
#C 2/2/2000; last updated 9/16/2000. URLs corrected
#C  and list of missing periods updated on 5/8/2009.
#C
#C ----------------------------------------------------------------------
#C
#C Most lines of this header describe particular oscillators.  Each entry
#C begins with an identifying label, of the form "period.row.column";
#C row and column numbers start at zero.  This is followed by the name of
#C the oscillator (if any) in quotation marks, the discoverer and date of
#C discovery (if known) in brackets, and perhaps a comment about the
#C oscillator.  For example:
#C
#C     2.0.0   "blinker"  [JHC 3/70]  Example of "+c*c" symmetry.  This
#C             often occurs in a group of 4, known as a "traffic light",
#C             which arises, for example, from a T-tetromino. 
#C
#C This indicates that the leftmost oscillator in the top row of the period 2
#C section is called a "blinker", and was found by John Conway in March 1970.
#C The notation "+c*c" indicates the symmetry type of the oscillator, which
#C is described later.
#C
#C Many oscillators were found by the following people or groups, so their
#C names are abbreviated in this header:
#C 
#C    AF  = Achim Flammenkamp
#C    AWH = Alan Hensel
#C    DIB = David Bell
#C    DJB = David Buckingham
#C    DRH = Dean Hickerson
#C    HH  = Hartmut Holzwart
#C    JHC = John Conway
#C    MDN = Mark Niemiec
#C    NDE = Noam Elkies
#C    PC  = Paul Callahan
#C    RCS = Rich Schroeppel
#C    RTW = Robert Wainwright
#C    RWG = Bill Gosper
#C    SN  = Simon Norton
#C    JHC group  = A group of people working with John Conway in the
#C                 early 1970s, including Conway, S. R. Bourne,
#C                 M. J. T. Guy, and Simon Norton.
#C    MIT group  = A group of people at MIT during the early 1970s,
#C                 including Robert April, Michael Beeler, Bill Gosper,
#C                 Richard Howell, Rici Liknaitzky, Bill Mann,
#C                 Rich Schroeppel, and Michael Speciner.
#C 
#C Also, many of the common oscillators were found independently by many
#C people; this is indicated by an asterisk in the name field.
#C
#C Here are definitions of some terminology and notation used below; for
#C a more extensive glossary, see Stephen Silver's Life Lexicon, at
#C  http://www.argentum.freeserve.co.uk/lex_home.htm 
#C 
#C The 'rotor' constists of all cells in an oscillator which change state.
#C The 'stator' constists of all cells which are alive in all generations.
#C (These terms were introduced by Allan Wechsler in 1994.)
#C
#C An oscillator whose stator is large is often called a 'billiard table';
#C such oscillators are somewhat easier to find than others, so many are
#C included in this collection.
#C
#C The 'period' of an oscillator (or spaceship) is the smallest positive
#C integer P for which generation P of the object is congruent to and in
#C the same orientation as generation 0.  The 'mod' of an oscillator (or
#C spaceship) is the smallest positive integer M for which generation M
#C of the object is congruent to generation 0, but not necessarily in the
#C same orientation.  The quotient q=P/M is always either 1, 2, or 4.  To
#C specify both P and M, we often write "period P.M" or "period P/q".

#C There are 43 types of symmetry that an oscillator can have, taking into
#C account both the symmetry of a single generation and the change of
#C orientation (if any) M generations later.  There are 16 types of
#C symmetry that a pattern can have in a single generation.  Each of these
#C is given a one or two character name, as follows:

#C    n   no symmetry

#C    -c  mirror symmetry across a horizontal axis through cell centers
#C    -e  mirror symmetry across a horizontal axis through cell edges

#C    /   mirror symmetry across one diagonal

#C    .c  180 degree rotational symmetry about a cell center
#C    .e  180 degree rotational symmetry about a cell edge
#C    .k  180 degree rotational symmetry about a cell corner

#C    +c  mirror symmetry across horizontal and vertical axes meeting
#C        at a cell center
#C    +e  mirror symmetry across horizontal and vertical axes meeting
#C        at a cell edge
#C    +k  mirror symmetry across horizontal and vertical axes meeting
#C        at a cell corner

#C    xc  mirror symmetry across 2 diagonals meeting at a cell center
#C    xk  mirror symmetry across 2 diagonals meeting at a cell corner
#C 
#C    rc  90 degree rotational symmetry about a cell center
#C    rk  90 degree rotational symmetry about a cell corner
#C 
#C    *c  8-fold symmetry about a cell center
#C    *k  8-fold symmetry about a cell corner

#C For a period P/1 object, specifying the symmetry of generation 0 tells
#C us all there is to know about the oscillator's symmetry.  For a period
#C P/2 or P/4 object, we also need to know how gen M is related to gen 0.
#C For the P/2 case, gen M can be either a mirror image of gen 0, a 180
#C degree rotation of it, or a 90 degree rotation of it if the pattern
#C has 180 degree rotational symmetry.  For the P/4 case gen M must be a
#C 90 degree rotation of gen 0.  In any case, if we merge all gens which
#C are multiples of M, the resulting pattern will have more symmetry than
#C the original oscillator.  We describe the complete symmetry class of
#C the oscillator by appending the one or two character description of
#C the union's symmetry to that of gen 0's symmetry.  For example, if
#C gen 0 has 180 degree rotational symmetry about a cell center, and
#C gen M is obtained by reflecting gen 0 across a diagonal, then the
#C union of gens 0 and M is symmetric across both diagonals, so its
#C symmetry class is denoted ".cxc".

#C The 43 possible symmetry types are:

#C    period/mod = 1:  nn    -c-c  -e-e  //    .c.c  .e.e  .k.k  +c+c
#C                     +e+e  +k+k  xcxc  xkxk  rcrc  rkrk  *c*c  *k*k

#C    period/mod = 2:  n-c   n-e   n/    n.c   n.e   n.k
#C                     -c+c  -c+e  -e+e  -e+k
#C                     /xc   /xk
#C                     .c+c  .cxc  .crc  .e+e  .k+k  .kxk  .krk
#C                     +c*c  +k*k  xc*c  xk*k  rc*c  rk*k

#C    period/mod = 4:  nrc   nrk

#C The collection includes examples of all of these with mod=1, and many
#C with larger periods.

#C ----------------------------------------------------------------------
#C Period 1 oscillators are usually called "still-lifes".  Programs
#C written by MDN and others have counted the still-lifes with N cells
#C for small N; the results up to N=20 are shown here:

#C N    4 5 6 7 8  9 10 11  12  13  14   15   16   17    18    19     20
#C #    2 1 5 4 9 10 25 46 121 240 619 1353 3286 7773 19044 45759 112243

#C Those with up to 10 bits are included in the stamp collection.  So are
#C some larger ones that either occur naturally in random soups, or are
#C useful, or exemplify symmetry types.  I'm omitting the discoverers and
#C dates for most of the small and naturally occurring ones, since they've
#C been independently discovered many times. 

#C There are 2 4-bit still lifes:
#C 1.0.0   "block"  [JHC group 1970]  Example of "*k" symmetry.  Used
#C         as an eater in many oscillators, such as 4.1.0, 5.2.4, 6.0.0,
#C         8.0.0, 10.1.0, 11.0.1, 12.1.1-2, 18.0.0, 28.0.0, 29.0.1,
#C         30.0.0, 32.0.1, 44.0.0, 46.0.0, 56.0.0, 124.0.0, 135.0.0,
#C         150.0.0, 188.0.0, 246.0.0, 360.0.0, and 460.0.0.  Also used as
#C         a 'rephaser' in 135.0.0, 150.0.0, and 240.0.0.
#C 1.0.1   "tub"  [JHC group 1970]  Example of "*c" symmetry.  Used as an
#C         eater in 12.2.1, 24.0.0, most p29s, 30.2.0-3, and 47.0.0.

#C There's 1 5-bit still life:
#C 1.0.2   "boat"  [JHC group 1970]  Example of "/" symmetry.

#C There are 5 6-bit still lifes:
#C 1.0.3   "ship"  [JHC group 1970]  Example of "xc" symmetry.  Used as an
#C         eater of traffic lights in 24.1.0 and 24.2.0.
#C 1.0.4   "barge"  [JHC group 1970]  Example of "xk" symmetry.
#C 1.0.5   "snake"  [JHC group 1970]  Example of ".k" symmetry.  Used in
#C         60.4.1 and 15240.0.0 to convert a glider into a boat, which a
#C         subsequent glider deletes.
#C 1.0.6   "beehive"  [JHC group 1970]  Example of "+e" symmetry.  This
#C         often occurs in a group of 4, known as a "honey farm", which
#C         arises, for example, from a beehive with an extra cell in one
#C         of its corners.
#C 1.0.7   "aircraft carrier".  Example of ".e" symmetry.

#C There are 4 7-bit still lifes:
#C 1.0.8   "long boat"  [JHC group 1970]
#C 1.0.9   "long snake".  Example of ".c" symmetry.
#C 1.0.10  "loaf"  [JHC group 1970]
#C 1.0.11  "eater" or "eater1" (formerly "fishhook")  [* 1971]  Smallest
#C         asymmetric still-life.  This is a very useful still-life,
#C         because of its ability to eat gliders (e.g. 30.0.1), beehives
#C         (30.0.2), and lightweight and middleweight spaceships (46.2.0
#C         and 46.3.0), and to modify many other things.  The term
#C         "eater" also applies to other still-lifes (and occasionally
#C         oscillators) that share this ability; the most useful of these
#C         are the block (1.0.0), eater2 (1.7.3), and eater3 (1.7.4), but
#C         many others are sometimes useful, including the tub (1.0.1),
#C         ship (1.0.3), and snake (1.0.5).

#C There are 9 8-bit still lifes:
#C 1.1.0   "long ship"  [JHC group 1970]
#C 1.1.1   "long barge"  [JHC group 1970]
#C 1.1.2   "long long snake"
#C 1.1.3   "sinking ship"
#C 1.1.4   "pond"  [JHC group 1970]
#C 1.1.5   "shillelagh"  [Charles L. Corderman & Hugh Thompson 1971]
#C 1.1.6   "tub with tail"  [Charles L. Corderman & Hugh Thompson 1971]
#C 1.1.7   "hook with tail"
#C 1.1.8   "mango"

#C There are 10 9-bit still lifes.  Only 7 have names:
#C 1.2.0   "long long boat"
#C 1.2.1   "long^3 snake"
#C 1.2.2   "long sinking ship"
#C 1.2.3   "hat"  [* 1971]  Example of "-c" symmetry.
#C 1.2.4   "integral sign"
#C 1.2.5   "up-boat with tail"
#C 1.2.6   "down-boat with tail"
#C 1.2.7   "long shillelagh"
#C 1.2.8-9  unnamed

#C There are 25 10-bit still lifes.  Only 9 have names:
#C 1.3.0   "long long ship"
#C 1.3.1   "long long barge"
#C 1.3.2   "long^4 snake"
#C 1.3.3   "long long sinking ship"
#C 1.3.4   "snake siamese snake"
#C 1.3.5   "snake siamese aircraft carrier"
#C 1.3.6   "aircraft carrier siamese aircraft carrier"
#C 1.3.7   "long integral"
#C 1.3.8-13  unnamed
#C 1.4.0   "beehive with tail"
#C 1.4.1   "up-barge with tail"
#C 1.4.2   "down-barge with tail"
#C 1.4.3-6  unnamed
#C 1.4.7   "loop"
#C 1.4.8   "block and table"
#C 1.4.9   "loaf siamese barge"
#C 1.4.10  "bi-boat" or "boat-tie" or "bow tie"

#C Still lifes 1.5.0-10 and 1.6.0-4 are some larger ones that sometimes
#C occur in random soups.
#C 1.5.0   "bi-ship" or "half fleet"  (A "fleet" consists of 2 of these,
#C         and arises, for example, from a ship with an extra bit added
#C         at one end.)
#C 1.5.1   "bi-loaf" or "half bakery"
#C 1.5.2   "paper clip"
#C 1.5.3   "big S"  [MIT group 1971]
#C 1.5.4   "bi-pond"
#C 1.5.5   "boat-ship tie"
#C 1.5.6   "pair of tables"
#C 1.5.7   "moose antlers"
#C 1.5.8   "cis-mirrored R-bee"
#C 1.5.9   "block on big table"
#C 1.5.10  "twin peaks"
#C 1.6.0   "dead spark coil"
#C 1.6.1   "beehive on big table"
#C 1.6.2   "scorpion"  Occurs in gens 4760-5165 of "rabbits", this 9-bit
#C         methuselah found by Andrew Trevorrow:
#C            o...ooo
#C            ooo..o.
#C            .o.....
#C 1.6.3   "fourteener"
#C 1.6.4   "bookends"

#C Still lifes 1.6.5-8 and 1.7.0-2 provide examples of other symmetries.
#C 1.6.5   Example of "-e" symmetry
#C 1.6.6   "beehive with 2 tails"  Example of "-e" symmetry
#C 1.6.7   Example of "+c" symmetry
#C 1.6.8   "spiral"  [RTW 1971]  Example of "rc" symmetry
#C 1.7.0-1 Examples of "+k" symmetry
#C 1.7.2   Example of "rk" symmetry.  Heinrich Koenig pointed out that there
#C         are smaller examples; the smallest are:
#C            ..oo.o..   ...o.o..
#C            ..o.oo..   .oooo.o.
#C            oo....oo   o.....o.
#C            .o.oo..o   .o.oo.oo
#C            o..oo.o.   oo.oo.o.
#C            oo....oo   .o.....o
#C            ..oo.o..   .o.oooo.
#C            ..o.oo..   ..o.o...

#C Still lifes 1.7.3-6 are eaters that are used in various oscillators.
#C 1.7.3   "eater2"  [DJB ????]  See 6.3.2, 6.5.2, and 13.0.0.
#C 1.7.4   "eater3"  [DJB 6/22/77]  See 8.2.1, 18.0.0, 42.0.0, 50.0.1,
#C         55.0.0, 246.0.0.
#C 1.7.5   "eater4"  [DJB ????]  See 9.0.4, 11.0.2, 29.0.1-2, 29.3.0-1.
#C 1.7.6   unnamed eater  [DJB ????]  I don't know any oscillators that
#C         use this.  Here it's shown deleting a loaf:
#C            .........o....
#C            ...o....o.o...
#C            ..o.o...o.ooo.
#C            .o..o..oo....o
#C            ..oo..o...ooo.
#C            ......ooooo...
#C            ....oo........
#C            ...o.o..ooo...
#C            .ooo.o.o..o...
#C            o....o.o......
#C            .oo.oo.oo.....
#C            ..o.o.........
#C            ..o.o.........
#C            ...o..........
#C 
#C 1.7.7   [DJB 3/78?]  Unnamed eater, used in 6.3.3 and 32.0.0.

#C The 10 digits:  [DRH 5/8/92; "4" changed 3/94]

#C ----------------------------------------------------------------------

#C There are 20 known p2 oscillators with <= 14 cells (in gen 0).
#C There's 1 with 3 cells:
#C 2.0.0   "blinker"  [JHC 3/70]  Example of "+c*c" symmetry.  This
#C         often occurs in a group of 4, known as a "traffic light",
#C         which arises, for example, from a T-tetromino. 

#C There are 3 with 6 cells:
#C 2.0.1   "toad"  [SN 5/70]  Note use as an eater ("killer toads") in,
#C         for example, 4.9.1, 6.2.5, 46.4.0, and 60.5.0.  See discussion
#C         of toad hasslers at 60.0.0.
#C 2.0.2   "beacon"  [JHC 3/70]
#C 2.0.3   "clock"  [SN 5/70]  Example of ".kxk" symmetry.

#C For any N>=8, there's at least one p2 with N cells.  Generically these
#C are called barber poles (see 2.7.0).  For 8<=N<=11 these are the only
#C known p2s; the first 3 have names:
#C 2.0.4   "bipole".  Example of ".cxc" symmetry.
#C 2.0.5   "tripole".  Example of "/xk" symmetry.
#C 2.0.6   "quadpole".  Example of ".cxc" symmetry.

#C There are 4 with 12 cells (including the 6-pole, which isn't shown):
#C 2.0.7   
#C 2.0.8   "the fox" or "gnome"  [DJB 7/77]  Smallest asymmetric p2.
#C 2.0.9   "flip flops"  [MIT group 12/71]  Example of "rk*k" symmetry.

#C There are 2 with 13 cells, the 7-pole and:
#C 2.0.10  "by flops"  [RTW ????]  Example of "-c+e" symmetry.

#C There are 6 with 14 cells, the 8-pole and:
#C 2.1.0   
#C 2.1.1   
#C 2.1.2   "why not"  [DJB 7/77]
#C 2.1.3   "eater plug"  [RTW 2/73]
#C 2.1.4   "test tube baby"

#C Oscillators 2.0.2 (beacon), 2.1.3 (eater plug), and 2.1.4 (test tube
#C baby) are examples of on-off oscillators, in which generation 0 is a
#C subset of generation 1.  Other examples are shown in 2.1.5 to 2.1.9.
#C 2.1.5   "spark coil"  [* 1971]
#C 2.1.6   "4 boats"
#C 2.1.7   "light bulb"  [* 1971]
#C 2.1.8   variant of light bulb
#C 2.1.9   "scrubber"  [* 1971]

#C Oscillators 2.1.8 to 2.5.4 provide examples of the remaining p2/2
#C symmetry types.
#C 2.2.0   "quad"  [Robert A. Kraus 4/71]  Example of "rk*k" symmetry.
#C 2.2.1   "cloverleaf"  [RTW before 6/72]  Example of "xc*c" symmetry.
#C 2.2.2   "singular flip flop"  [RTW 7/72]  Example of "n-e" symmetry.
#C 2.2.3   "almosymmetric"  [* 1971]  Example of "n-e" symmetry.

#C 2.2.4   Example of "-c+e" symmetry.
#C 2.2.5   [DRH 5/20/93]  Example of "n-c" symmetry.
#C 2.2.6   [DRH 4/23/93]  Example of ".c+c" symmetry.
#C 2.3.0   [DRH 5/20/93]  Example of "n/" symmetry.
#C 2.3.1   "Laputa"  [RCS 9/23/92]  Example of "n.e" symmetry.
#C 2.3.2   "blinkers bit pole"  [RTW 6/77]  Example of "n.e" symmetry.
#C 2.3.3   [DRH 5/20/93]  Example of "n.k" symmetry.
#C 2.3.4   [DRH 5/20/93]  Example of "n.k" symmetry.
#C 2.3.5   [DRH 4/23/93]  Example of ".k+k" symmetry.
#C 2.3.6   Example of ".kxk" symmetry.
#C 2.4.0   "piston"  [* 1971]  Example of "-c+c" symmetry.
#C 2.4.1   Example of "-c+c" symmetry.
#C 2.4.2   [DRH 5/20/93]  Example of "n.c" symmetry.
#C 2.4.3   "complementary blinker"  [AF 7/12/94].  Example of ".c+c"
#C         symmetry.
#C 2.4.4   Example of ".cxc" symmetry.
#C 2.4.5   [DRH 4/23/93]  Example of "/xc" symmetry.
#C 2.4.6   [DRH 4/23/93]  Example of ".crc" symmetry.
#C 2.5.0   [DRH 4/23/93]  Example of "rc*c" symmetry.
#C 2.5.1   [AF 7/26/94]  Example of "rk*k" symmetry.  A muttering moat;
#C         see 2.12.2.
#C 2.5.2   [DRH 4/23/93]  Example of "xk*k" symmetry.
#C 2.5.3   [DRH 1973]  Example of "-e+e" symmetry.  Infinitely extensible.
#C 2.5.4   [DRH 4/23/93]  Example of "-e+e" symmetry.
#C 2.5.5   [DRH 4/23/93]  Example of "-e+e" symmetry.
#C 2.5.6   [DRH 4/23/93]  Example of "-e+k" symmetry.
#C 2.6.0   Example of ".e+e" symmetry.
#C 2.6.1   Example of "+k*k" symmetry.
#C 2.6.2   Example of "+k*k" symmetry.
#C 2.6.3   Example of ".krk" symmetry.
#C 2.6.4   Example of "xk*k" symmetry.

#C Oscillators 2.7.0 to 2.9.1 are examples of stabilized wicks, which may
#C be made arbitrarily long.
#C 2.7.0   "barber pole"  [MIT group 1970]
#C 2.7.1   [RTW <1990]
#C 2.7.2   [DRH 1994]
#C 2.7.3   [RTW <1990]
#C 2.7.4   [bottom end: RTW <1990; top end: DRH 1995]
#C 2.7.5   [RTW <1990]
#C 2.8.0   [DRH 1994]
#C 2.8.1   [AWH 8/25/94]  This was discovered as a stabilizer for 4.4.1.
#C 2.9.0   [DRH 1994]
#C 2.9.1   [DRH 1994]

#C Oscillators 2.10.0 to 2.12.1 are stabilized agars, which may be
#C made arbitrarily large.
#C 2.10.0  "venetian blinds"  [DRH 9/12/92]  This uses diagonal edges for
#C         the agar.  A vertical edge is also known, along with a corner
#C         joining it to the diagonal edge.  It's easy to prove that
#C         horizontal edges don't exist.
#C 2.10.1  [DRH 12/4/94, improved by MDN 12/6/94]
#C 2.11.0  "houndstooth agar"  [DRH 3/30/94]
#C 2.11.1  [agar found by Robert A. Kraus 1971, stabilized by DRH 12/13/94]
#C 2.11.2  
#C 2.12.0  [agar found by Robert A. Kraus 1971, stabilized by ????]
#C 2.12.1  "quilt" or "squaredance"  [agar found by Don Woods, 1971, stabilized
#C         by DRH 3/25/93]
#C 2.12.2  "ring of fire"  [DRH 9/24/92]  A "muttering moat"; i.e. an
#C         oscillator whose rotor consists of a closed loop of cells,
#C         each of which touches exactly 2 others.  Also see 2.5.1.
#C ----------------------------------------------------------------------
#C One other p3 is included as part of 12.4.0.

#C 3.0.0   "caterer"  [DRH 8/4/89]  Both this and jam (3.0.1) supply a
#C         spark which is used, e.g., in 3.4.0-3.4.3, 6.5.2, 12.0.2,
#C         12.0.3, 12.1.1, and 21.0.0.  Also see the multiple caterer
#C         used in 12.4.0.
#C 3.0.1   "jam"  [AF 1988]
#C 3.0.2   "2 eaters"  [RWG 9/71]
#C 3.0.3   "eaters plus"  [RTW 7/91]
#C 3.0.4   "biting off more than they can chew"  [Peter Raynham 7/72]
#C 3.0.5   "trice Tongs"  [RTW 2/82]
#C 3.0.6   "pulse"  [DJB#46 7/73]
#C 3.0.7   "pulsar 18-22-20"  [DJB#47 7/73]  Two copies of 3.0.6.
#C 3.0.8   [RTW 4/82]
#C 3.1.0   [DRH 8/89]  volatility = 17/18, which was the maximum known
#C         for a p3 until 3.8.1 was discovered.

#C Oscillators 3.1.1 to 3.1.3 all have rotors made of 3 cells in a
#C triangle, but with different cycles.
#C 3.1.1   "cuphook" or "MIT oscillator"  [RCS 10/70]
#C 3.1.2   "stillater"  [RTW 9/85]
#C 3.1.3   "1-2-3"  [DJB#4 8/72]

#C 3.1.4   [AF 8/22/94]  Rotor consists of 2 copies of that in 3.1.2.
#C 3.1.5   "germ"  [DJB#9 9/72]
#C 3.1.6   [DJB#7 <=1976]  Same rotor as in "2 eaters".
#C 3.2.0   "period three"  [RTW 6/72]  Can be reduced by 4 cells, by
#C         replacing the snakes by joined L tetrominos.
#C 3.2.1   "mini pressure cooker"  [RTW before 6/72]
#C 3.2.2   "pressure cooker"  [MIT group 9/71]
#C 3.2.3   "hustler"  [RTW 6/71]
#C 3.2.4   "loading dock"  [DJB#3 9/72]
#C 3.2.5   "snake dance"  [RTW 5/72]
#C 3.2.6   "tubber"  [RTW before 6/72]  Rotor is confined to 2 parallel
#C         diagonals.  Also see 4.2.4.
#C 3.3.0   "diamond ring"  [DJB#2 1972]
#C 3.3.1   "new five"  [DRH 1/90]
#C 3.3.2   [DJB#92 7/26/76]
#C 3.3.3   [DJB#103 6/3/77]  Rotor has symmetry type "-c", but stator
#C         can't be made symmetric.  (The left edge can be made 1 column
#C         narrower and 1 bit smaller by using a block below the snake.)
#C 3.3.4   [DRH 10/89]
#C 3.3.5   [DJB#79 6/6/76]  (DJB found the smallest form of this, with
#C         just 1 2x3 rectangle.  I don't know who found the wick.)

#C Oscillators 3.4.0-3 are examples of "catered" oscillators.  The
#C necessary sparks can be supplied by either a caterer (3.0.0) or a
#C jam (3.0.1).
#C 3.4.0   [DRH 8/89]
#C 3.4.1   [DRH 8/89]
#C 3.4.2   [RTW 8/89]
#C 3.4.3   "skewed traffic light"  [RTW 8/89]

#C 3.4.4   "double ewe"  [RTW before 9/71]
#C 3.5.0   "double caterer"  [DRH 10/89]
#C 3.5.1   "triple caterer"  [DRH 10/89]  Used in 6.6.0.
#C 3.5.2   [DRH 1/90]  Smallest known p3 in which a corner of the
#C         bounding box is active.
#C 3.5.3   [AF 7/30/94 (symmetric form)]
#C 3.5.4   "surprise"  [DJB#10 11/72]
#C 3.6.0   [DRH 9/10/89]
#C 3.6.1   "bent keys"  [DRH 8/89]
#C 3.6.2   "short keys"  [DRH 8/89]  This is the shortest version of the
#C         left wick in 3.6.4.
#C 3.6.3   [AF 7/13/94]
#C 3.6.4   [left side by DRH 8/89, right side by Charles Trawick 6/71]
#C         2 related wicks.  The one on the right is "candelabra".  The wick
#C         can also turn a corner, as shown in 3.7.2.
#C 3.7.0   "candlefrobra"  [RTW 11/84]  Variant of "candelabra" (3.6.4).
#C 3.7.1   "cross"  [RTW 10/89]  Same as 3.11.0.  One of the few known
#C         oscillators in which one phase is a polyomino.  Also see
#C         3.7.2.
#C 3.7.2   [HH 2/26/93]  A larger version of 3.7.1, which may be made
#C         any size.
#C 3.7.3   "star"  [HH 2/16/93]  Another polyomino.
#C 3.7.4   [HH 3/5/93]  Blocks may be added in any of the 4 corners of
#C         3.6.3.
#C 3.8.0   [DRH 1994] 
#C 3.8.1   [DRH 11/27/94]  Volatility -> 1 as length increases.  No
#C         finite p3 is known with volatility = 1.  (Volatility = number
#C         of rotor cells divided by total number of cells in rotor and
#C         stator.)
#C 3.9.0   [DRH 9/18/89] 
#C 3.9.1   "p3 rumbling river"  [DRH 11/26/94]  The rotor is connected
#C         and contained in a strip of height 2.

#C In the next 3 rows, each oscillator in the left column consists of
#C 4 quarters, which can be rearranged to form larger closed loops
#C (middle column) or chains that aren't closed (right column).  See
#C 5.8.0-5.8.1 for another example.
#C 3.10.0  "pulsar" or "pulsar CP 48-56-72"  [JHC 3/70]  The first
#C         known, and most commonly occurring, p3 oscillator.
#C 3.10.1  "quasar"  [RTW 8/71]
#C 3.10.2  [???? before 11/27/94]
#C 3.11.0  "cross"  [RTW 1989]  Same as 3.7.1.
#C 3.11.1  [DRH 11/27/94]
#C 3.11.2  [DRH 11/27/94]
#C 3.12.0  [HH 3/5/93]
#C 3.12.1  [DIB 3/7/93]
#C 3.12.2  [RWG 9/22/94]
#C ----------------------------------------------------------------------
#C Some other p4s are included as parts of oscillators with larger
#C periods, namely 124.1.0-1 and 188.0.0-1. 

#C 4.0.0   "mold"  [AF 1988]  Period 4/2, symmetry type "n/".  Supplies
#C          a 1-bit spark that's used, e.g., in 8.3.4, 16.1.1, several
#C          p28s, 32.1.1, 36.0.1, 36.0.2, 40.0.1, 52.0.1, 88.0.0,
#C          100.0.1, and 200.0.0.
#C 4.0.1   "mazing"  [DJB#45 12/73]  Period 4/2, symmetry type "/xk".
#C 4.0.2   "monogram" or "JHC"  [DRH 8/11/89]  Period 4/2, symmetry type
#C         "+c*c".  Supplies a spark that's used in 12.2.0-12.3.1.
#C 4.0.3   [DRH 8/89]  Period 4/2, symmetry type "/xk".  Supplies a spark
#C         that's used in 4.13.1 and 4.17.1.
#C 4.0.4   [DRH before 4/92]
#C 4.0.5   [DRH 9/89]  Supplies a spark that's used in 12.1.0.
#C 4.0.6   "Achim's p4"  [DJB#88 1976, AF 1988]  DJB found a larger
#C         form of this, using the same pieces that occur in siesta
#C         (5.2.3) and sombreros (6.1.1).  AF found the smaller version.
#C         The rotor consists of 2 copies of that in 4.2.6.
#C 4.0.7   [DJB#23 <1973?]
#C 4.1.0   "eater/block frob"  [DJB#51 <=1976]
#C 4.1.1   "confused eaters"  [DJB#49 before 1973]  Period 4/2, symmetry
#C         type "n/".
#C 4.1.2   "pinwheel"  [SN 4/70]  Period 4/4, symmetry type "nrk".
#C 4.1.3   "clock II"  Period 4/4, symmetry type "nrk".
#C 4.1.4   [DJB#28 before 1973?]  Rotor is p4/2, symmetry type "rk*k".
#C 4.1.5   "T-nosed p4"  [RTW 1989]
#C 4.1.6   [DRH 1994]  A narrower but longer T-nosed p4

#C Oscillators 4.2.0 to 4.2.3 are examples of "babbling brooks", in which
#C the rotor consists of a chain of cells, each one adjacent to only 1 or
#C 2 others.  At the time the collection was built, these were the only
#C known babbling brooks with period > 2.  I found another on 8/3/97:

#C .......o........
#C .....ooo....oo..
#C ....o...oo..o...
#C .o..o.oo..o.o...
#C o.o.o....oo..oo.
#C .oo..oo....o.o.o
#C ...o.o..oo.o..o.
#C ...o..oo...o....
#C ..oo....ooo.....
#C ........o.......

#C (For p2 examples, see 2.0.2, 2.1.3-5, and 2.1.7-8.)
#C 4.2.0   [DJB#13 before 1973]  Period 4/2, symmetry type "n/".
#C 4.2.1   [DJB#15 <1973]
#C 4.2.2   [DJB#104 6/3/77]
#C 4.2.3   [DRH 11/10/94]

#C 4.2.4   "wavefront"  [DJB#24 <=1976]  Rotor is confined to 2 parallel
#C         diagonals.  Also see 3.2.6.
#C 4.2.5   "Gray counter"  [???? 1971]  Also see 4.15.1.
#C 4.2.6   [DRH 8/89]  Also see 4.0.6.
#C 4.3.0   [DRH 8/89]  Period 4/2, symmetry type "n-e".
#C 4.3.1   [DRH 8/89]  Period 4/2, symmetry type "n-e".
#C 4.3.2   [DRH 8/89]  Period 4/2, symmetry type "n-c".
#C 4.3.3   [DRH 3/90]  Period 4/2, symmetry type "n/".
#C 4.3.4   [DRH 3/90]  Period 4/2, symmetry type "n/".
#C 4.3.5   [DRH 3/90]  Period 4/2, symmetry type "n/".
#C 4.3.6   [DJB#21 <1973]
#C 4.4.0   "penny lane"  [DJB#123 1972]
#C 4.4.1   [AF 8/22/94 (symmetric form), AWH 8/25/94 (using 2.8.1 for
#C         right half), DRH 11/23/94 (this p2 on right)]  Only 3 cells
#C         are p4; the rest are p1 or p2.
#C 4.4.2   [DJB#98 4/28/77]  Period 4/2, symmetry type "n-e".
#C 4.4.3   [RTW 1989]
#C 4.4.4   [DJB#20 <1977]
#C 4.5.0   "windmill"  [DRH 11/89]
#C 4.5.1   [AF 8/23/94 (symmetric form)]
#C 4.5.2   [AF 7/17/94 (symmetric form), RWG,AWH 11/20/94]
#C 4.5.3   [AF 8/31/94 (symmetric form)]
#C 4.5.4   "boss"  [DJB#30 1972]
#C 4.5.5   [DJB#69 <=1976]

#C In 4.6.0 to 4.6.5, only 2 cells are p4; the rest are p1 or p2.
#C 4.6.0   [DRH 12/10/94]
#C 4.6.1   [RTW 11/90]
#C 4.6.2   [DRH 12/10/94]
#C 4.6.3   [DRH 12/10/94]
#C 4.6.4   [DRH 12/10/94]
#C 4.6.5   [DRH 12/10/94]

#C Oscillators 4.7.0 to 4.10.1 are all related.  They are based on this
#C infinite oscillator, in which a single row of cells is surrounded by
#C 2 lines of blocks (or other things):

#C      oo..oo..oo.oo.oo.oo.o..oo
#C      oo..oo..oo.oo.oo.o.oo..oo
#C      .........................
#C      .........................
#C      .........................
#C      .........................
#C  ... ooooooooooooooooooooooooo ...
#C      .........................
#C      .........................
#C      oo.oo.o..oo.oo.oo..oo..oo
#C      o.oo.oo..oo.oo.oo..oo..oo
#C 
#C This can be made finite in several ways.  First, any of 3 small pieces
#C can be attached to the ends.  The first is shown in row 4.7.  (Also
#C see 8.0.5.)  The others are shown in 4.8.1 to 4.8.3.  (A much larger
#C end piece is shown in 4.12.2.)  Next, the line can be bent to form a
#C corner, as in 4.8.4.  If it's bent 4 times, it can form an octagon,
#C as in 4.9.0 to 4.10.0.

#C 4.7.0   "lightweight emulator"  [RTW 6/80]
#C 4.7.1   "middleweight emulator"  [RTW 6/80]  Supplies a 1-bit spark
#C         that's used, e.g., in 20.0.0-20.0.2, 24.1.2, 60.5.1, and
#C         124.1.0. 
#C 4.7.2   "heavyweight emulator"  [RTW 6/80]  Supplies a domino spark
#C         that's used, e.g., in 8.3.3, 12.0.2, 12.4.0, 32.0.2, 36.1.2,
#C         and 44.0.0.
#C 4.7.3   "overweight emulator"  [RTW ????] 
#C 4.7.4   
#C 4.8.0   [AF 7/13/94]  May be compressed horizontally by 1 or 2 cells.
#C         Also see 4.8.1 and 4.8.3-4.
#C 4.8.1   [DRH 7/14/94]  Half of 4.8.0, supported by 2 clocks.  (This
#C         use of a clock was discovered, in another universe, by DIB.)
#C 4.8.2   [DRH 12/6/94]
#C 4.8.3   
#C 4.8.4   
#C 4.9.0   [RTW ????, AF 8/7/94]  An octagon of side 2, showing 2 ways to
#C         stabilize the edge.
#C 4.9.1   [DRH 9/89]  An octagon of side 3, showing 4 ways to stabilize
#C         the edge.
#C 4.9.2   "octagon IV"  [RTW 1/79]  An octagon of side 4.  The edges
#C         can also be stabilized using eaters or toads as in 4.9.1.
#C         This also works if a block is added in the center.
#C 4.9.3   [DRH,RTW 9/89, AF 8/7/94]  An octagon of side 5, showing 4 ways
#C         to stabilize the edge.
#C 4.10.0  [AF,DRH 1994]  A larger octagon.  The corners can also be
#C         stabilized using eaters or toads as in 4.9.1.
#C 4.10.1  [DRH 9/16/92]  Stabilized p4 agar, made of several parallel
#C         lines.

#C 4.10.2  [DRH ????]  Period 4/2, symmetry type "+k*k".
#C 4.10.3  [RTW before 10/92]  The MW emulators (4.7.1) can be replaced by
#C         molds (4.0.0).

#C Pattern 4.7.1 (MW emulator) is often useful because of its 1-bit
#C spark.  But in some applications the object being sparked would
#C collide with the rest of the emulator.  In such situations the
#C oscillators below may be more useful.  (Also see the p4 at the top
#C of 124.1.0 and the one in 188.0.0.)
#C 4.11.0  [DRH 1994]
#C 4.11.1  "fountain"  [DRH 11/28/94]  Supplies a spark that's used in
#C         24.1.0-24.2.1, 124.0.0-1, and 124.1.1.  It can also be used
#C         (not shown) to double the period of a period 4N+2 MWSS stream,
#C         in a manner similar to that used in 60.5.1 to double the
#C         period of a LWSS stream.
#C 4.11.2  [DRH 1994]

#C 4.11.3  [AWH 2/10/95]
#C 4.11.4  [DRH 4/6/92]

#C Pattern 4.7.2 (HW emulator) has a useful 2-bit spark.  But sometimes
#C these are better:
#C 4.12.0  [DRH >=11/30/94]  Supplies a spark that's used in 12.0.3,
#C         60.3.1, and 124.1.1.  It can also be used (not shown) to
#C         double the period of a period 4N+2 HWSS stream, in a manner
#C         similar to that used in 60.5.1 to double the period of a
#C         LWSS stream.
#C 4.12.1  [DIB,DRH 12/12/94]  A longer but narrower version of 4.12.0.
#C 4.12.2  [DRH 1994]

#C 4.12.3  [RTW 9/91, DRH 1/14/95]  First stabilization (not shown here)
#C         was found by RTW 9/91.

#C 4.13.0  "sixty nine"  [RTW 10/78] Period 4/4, symmetry type "nrk".

#C 4.13.1  [RTW 9/89]  Period 4/2, symmetry type ".crc".
#C 4.13.2  [DRH 1/10/95]  Period 4/4, symmetry type "nrc".
#C 4.13.3  [DRH 1/10/95]  Period 4/4, symmetry type "nrc".
#C 4.14.0  [DRH 10/89]  2 related wicks.  The one on the left is
#C         "turning toads"; it's related to the toad hasslers such as
#C         60.1.0 - 60.1.4.
#C 4.14.1  [DRH 8/89, AF 1994]
#C 4.15.0
#C 4.15.1  [???? 1971]
#C 4.16.0  [RTW 9/91]
#C 4.16.1  [DRH ????, DIB 12/11/94]
#C 4.17.0  [RWG 9/17/94 (wick), 11/20/94 (ends)]  The repeating part of
#C         this wick may be attached to itself in 6 different ways.
#C 4.17.1  [RTW 9/89]
#C ----------------------------------------------------------------------
#C 5.0.0   "fumarole"  [DRH 9/3/89]  Supplies a domino spark that's used
#C         in traffic jam oscillators such as 50.0.0, 100.0.1, 110.0.0,
#C         200.0.0.  (The domino spark in a HW volcano (5.7.1) is more
#C         usable.)
#C 5.0.1   "octagon II"  [Sol Goodman & Arthur C. Taber 1971]
#C 5.0.2   [AF 7/13/94]  Also see 5.0.3.
#C 5.0.3   [AWH 11/19/94]  Skewed version of 5.0.2.
#C 5.0.4   "pseudo barberpole"  [AF 8/22/94]
#C 5.0.5   [RTW 1/82, DJB#145 8/15/84]
#C 5.0.6   [AF 7/27/94]
#C 5.1.0   "technician finished product"  [DJB#33 1/73]  Also see 5.3.3.
#C 5.1.1   "mathematician"  [DJB#34 1972]
#C 5.1.2   "aVerage"  [DJB#35 1973]
#C 5.1.3   [DJB#160 1/6/87]   
#C 5.1.4   [DJB#163 2/19/87]
#C 5.1.5   [RTW 1/82 (DJB#146)]
#C 5.1.6   "pentant"  [DJB#85 7/11/76]
#C 5.2.0   "toaster"  [DRH 4/1/92]  Supplies sparks that are used
#C         in 15.1.1.
#C 5.2.1   "middleweight volcano" or "MW volcano"  [DRH 4/6/92]  Supplies
#C         sparks that are used in 10.0.3, 10.1.1, 15.1.1, 20.0.0,
#C         20.0.2, all known p25s, 50.0.1, 80.0.0, 230.0.0, and 230.0.1.
#C 5.2.2   "101"  [AF 8/19/94]
#C 5.2.3   "siesta"  [DJB#57 1973]  Also see 4.0.6, 6.1.1-6.1.4, and
#C         8.3.0.
#C 5.2.4   [DJB#158 2/25/85] 
#C 5.2.5   [DJB#101 5/22/77]
#C 5.3.0   "chemist"  [DJB#38 1973]
#C 5.3.1   [DJB#84 7/76?]
#C 5.3.2   [DJB#44 ????]
#C 5.3.3   "pedestle"  [DJB#39 1973]  Rotor consists of 2 copies of
#C         the rotor in 5.1.0.
#C 5.3.4   [DRH 1994]  2 fumaroles hassle a long barge.  Based on 8.3.1.
#C         A different mechanism is used in 15.1.0.
#C 5.4.0   [DJB#151 9/29/84]
#C 5.4.1   [DJB#114 6/21/77]  Also see 7.1.2 and 11.0.0.
#C 
#C The next 2 are almost "period 5/2" oscillators:  In each one, the top
#C and bottom halves go through the same cycle, 2 gens out of phase.
#C 5.4.2   [DJB#87 7/15/76]
#C 5.4.3   [DJB#142 5/21/84]

#C 5.4.4   [DRH 10/4/89]
#C 5.5.0   "pentoad"  [RWG 6/77]  Also see 5.5.1 and 6.4.0.
#C 5.5.1   "multiple pentoads"  [RWG & Scott Kim ????]
#C 5.5.2   [DJB#93 7/26/76]
#C 5.5.3   [DJB#152 9/29/84]  Also see 6.4.2.
#C 5.5.4   [AF 8/7/94 (symmetric form), AWH 11/19/94]
#C 5.6.0   "electric fence"  [HH 10/20/92, DRH 11/23/92, 2/21/93]  A
#C         stream of 'ants' moves leftward from the 'source' at the
#C         right to the 'sink' at the left.  HH found a source that
#C         moves right at c/4, but no moving sink has been found.  DRH
#C         found the stationary sink and later found the stationary
#C         source.  Also see 5.7.0.
#C 5.6.1   [DRH ????]  There are 6 adjacent columns with only 1 active
#C         cell each.
#C 5.7.0   "another electric fence"  [DRH 1/26/95]  Also see 5.6.0.
#C 5.7.1   "heavyweight volcano" or "HW volcano"  [DRH 2/5/95]  Supplies
#C         sparks that are used in 10.0.3, 10.1.1, 30.4.0, 30.5.0, and
#C         35.0.0.
#C 5.8.0   "harbor" (so-named because gen 3 consists of 4 ships and
#C         8 boats)  [DJB#122 9/17/78]
#C 5.8.1   [DRH 12/2/94]  The pieces of harbor (5.8.0) can be
#C         rearranged in the same way as 3.10.0-3.12.2.
#C ----------------------------------------------------------------------
#C Also see the p6 used in 18.0.1.

#C 6.0.0   "unix"  [DJB#48 2/10/76]  Produces a 1-bit spark that's used
#C         in many oscillators.
#C 6.0.1   "A for all"  [DRH 3/6/93]
#C 6.0.2   [AF 7/25/94]
#C 6.0.3   "$rats"  [DJB#36 1972]
#C 6.0.4   "extremely impressive"  [DJB#78 8/76]
#C 6.0.5   [DJB#100 5/21/77]
#C 6.0.6   [DJB#65 <=1976]
#C 6.1.0   [AF 8/7/94 (symmetric form)]  Note similarity to unix (6.0.0).

#C The next 4 oscillators are closely related.  Also see 4.0.6, 5.2.3, 
#C and 8.3.0.
#C 6.1.1   "sombreros"  [DJB#56 1972]
#C 6.1.2   [DJB#133 11/16/80]  Also see 6.1.1
#C 6.1.3   [DJB#58 <=1976]
#C 6.1.4   [DJB#59 <=1976]

#C 6.2.0   [DRH 8/89]  Period 6/2, symmetry type ".e+e".
#C 6.2.1   [DRH 8/89]  Period 6/2, symmetry type ".e+e".
#C 6.2.2   [AF 7/13/94]
#C 6.2.3   [DJB#72 <=1976]
#C 6.2.4   [DJB#102 6/3/77]
#C 6.2.5   [RTW 1989]  Also see 6.2.6.
#C 6.2.6   [DJB#141 4/25/84]  Also see 6.2.5.
#C 6.3.0   [DRH 8/89]  Period 6/2, symmetry type "n/".
#C 6.3.1   [AF 7/26/94]
#C 6.3.2   [DJB#132 10/30/80]
#C 6.3.3   [DJB#117 9/1/77]
#C 6.3.4   [DJB#121 3/4/78]  Also see 32.0.0. 
#C 6.3.5   [DJB#110 6/19/77]
#C 6.4.0   [DJB#99 5/12/77]  Also see 5.5.0.
#C 6.4.1   "trivial p6"  [DRH 12/10/94]  There are no period 6 cells;
#C         the left 7 columns are p2; the rest are p3.
#C 6.4.2   [DJB#157 10/14/84]  Also see 5.5.3.
#C 6.4.3   [DRH 9/22/94]
#C 6.5.0   "symmetric T-nosed p6"  [AF 8/31/94]
#C 6.5.1   "T-nosed p6"  [AF 9/12/94]  Supplies a spark that's used in
#C         12.4.1.
#C 6.5.2   [DRH 9/89]  Period 6/2, symmetry type "-e+e".
#C 6.5.3   [RTW 11/16/94]  4 unixes support a simple diagonal wick.
#C 6.6.0   [right end:RTW 10/78, middle and left end:DRH 10/89]
#C 6.7.0   [NDE 11/21/94]  The wick (left end) was found by AF (8/19/94);
#C         NDE stabilized it; the variations are by DRH (11/22&27/94).
#C 6.8.0   [wick by DJB 1973, ends by DRH 1995?]
#C ----------------------------------------------------------------------
#C 7.0.0   "burloaferimeter"  [DJB#40 1972]  Also see 7.0.1.
#C 7.0.1   "airforce"  [DJB#41 1972]  Rotor consists of 2 copies of
#C         the rotor in burloaferimeter (7.0.0).
#C 7.0.2   [DJB#77 <=1976]
#C 7.0.3   [DJB#106 6/6/77]  Right half can also be turned upside-down
#C         and shifted up 2 units.
#C 7.0.4   [DJB#109 6/19/77]  Supplies a domino spark that's used in
#C         21.0.0, 105.0.0, and 329.0.0.  Also see 26.1.0, where an
#C         equivalent p7 gets phase-shifted by 2 gens.
#C 7.1.0   [DRH 9/22/94]
#C 7.1.1   [DRH 10/1/94]
#C 7.1.2   [DJB#113 6/21/77]  Also see 5.4.1 and 11.0.0.
#C 7.1.3   [DJB#135 9/7/81]
#C ----------------------------------------------------------------------
#C 8.0.0   "blocker"  [RTW ????]  Supplies a spark used in 16.0.1, 16.1.1-2,
#C         24.1.3, 40.0.1, 72.0.0, and 360.0.0.
#C 8.0.1   "Kok's galaxy"  [Jan Kok 1971]  Supplies a spark used in 56.0.0,
#C         120.3.0, 128.0.0, and 856.0.0.
#C 8.0.2   "figure 8" or "big beacon"  [SN 1970]  Supplies sparks used
#C         in 8.3.1-2, 8.5.0-2, 16.0.2, 24.1.1, 24.2.1, 32.1.1, 40.0.1,
#C         40.1.0, 96.0.0, 120.3.0, 128.0.0, and 808.0.0.
#C 8.0.3   "smiley"  [AF 7/17/94]
#C 8.0.4   [AF 7/20/94]  Period 8/2, symmetry type ".cxc".
#C 8.0.5   [DRH 11/16/94]  A p8 variant of the p4 emulators; see
#C         4.7.0-4.7.3.
#C 8.1.0   "cauldron" or "crucible"  [Don Woods, RTW 1971]
#C 8.1.1   "Hertz oscillator"  [JHC group 1970]
#C 8.1.2   "R2D2"  [Peter Raynham early 1970s (with a different stator),
#C         redeiscovered and named by NDE 8/14/94]
#C 8.1.3   "pyrotechnecium"  [DJB#42 1972]  (This was mis-named
#C         "pyrotechneczum" for many years.)
#C 8.1.4   [AF 8/26/94]  Supplies a 2-bit spark, which might be usable
#C         when the one in figure 8 (8.0.2) fails.
#C 8.1.5   [DJB#80 6/30/76]
#C 8.2.0   [RTW 1989]
#C 8.2.1   [DJB#115 6/22/77]
#C 8.2.2   "roteightor"  [RTW 1972]  Also see 8.2.3.
#C 8.2.3   "multiple roteightors"  [DRH 1/90]  A finite agar of any size
#C         can be constructed in this way.
#C 8.2.4   [DJB#105 6/6/77]
#C 8.3.0   [DJB#55 <=1976]
#C 8.3.1   [RTW 9/84]  2 figure 8s hassle a long barge.  Also see 5.3.4.
#C         A different mechanism is used in 15.1.0.
#C 8.3.2   [AF 8/31/94]  4 figure 8s hassle a tub.
#C 8.3.3   "p8, type 0 toad flipper"  See discussion at 60.0.0.
#C 8.3.4   [RTW 9/89]  Period 8/2, symmetry type "/xk".

#C The next 3 are closely related:
#C 8.4.0   [DJB#90 7/16/76]
#C 8.4.1   [DJB#138 1/23/83]
#C 8.4.2   [DJB#94 7/29/76]

#C 8.4.3   "bottle"  [AF 8/7/94]  Also see "ship in a bottle", 16.0.1.
#C 8.5.0   "tumbling T-tetson" [RTW ????]
#C 8.5.1   [DJB ????] "nonstandard type 1 p8 toad sucker"  See
#C         discussion at 60.0.0.
#C 8.5.2   [DJB ????] "nonstandard type 2 p8 toad flipper"  See
#C         discussion at 60.0.0.
#C ----------------------------------------------------------------------
#C 9.0.0   "worker bee"  [DJB#52 1972]
#C 9.0.1   multiple worker bees
#C 9.0.2   [DJB#43 1972??]
#C 9.0.3   [DJB#83 7/10/76]
#C 9.0.4   [DJB#155 10/9/84]
#C 9.1.0   "snacker"  [MDN 1972]
#C 9.1.1   multiple snackers
#C 9.1.2   [RWG 7/15/94]  Based on 15.0.1.
#C 9.1.3   [RWG 7/15/94]  Based on 15.0.2.
#C ----------------------------------------------------------------------
#C 10.0.0   [DJB#76 <=1976]
#C 10.0.1   [DJB#161 1/21/86]
#C 10.0.2   [DJB#153 9/30/84]
#C 10.0.3   [DRH 2/16/95]  2 p5s hassle a blinker.  Also see 10.1.1.
#C 10.1.0   [DJB#139 5/1/83]
#C 10.1.1   [DRH 2/16/95]  4 p5s hassle a blinker.  Also see 10.0.3.
#C ----------------------------------------------------------------------
#C 11.0.0   [DJB#112 6/20/77]  Also see 5.4.1 and 7.1.2.
#C 11.0.1   [AF 8/4/94]
#C 11.0.2   [DJB#156 10/9/84]
#C ----------------------------------------------------------------------
#C 12.0.0   "dinner table"  [RTW 1972]  Period 12/4, symmetry type "nrc".
#C 12.0.1   [DJB#159 1986?]
#C 12.0.2   [NDE 1/3/95]  Supplies a spark that's used in 24.0.1,
#C          48.0.0, 96.0.0, 132.0.0, 144.1.0, and 156.0.0.  It should
#C          also be used in 36.1.2, but an earlier version of the p12
#C          was inadvertently used there.   Also see 12.4.0.
#C 12.0.3   [DRH 1/4/95]  A larger version of 12.0.2, with a more
#C          accessible spark.
#C 12.1.0   [AF,AWH,RWG 8/8/94]  First found on a 32x32 torus, without
#C          the outer p4s.
#C 12.1.1   "baker's dozen"  [RTW 8/89]  Earlier versions used sparks
#C          from p4 and p6 oscillators.
#C 12.1.2   [DJB#131 10/26/80]  4 baker's dozens, using only stable
#C          objects and each other for support.

#C Oscillators 12.2.0 to 12.3.1 are variations on a p12 wick.
#C 12.2.0   
#C 12.2.1   [DJB <1980, RTW 1989]  Originally supported by MW emulators;
#C          RTW found that monogram works too.
#C 12.3.0
#C 12.3.1   "carnival shuttle"  [RTW 9/84]  Originally used MW emulators
#C          at the ends.  ???? {see RTW's 11/10/89 ltr}
#C 12.4.0   [MDN, DRH >~2/20/95]  A wick based on 12.0.2, using a p3
#C          multiple caterer.
#C 12.4.1   [NDE 6/9/95]
#C ----------------------------------------------------------------------
#C 13.0.0   [DJB#96 7/31/76]
#C ----------------------------------------------------------------------
#C 14.0.0   "tumbler"  [George Collins, Jr. 1970]  Period 14/2, symmetry
#C          type "-c+c".
#C ----------------------------------------------------------------------
#C 15.0.0   "pentadecathlon" or "PD"  [JHC 1970]  Supplies sparks used in
#C          ????  {mention phase changers}
#C 15.0.1   [RTW 10/78]  2 PDs hassle 2 blocks symmetrically.  Also see
#C          9.1.2.
#C 15.0.2   "Jolson"  [RTW 11/84]  2 PDs hassle 2 blocks asymmetrically.
#C 15.0.3   [DJB 3/73]  4 PDs hassle 4 blocks.
#C 15.1.0   [DJB 7/73]  2 PDs hassle a long barge.  Note that this is
#C          not the same mechanism as in 5.3.4 and 8.3.1.
#C 15.1.1   "p15 biblock hassler"  [DRH 2/21/95]  See description
#C          at 16.1.1.
#C 15.1.2   "loaflipflop"  [RTW 1990]  4 PDs hassle a loaf.
#C ----------------------------------------------------------------------
#C 16.0.0   [AF 7/27/94]  Period 16/2, symmetry type "rc*c".
#C 16.0.1   "2 pre L hassler"  [RTW 7/83]  4 blockers hassle a pair of
#C          pre-loafs.  Period 16/2, symmetry type ".k+k".
#C 16.0.2   "sailboat"  [RTW 6/84]  The 2 p8 oscillators (figure 8 and
#C          Kok's galaxy) supply sparks which attack the boat in the
#C          same way, but it's not possible to use 2 copies of either.
#C 16.1.0   "ship in a bottle"  [RWG 8/7/94]  Period 16/2, symmetry
#C          type "/xk".
#C 16.1.1   "p16 biblock hassler"  [NDE 2/20/95]  2 1-bit sparks (from
#C          a blocker (8.0.0) and a mold (4.0.0)) hassle a pair of
#C          blocks.  Sparks can also come from oscillators of period 5
#C          (see 15.1.1), 6 (see 18.1.0), 12, 29, 47, or 72 (not shown).
#C          The biblock creates a 1-bit spark of its own in gen 13, so
#C          it's possible to build a loop of 4 of them (see 52.0.1).
#C          Also see 16.1.2 for a symmetric version.
#C 16.1.2   "symmetric p16 biblock hassler"  [NDE 2/21/95]  See
#C          description at 16.1.1.
#C 16.2.0   [AF 8/7/94 (on a 32x32 torus), RWG 8/17/94]
#C 16.2.1   [RWG 8/9/94 (ship inside), RWG 8/17/94 (toad hassler)]
#C          A nonstandard toadflipper; see discussion at 60.0.0.
#C ----------------------------------------------------------------------
#C 18.0.0   [DJB before 5/91]  Period 18/2, symmetry type "n.e".
#C 18.0.1   [DRH 1/1/95]  2-glider shuttle.  See comments for 42.0.0.
#C 18.1.0   "p18 biblock hassler"  [NDE 2/20/95]  See description
#C          at 16.1.1.
#C ----------------------------------------------------------------------
#C 20.0.0   [NDE 3/22/95]  A period 9+11 traffic light hassler.
#C 20.0.1   [NDE 4/2/95]  A period 10+10 traffic light hassler.
#C 20.0.2   [NDE 6/29/95]  Sparks from some p4 and p5 oscillators
#C          hassle a loaf.
#C ----------------------------------------------------------------------
#C 21.0.0   [RTW 2/21/95]  A period 10+11 traffic light hassler.
#C ----------------------------------------------------------------------
#C 24.0.0   "p24, type 2 toadflipper"  [RWG 1994]  See discussion at 60.0.0.
#C 24.0.1   [NDE 11/20/94]
#C 24.1.0   [RWG 11/29/94]
#C 24.1.1   [RWG 11/29/94]  MDN found (not shown; 11/30/94) that an
#C          eater can be added at the top left in gen 14 to produce a
#C          rather inaccessible 1-bit spark. 
#C 24.1.2   [RWG 11/29/94]
#C 24.1.3   [NDE 11/29/94]
#C 24.2.0   [RTW 12/10/94]  Produces a 2-bit spark that's used in
#C          2 p48 toad hasslers (48.0.1-2).  Also see 24.2.1.
#C 24.2.1   [RWG 12/12/94]  A variant of 24.2.0.
#C ----------------------------------------------------------------------
#C All known p25 oscillators are based on pushing 2 or more traffic light
#C predecessors 3 units in 14 gens and pushing them back in 11 gens.
#C No way is known to do this with just one pre-t.l.
#C 25.0.0   [NDE 9/23/94 (with toasters instead of eaters), DRH 10/19/94]
#C 25.0.1   [NDE 11/5/94]
#C 25.1.0   [NDE 11/5/94]
#C 25.1.1   [NDE 11/18/94]
#C 25.2.0   [NDE 11/18/94]
#C ----------------------------------------------------------------------
#C 26.0.0   [DJB#140 1/18/83]
#C 26.0.1   
#C 26.1.0   [use of p7s in top by RWG 8/24/94; see RWG 10/30/94]
#C ----------------------------------------------------------------------
#C All known p28 and p29 oscillators are "pulsar hasslers".  Consider a
#C pair of hollow 3x3 squares, with 3 empty columns between them:
#C    ooo...ooo
#C    o.o...o.o
#C    ooo...ooo
#C After 15 generations, this becomes 4 hollow squares:
#C    ooo...ooo
#C    o.o...o.o
#C    ooo...ooo
#C    .........
#C    .........
#C    .........
#C    ooo...ooo
#C    o.o...o.o
#C    ooo...ooo
#C (This goes on to become a p3 "pulsar" in gen 20.)  By repeatedly
#C suppressing 2 of the hollow squares, we obtain oscillators of
#C periods 30 and 60; see 30.2.0-3 and 60.5.0.
#C 
#C It's also possible to suppress 2 of the squares in such a way that
#C the other 2 form in gen 14 instead of 15; this leads to oscillators
#C with periods 28 and 29.  Originally this required 8 pairs of squares
#C supporting each other; DJB found the first p28 ("newshuttle", not
#C included in this collection) in 1973.  Later, several methods were
#C found which use either 1, 2, or 4 mutually supporting pairs.

#C 28.0.0   
#C 28.0.1   
#C 28.0.2   
#C 28.0.3  [RWG 7/31/94] 
#C 28.1.0   
#C 28.1.1   
#C 28.1.2   "smaller newshuttle"  [DJB#64 8/2/80]
#C 28.2.0   
#C 28.2.1   
#C 28.2.2   
#C ----------------------------------------------------------------------
#C 29.0.0   
#C 29.0.1
#C 29.0.2   
#C 29.1.0   
#C 29.1.1   
#C 29.1.2   
#C 29.2.0   [RWG 7/31/94]
#C 29.2.1   "prime"  [DJB#127 8/2/80]
#C 29.2.2
#C 29.3.0   "p29 PD hassler"  [RWG ????, DRH 12/13/94]  2 copies of
#C          29.0.1 change the phase of a PD.  Supplies a 2-bit spark
#C          that's used in 58.0.0.  Also see 36.1.0 and 54.1.0.
#C 29.3.1   
#C 29.3.2   
#C ----------------------------------------------------------------------
#C 30.0.0   "queen bee" or "p30 shuttle"  [RWG 1970]  The central
#C          part (the shuttle) reappears, reflected across a vertical
#C          line, in 15 gens, but a beehive is also produced, which
#C          would destroy the shuttle.  The beehive can be destroyed
#C          by a block, as shown here, or by an eater in one of two
#C          different positions, as in 30.0.2. 
#C 30.0.1   "p30 glider gun"  [RWG 11/70]
#C 30.0.2   2 p30 shuttles push a beehive back and forth.  This also
#C          demonstrates the 2 positions of an eater that stabilize
#C          the shuttle.
#C 30.1.0   [NDE 10/30/94]  2 p30 shuttles repeatedly change the phase
#C          of a blinker.
#C 30.1.1   [DIB 9/1/92]  2 p30 shuttles repeatedly reverse a loaf.
#C 30.1.2   [RTW ????]  2 p30 shuttles repeatedly convert blocks to
#C          gliders.  Also see 92.3.0.
#C 30.2.0   "Eureka"  [DJB#130 8/16/80]  The simplest pulsar hassler.
#C          Can also be skewed, by moving one half up 2 units.
#C 30.2.1   
#C 30.2.2   
#C 30.2.3   "pulshuttle V"  [RTW 5/85]
#C 30.3.0   "hectic"  [RTW 9/84]  Period 30/2, symmetry type ".crc".
#C 30.3.1   "p30 LWSS gun"
#C 30.4.0   [DRH 2/14/95]  4 p5s hassle a beehive.  Also see 35.0.0.
#C 30.4.1   [????]  6 gliders in a 180 gen loop.  This use of a queen bee
#C          as a reflector is called a "buckaroo".
#C 30.5.0   "zweiback"  [MDN 2/13/95]
#C ----------------------------------------------------------------------
#C 32.0.0   "gourmet"  [DJB#120 3/4/78]  Period 32/4, symmetry type
#C          "nrk".  Also see 6.3.4.
#C 32.0.1   "popover"  [RTW 8/84]  Period 32/4, symmetry type "nrk".
#C 32.0.2   "pi portraitor"  [RTW 1984 or 1985]  Period 32/4, symmetry
#C          type "nrk"
#C 32.1.0   [RTW 5/85]  Period 32/2, symmetry type "n.c".  Two gourmets
#C          overlap, sharing a loaf.  It's possible to build an
#C          arbitrarily large agar this way.
#C 32.1.1   [NDE 1/26/95]  Period 32/2, symmetry type "-c+e".
#C ----------------------------------------------------------------------
#C 35.0.0   [DRH 2/14/95]  4 p5s hassle a beehive.  Also see 30.4.0.
#C ----------------------------------------------------------------------
#C 36.0.0   [NDE 1/29/95]
#C 36.0.1   "p36 traffic jam"  [RWG 10/14/94]
#C 36.0.2   [NDE 11/23/94]  2 copies of 36.0.1 change the phase of a PD.
#C          Also see 29.3.0 and 54.1.0.
#C 36.1.0   "p36, type 0 toadflipper"  [????]  See discussion at 60.0.0.
#C 36.1.1   "p36, type 1 toadsucker"  [????]  See discussion at 60.0.0.
#C 36.1.2   [NDE 11/20/94]  Could be made smaller using jams instead of
#C          T-nosed p4s.
#C ----------------------------------------------------------------------
#C 40.0.0   [DJB before 5/91]
#C 40.0.1   "p40 traffic jam"  [NDE 10/14/94]
#C 40.1.0   [DRH 11/4/94]  A period 20+20 traffic light hassler.  Period
#C          40/2, symmetry type "-c+e".  This use of a bookend as an
#C          eater also occurs in 25.0.1-25.2.0.
#C ----------------------------------------------------------------------
#C 42.0.0   [RTW 9/84, MDN ??/94]  A 2-glider shuttle, using a reaction
#C          in which an eater3 and sparks from 2 unixes reflect a pair of
#C          gliders.  RTW found a period 66+24n version of this; MDN
#C          noticed that period 42 could be achieved by rearranging the
#C          unixes.  The unixes can also be replaced by period 5 or 47
#C          oscillators, giving periods 50+40n (see 50.0.1) and 282+376n
#C          (see 282.0.0), or by a larger p6 oscillator, giving period
#C          18 (see 18.0.1).  Also, by a lucky coincidence, the spacing
#C          between the gliders allows 2 pairs of gliders to cross using
#C          rephasers, giving periods 246+24n (see 246.0.0), 230+40n
#C          (see 230.0.0), and 846+376n (not shown).
#C ----------------------------------------------------------------------
#C 44.0.0   [DJB 4/2/92]  (OBSOLETE: About 4/29/96, NDE found a simpler
#C          version:  Advance the MW emulators 3 gens and delete the 2
#C          blocks closest to them.)
#C 44.0.1   "p44 glider gun"  [DJB 4/2/92]  Large sparks from 2 p44
#C          oscillators combine to produce gliders.  (OBSOLETE: In 10/96,
#C          DJB found a p44 gun using only 1 p44 oscillator.)
#C ----------------------------------------------------------------------
#C 45.0.0   A p15 PD (15.0.0) and a p9 snacker (9.1.0) interact almost
#C          trivially.
#C ----------------------------------------------------------------------
#C Period 46: The p46 shuttle, known as "twin bees", was discovered in
#C 1971 by Bill Gosper.  Each end of the shuttle can be stabilized by
#C either 1 or 2 blocks, as shown in 46.0.0.  If only 1 block is used,
#C a large spark is produced which can reflect gliders and spaceships
#C in several ways.  Two shuttles can be combined in at least 5 ways to
#C produce glider guns (46.1.0, 46.1.1, 46.2.0, 46.3.0, and the right
#C half of 92.4.0).  Also see periods 92, 138, 184, 230, 276, 460, 552,
#C 690, and 40894.

#C 46.0.0   "twin bees" or "p46 shuttle"  [RWG 1971]
#C 46.0.1   [????, DRH 10/26/94]  2 shuttles push a beehive back and forth
#C          using 2 different reactions.  Also see 92.0.0.
#C 46.1.0   [RWG ???? {before 3/92}]  A p46 glider gun
#C 46.1.1   [RWG ???? {before 12/30/90}]  Double-barreled p46 glider gun
#C 46.2.0   [PC 6/24/94]  A p46 glider gun.  This one is useful for
#C          creating gliders parallel to an existing glider stream,
#C          as in 46.4.0.
#C 46.2.1   [RWG <=1992]  p46 LWSS gun, based on a 135 degree glider ->
#C          LWSS reflection.
#C 46.3.0   "newgun"  [RWG 1971]  The first known p46 gun.
#C 46.3.1   [RWG <=1992]  p46 MWSS gun, based on a 135 degree glider ->
#C          MWSS reflection from a pair of p46 shuttles.  (This glider +
#C          pre-block -> MWSS reaction is very useful; see 60.6.0 and
#C          120.2.0.)
#C 46.4.0   [DJB ????, DRH 12/31/90?]  p46 HWSS gun.  DJB found the only
#C          known 3-glider synthesis of a HWSS.
#C 46.5.0   [DJB? ????]  Pseudo p23 gun.  The outputs of 2 p46 guns are
#C          interleaved to produce a p23 glider stream.  (Also see
#C          60.6.0.)
#C 46.5.1   [PC,DRH 1994] p46 glider gun based on a 90 degree
#C          reflection that changes 1 glider to 2.  Also see 230.1.0.
#C 46.6.0   "p46 LWSS loop"  [Peter Rott 11/93, PC 1994]  Based on a
#C          90 degree LWSS reflection.
#C ----------------------------------------------------------------------
#C 47.0.0   [DJB#137 12/5/82]
#C 47.0.1   [???? before 9/92 (horizontal stacking), RWG before 9/92 (skewed
#C          vertical stacking)]  It's possible to build an arbitrarily
#C          large agar this way.
#C ----------------------------------------------------------------------
#C 48.0.0   [RTW 1995]  Sparks from 2 p12s move a pair of beehives.
#C 48.0.1   "p48, type 2 toadflipper" [RWG 12/11/94]  See discussion at
#C          60.0.0.
#C 48.0.2   "p48, type 2 toadsucker" [RWG 12/11/94]  See discussion at
#C          60.0.0.
#C ----------------------------------------------------------------------
#C 50.0.0   "p50 traffic jam"  [NDE 10/16/94]  Period 50/2, symmetry
#C          type "n-e".
#C 50.0.1   [DRH 3/19/92 (using early version of toaster)]  2-glider
#C          shuttle with period 50+40n.  See comments for 42.0.0.
#C ----------------------------------------------------------------------
#C 52.0.0   [DJB#119 10/1/77]  Period 52/4, symmetry type "nrc".
#C 52.0.1   [NDE 2/21/95]  Period 52/4, symmetry type "nrk".  See
#C          description at 16.1.1.  One can also have two pulses
#C          traveling around the loop separated by 16, 20, or 24 gens,
#C          or three pulses separated by 16+16+20.
#C 
#C ----------------------------------------------------------------------
#C 54.0.0   [DJB#62 <=1976]  This is based on the twin bees shuttle
#C          (46.0.0).  Also see centinal (100.0.0).
#C 54.0.1   
#C 54.1.0   [DJB before 5/91]  2 p54 shuttles change the phase of a PD.
#C          Also see 29.3.0 and 36.1.0.
#C ----------------------------------------------------------------------
#C 55.0.0   [DJB#162 1/26/86]
#C ----------------------------------------------------------------------
#C 56.0.0   [DJB before 5/91]
#C 56.0.1   "nonstandard p56 toadsucker"  [RWG 10/25/94]  See discussion
#C          at 60.0.0.
#C 56.0.2   "nonstandard p56 toadflipper"  [RWG 1994]  See discussion at
#C          60.0.0.
#C ----------------------------------------------------------------------
#C 58.0.0   "p58, type 3 toadsucker"  [RWG,MDN 10/25/94 (using larger
#C          p29s), DRH 12/13/94]  See discussion at 60.0.0.
#C ----------------------------------------------------------------------
#C 60.0.0   "p60 glider shuttle"  [???? <=1971]
#C 60.0.1   [AF 7/18/94]  2 p30 shuttles push a blinker up and down.

#C A "toad hassler" is an oscillator in which a toad is changed by a
#C pair of domino sparks above and below it.  It either moves 1 unit
#C sideways ("toadsucker") or changes its orientation ("toadflipper").
#C Amazingly, there are 5 different positions for the sparks which
#C work; I call them "type -1" through "type 4", depending on the
#C horizontal distance between the top and bottom sparks.  The odd types
#C are toadsuckers; the even ones are toadflippers.  Given a period N
#C oscillator which produces accessible domino sparks once per period,
#C the resulting toad hasslers have period 4N if N is odd, 2N if N is
#C even.  However, there are also some toad hasslers in which the period
#C is smaller, either because the sparks occur more than once per period
#C (see 58.0.0) or because the interaction with the spark is more
#C complicated (see 8.5.1-2, 16.2.1, and 56.0.1-2).  Oscillators 60.1.0
#C to 60.1.4 show the 5 standard toad hassler geometries; see 8.3.3,
#C 36.1.0-1, 108.0.0-1 for more examples.  Toad hassling was apparently
#C first discovered by RTW in 6/84, using sparks from PDs and snackers to
#C give p60 and p36 oscillators.
#C 60.1.0   "p60, type -1 toadsucker"
#C 60.1.1   "p60, type 0 toadflipper"
#C 60.1.2   "p60, type 1 toadsucker"
#C 60.1.3   "p60, type 2 toadflipper"
#C 60.1.4   "p60, type 3 toadsucker"
#C 
#C 60.2.0   "p60 glider gun" or "twogun"
#C          [V. Everett Boyer & Doug Petrie <=1973]
#C 60.2.1   "p60 end-to-end glider gun"
#C 60.3.0   
#C 60.3.1   "overwrought p60"  [NDE 2/18/95]  2 modified Eurekas (30.2.0)
#C          and a p4 2-bit sparker (4.12.0) push a traffic light back
#C          and forth.
#C 60.4.0   "metamorphosis II"  [RTW 12/13/94]  Illustrates a glider to
#C          LWSS reflection from a pair of p30 shuttles [found by
#C          Paul Rendell before 1/20/86, rediscovered by PC 12/9/94], and
#C          a symmetric collision between 2 LWSSs which makes 2 gliders.
#C 60.4.1   This demonstrates a reaction [???? 1971?] in which gliders
#C          hitting a snake alternately create and destroy a boat.  This
#C          can be used as a memory device (called a "boat-bit"); see
#C          15240.0.0.
#C 60.5.0   "twirling T-tetsons II"  [RTW 1989]  Period 60/4, symmetry
#C          type "nrk".
#C 60.5.1   "p60 LWSS gun"  [DRH 1/28/91?]  A MW emulator deletes half of
#C          the outputs of a p30 LWSS gun.  (There are also oscillators
#C          which can do the same for MWSS or HWSS streams; see 4.11.1
#C          and 4.12.0.)
#C 60.6.0   "p60 MWSS gun"  This glider + pre-block -> MWSS reaction is
#C          very useful; see 46.3.1 and 60.6.0.
#C 60.7.0   "pseudo p20 glider gun"  [DRH 12/19/91]  3 p60 glider streams
#C          are merged to form a p20 stream.  This uses a head-on
#C          collision between a glider and a pair of gliders to insert
#C          gliders into an existing glider stream. Using this reaction,
#C          a pseudo period N gun can be built for any N>=19.  More
#C          complicated methods are known for getting periods 14 to 18.
#C          (Also see 46.5.0.)
#C ----------------------------------------------------------------------
#C 72.0.0   [RTW 7/90]
#C ----------------------------------------------------------------------
#C 75.0.0   "glider shuttle III"  [RTW 9/84]
#C ----------------------------------------------------------------------
#C 80.0.0   [DRH 10/28/94]  A p16 (16.2.0) and a MW volcano (5.2.1)
#C          interact almost trivially.
#C ----------------------------------------------------------------------
#C 88.0.0   [DRH 1994]  A variant of 44.0.0.
#C ----------------------------------------------------------------------
#C 90.0.0   "p90 glider shuttle"
#C 90.0.1   [DIB 11/30/93]  A glider shuttles between 2 pairs of p30
#C          shuttles.  At each end it turns into a boat and then back
#C          into a glider.  The spark that turns the glider into a boat
#C          is symmetric, so this reaction can also be used to shift a
#C          glider's path by 2 units without reversing its direction. 
#C          Also see 184.0.0 and 276.0.0.
#C 90.1.0   "p90 glider gun"  [DRH ????]
#C ----------------------------------------------------------------------
#C 92.0.0   [RWG 5/28/92]  2 p46 shuttles push a beehive back and forth.
#C          Also see 46.0.1.
#C 92.1.0   [NDE 11/23/94]  2 p46 shuttles push a blinker back and forth.
#C 92.2.0   [DRH, NDE 1/15/95]  2 p46 shuttles repeatedly reverse a loaf.
#C 92.3.0   [RTW 3/91]  2 p46 shuttles repeatedly convert blocks to
#C          gliders.  Also see 30.1.2.
#C 92.4.0   "p92 glider gun"  [DRH 1/7/91]  Made from 2 overlapping p46
#C          guns.
#C ----------------------------------------------------------------------
#C 96.0.0   "p96 Hans Leo hassler"  [NDE 1/28/95]  A p12 sparker
#C          (12.0.2) changes a traffic light into a B-heptomino; an
#C          eater and a figure 8 change it back.   Also see 132.0.0,
#C          144.1.0, and 156.0.0.
#C ----------------------------------------------------------------------
#C 100.0.0  [RWG before 9/87]  "centinal"  Related to 46.0.0 and 54.0.0.  RWG
#C          created a huge (13584x12112) p1100 glider gun from this.
#C 100.0.1  "p100 traffic jam"  [NDE 10/15/94]
#C ----------------------------------------------------------------------
#C 105.0.0  A p15 PD (15.0.0) and a p7 (7.0.4) interact almost trivially.
#C ----------------------------------------------------------------------
#C 108.0.0  "p108, type 0 toadflipper"  See discussion at 60.0.0.
#C 108.0.1  "p108, type 1 toadsucker"  [DJB before 5/92]  See discussion at
#C           60.0.0.
#C ----------------------------------------------------------------------
#C 110.0.0  "p110 traffic jam"  [RWG 10/17/94]
#C ----------------------------------------------------------------------
#C 120.0.0  "p120 glider gun"  [DRH 1/13/91]  A blocker can convert a
#C          period 8n+4 glider gun to period 16n+8.
#C 120.0.1  [MDN ????]
#C 120.1.0  "p120 LWSS gun"  [DRH 1/28/91]  A blocker can convert a
#C          period 8n+4 LWSS gun to period 16n+8.
#C 120.2.0  "p120 MWSS gun"  [????]  This glider + pre-block -> MWSS
#C          reaction is very useful; see 46.3.1 and 60.6.0.
#C 120.3.0  "p120 HWSS gun"  [DJB ????]
#C ----------------------------------------------------------------------
#C This mechanism was known for years before a way was found to make it
#C work.  A "lumps of muck" predecessor is hassled on the left starting
#C around gen 15, causing its left half to disappear.  The right half
#C is hassled at the top starting around gen 55, causing another LoM
#C predecessor to form in gen 62.  The process is repeated, rotated 180
#C degrees.
#C 124.0.0  [clock+eater+block by DRH ????, 4.11.1 by RWG 11/30/94]
#C          Smallest known version. 
#C 124.0.1  [DRH ????]  An arbitrarily large agar can be built.
#C 124.1.0  [eater3 by DJB? ????, MW emulator by MDN? ????,
#C          eater+p4 by DRH ????, 4.11.0 by ???? ????]
#C 124.1.1  [4.12.0 by RWG 11/30/94, eater+p4 by DRH ????]
#C ----------------------------------------------------------------------
#C 128.0.0  [DJB before 11/91]  2 B-heptominoes move around a track of length
#C          256 gens formed from p8 oscillators.  Also see 808.0.0.
#C ----------------------------------------------------------------------
#C 132.0.0  "p132 Hans Leo hassler"  [NDE 1995]  A p12 sparker (12.0.2)
#C          changes a traffic light into a B-heptomino; a unix changes
#C          it back.  Also see 96.0.0, 144.1.0, and 156.0.0.
#C 132.0.1  [DJB before 8/94]  A variant of 44.0.0.
#C ----------------------------------------------------------------------
#C 135.0.0  [RWG 1989]  A 2-glider shuttle, combining a rephaser and the
#C          reflections from 75.0.0.  Also see 150.0.0.
#C ----------------------------------------------------------------------
#C 138.0.0  [RWG ????]  Glider loop based on a 'flawed' 180 degree
#C          glider reflection.  The first reflection leaves behind a
#C          pond, which the next deletes, so gliders must occur in
#C          pairs.  (But see 552.0.0.)  The length of the loop may be
#C          anything of the form 138+184n.
#C ----------------------------------------------------------------------
#C 144.0.0  [AF 7/21/94, DIB 8/8/94]  Found by AF on a cylinder of
#C          height 22 (without the outer blocks) and originally
#C          stabilized using figure 8s.  The use of blocks (which
#C          temporarily become loaves) was found by DIB.
#C 144.0.1  "p144 glider gun"  [RWG 7/22/94]  Uses a spark from 72.0.0
#C          to turn a block produced by 144.0.0 into a glider.
#C 144.1.0  "p144 Hans Leo hassler"  [NDE 1/4/95]  A p12 sparker (12.0.2)
#C          changes a traffic light into a B-heptomino; an eater changes
#C          it back.  Also see 96.0.0, 132.0.0, and 156.0.0.
#C ----------------------------------------------------------------------
#C Also see p150 glider gun in 2700.0.0.
#C 
#C 150.0.0  [DRH 1989]  A 2-glider shuttle, combining a rephaser and the
#C          reflections from 90.0.0.  Also see 135.0.0.
#C 150.0.1  [RTW <=1989]  A p150 2-glider shuttle, extensible to period
#C          150+120N.  Also see 165.0.0.
#C ----------------------------------------------------------------------
#C 156.0.0  "p156 Hans Leo hassler"  [NDE 1/4/95]  A p12 sparker (12.0.2)
#C          changes a traffic light into a B-heptomino; an eater changes
#C          it back.  Also see 96.0.0, 132.0.0, and 144.1.0.
#C ----------------------------------------------------------------------
#C 165.0.0  [RTW <=1989]  A p165 2-glider shuttle, extensible to period
#C          165+120N.  Also see 150.0.1.
#C ----------------------------------------------------------------------
#C 184.0.0  [DRH 1/24/92]  Glider shuttle based on 180 degree reflection: a
#C          p46 spark turns the glider into a block; the next spark turns
#C          it back into a glider.  The period can be anything of the
#C          form 184+92n.  Also see 276.0.0 and 90.0.1.
#C ----------------------------------------------------------------------
#C 188.0.0  "pseudo p94 gun"  [DJB,RCS,PC 7/11/94]  A pre-honey farm
#C          interacts with an eater and a block, emitting a glider,
#C          creating a traffic light, and forming another pre-honey farm
#C          47 gens later; this reaction is called "AK47".  The new
#C          pre-h.f. interacts with another eater and block to recreate
#C          the original configuration.  Unfortunately, the 2 traffic
#C          lights must be suppressed in order to make the process repeat
#C          every 94 gens.  This reaction was found independently by DJB
#C          and RCS and was known for years before PC found a period 4
#C          oscillator which could suppress the traffic lights.  (A true
#C          p94 gun was built by DRH in 6/90, using 36 AK47s.)
#C 188.0.1  "p188 glider gun"  [DRH 7/19/94]
#C ----------------------------------------------------------------------
#C 200.0.0  "p200 traffic jam"  [RWG 10/16/94]  (ERROR:  This isn't an
#C          oscillator; it becomes one in gen 60.)
#C ----------------------------------------------------------------------
#C 230.0.0  [DRH 3/19/92 (using early version of toaster)]  4-glider
#C          shuttle with period 230+40n.  See comments for 42.0.0.
#C 230.0.1  "obnoxious p230"  [RWG 5/28/92]  Sparks from a p46 shuttle
#C          interact 3 times with sparks from a p5 MW volcano; one
#C          interaction makes a temporary blinker; another makes a
#C          temporary glider. 
#C 230.1.0  [PC 6/28/94]  p230 glider gun based on 2 LWSS reflections from
#C          p46 oscillators.  In one, the LWSS is turned 90 degrees; in
#C          the other it becomes 2 parallel gliders.  Also see 46.5.1.
#C ----------------------------------------------------------------------
#C 240.0.0  2-glider shuttle.  Uses the same 180 degree reflection as
#C          60.0.0, combined with 2 rephasers.
#C ----------------------------------------------------------------------
#C 246.0.0  [DRH 11/89 (p270+24n), 4/92 (p246)]  2-glider shuttle with
#C          period 246+24n.  See comments for 42.0.0.
#C ----------------------------------------------------------------------
#C 276.0.0  [DRH 1/24/92]  Glider shuttle based on the same reflection
#C          as in 184.0.0.  Also see 90.0.1
#C 276.1.0  "4-barrelled p276 glider gun"  [DJB before 11/92]
#C ----------------------------------------------------------------------
#C 282.0.0  [RWG 9/13/92]  2-glider shuttle.  See comments for 42.0.0.
#C ----------------------------------------------------------------------
#C 300.0.0  [MDN 10/27/94]  Sparks from a pentadecathlon (15.0.0) and a
#C          centinal (100.0.0) interact to form a temporary block.
#C ----------------------------------------------------------------------
#C 329.0.0  A p47 (47.0.0) and a p7 (7.0.4) interact almost trivially.
#C ----------------------------------------------------------------------
#C 360.0.0  "p360 2-barelled glider gun"  [DJB before 10/92]
#C ----------------------------------------------------------------------
#C 400.0.0  "p400 glider loop"  [RWG 1987]  A glider bounces between 4
#C          centinals.  By expanding the loop and using more than one
#C          glider, oscillators of period 100N can be built for any N.
#C ----------------------------------------------------------------------
#C 460.0.0  [DJB 1992, DRH 1995]  p460 glider gun based on a reaction
#C          found by DJB which converts 2 gliders to 3 gliders.  One
#C          glider escapes; the others are reflected by p46 shuttles
#C          to repeat the reaction.  Given a period P oscillator which
#C          can reflect a glider 90 degrees, we can build a gun whose
#C          period is any multiple of P that's >= 452.  (DJB originally
#C          used this to build a p500 gun, using centinals (100.0.0) to
#C          reflect the gliders.)
#C ----------------------------------------------------------------------
#C 552.0.0  [RWG ????, DRH 1/23/92]  Glider loop based on the same
#C          reflection as in 138.0.0.  Here the ponds are deleted by a
#C          p8 blocker.  The period of the loop can be anything of the
#C          form 138+184n, but the period of the oscillator is 4 times
#C          that.
#C ----------------------------------------------------------------------
#C 690.0.0  [DRH 1/3/91]  Sparks from a p46 shuttle interact 6 times with
#C          sparks from a p15 pentadecathlon; one interaction makes a
#C          temporary blinker.
#C ----------------------------------------------------------------------
#C 808.0.0  "p808 glider gun"  [DJB before 11/91]  A B-heptomino moves around
#C          a track made of various eaters and p8 oscillators; it makes
#C          4 moves each of durations 64, 65, and 73.  Also see 128.0.0.
#C          (In 1996, DJB found several B-heptomino moves using only
#C          stable objects to form a track, thereby producing guns of
#C          all periods >= 62.)
#C ----------------------------------------------------------------------
#C 856.0.0  "p856 glider gun"  [DJB before 11/91]
#C ----------------------------------------------------------------------
#C 2700.0.0    "crystallization and decay oscillator"  [DRH 3/27/90]
#C             Extensible to period 2700+1950N.  A p150 gun shoots gliders
#C             toward a pair of PDs.  The first is reflected 180 degrees
#C             and hits the second, forming a honey farm.  Subsequent
#C             gliders grow a crystal back toward the gun; every 11
#C             gliders add another pair of beehives to the crystal.
#C             Eventually, an eater stops the growth and the crystal
#C             begins to decay: two successive gliders delete one pair of
#C             beehives.  (This is based on an earlier pattern found and
#C             lost by RWG, using a p46 gun.)
#C ----------------------------------------------------------------------
#C 15240.0.0   "p120-based PRNG"  [DRH 3/21/92]  Pseudo random number
#C             generator, based on an earlier pattern by RWG (a larger
#C             version of 40894.0.0).  Produces a sequence of bits b[n],
#C             represented by gliders, satisfying the recurrence
#C             b[n] = b[n-1] XOR b[n-7].  The sequence has period 127,
#C             so the period of the pattern is 120*127.  Increasing the
#C             separation between the NW and SE parts by 15N units
#C             diagonally changes the 7 above to K=7+N  (N >= -4).  The
#C             period of the sequence depends rather erratically on K:
#C 
#C             K | 2 3  4  5  6   7  8  9  10   11   12   13    14    15
#C             P | 3 7 15 21 63 127 63 73 889 1533 3255 7905 11811 32767
#C 
#C             K |  16  17     18     19     20   21      22      23
#C             P | 255 273 253921 413385 761763 5461 4194303 2088705
#C 
#C             K |      24       25     26        27       28        29
#C             P | 2097151 10961685 298935 125829105 17895697 402653181
#C 
#C             K |       30      31   32   33
#C             P | 10845877 2097151 1023 1057
#C 
#C             Also see 40894.0.0.  (In 1996, DRH built a p30-based PRNG.)
#C             This uses a "boat-bit", a reaction in which gliders hitting
#C             a snake alternately create and destroy a boat. 
#C ----------------------------------------------------------------------
#C 40894.0.0   "p46-based PRNG"  [RWG ????, DRH 1/10/95]  Pseudo random
#C             LWSS generator. Produces a sequence of bits b[n],
#C             represented by LWSSs, satisfying the recurrence
#C             b[n] = b[n-1] EQV b[n-10].  The sequence has period 889,
#C             so the period of the pattern is 46*889. Moving the bottom
#C             right gun and the reflector at the right edge 46N units
#C             farther right changes the 10 above to  K=10+4N  (N>=0).
#C             The period of the sequence depends on K as indicated in
#C             the description of 15240.0.0.
#P
      **     **    *              **              **     *     **    **    **               **     **       **    **                  ** *                                                                                                                                **    **                                                                                                               **                  * **                                          *           **                                                        **                                                                                                                                  *                                                                                                                                         *                                                                                                                                   *                                                                        **   **                                              **   **                                                                                                                                *                                                                                                                                                                                                   **          **                           **    **    ** *                               *                                                                    *                                                                                                                            *    *                                                  ** *      ** *                                                                                                                                  * **      ** *                         *                                                                                                                                                                                                                     **    **                                                                                                                 **         **                 **         **                                                                                                                           ***                                                                                                          **            **                                                                                                                                                        *       *                                                                                                                           **     **                                                                                                                                                                              **
       *     **   * *             * *             * *   * *    *    *  *   *  *             * *    * * *   *  *   * *                 * **                                                                *                                                                *     *                                                                                             **   **          *  *                 ** *                                         * *           *           **                      **                  *  *                   * **                                **                      **                                               * *                                                                                                                                        *                                                                                                                                  * *                                                                      *  * *  *                                            *  * *  *                                            ** *      ** *                                                                     * *                                                                                                                                                                                                * *          * *                           *     *    * **                  *          *****                                         *                      *****          *                                                                                                             ***    ***               *    *                           * **      * **                                                                                                                                  ** *      * **                        * **                                                                                                                                                                                                                   * *  * *                                                                                                                  *         *                   *         *                                                                                                                                                                                                                                 **  **  *              *  **  **                                                                                                                                               * *     * *                                                                                                                          **     **                                                                                                                                                                              **
      *            *               *               **    * *    *    **      **              * *      **    * *     *                     **       *           *                         **             ***                                  ***          ***             *     *                      *                       * *         * *                                *  * *  *          ** *              **                                             * *           * **        *  *                   * *               *   * *                   ** *                                **                      *                    *         *                 * *                                                                                                                             **       *   *                                                                                                                                * *                                                                  **   **   **   **                                    **   **   **   **                                        * **      * **                                                    *                 * *                                                                                                                                                                                             ***              ***                        *     *   **           **        **         ** *  *                       **               **             **     *  * **         **        **                                                                                                 *          *            ***    ***                       **        **    **                                                                                                                                    **        **                      * **                                                                                                                                                                                                                     ****                                                                                                                   *           *                 *           *                                                                                                                          *   *                                                                                                 *  *  * *              * *  *  *                                                                                                                                                *       *
      **                                                  *    **                             *              *      **                    *        *           *              **         *             *             **        ***                                        **    **          * *       * *        **   **       * * **      *  *               * *  * ***      * ** ** *             *  *            *              **              **            ** **         ** *          * *                *  * **            ******* **                      **          *                                            *                  * *       * *             ** * **                                                                   **                                                       **** *    ***        **                                                                                                                      ** **                                                                 *               *                                    *               *                                            **  **    **                                                  **                *  *   **                                                                                                                                                                                   ** *   *            *   * **                    **    **  *            **       **         *       *                      **                **           *  *   *       *         **       **                                                                                                 **        **           *          *                      *         *     *        *    *                                                                           **             **                            *        *                        **                                                                                                                                                                                                                    *  **  *                                                                                                                 **         **                 **         **                                                                                                                          *   *                                                                                                  ** *** **            ** *** **                                                                                                                                                                                                                                                                                                                                                **     **
                                                                                                                                           *      ** *        ** *            *       ** *              *         **  *                     *    *       *                  * **               *                  * * *      **    *          *              *  * * * *      **       **       **** * * *          *             *    *           *  *            * *           * *                            * * *   *          *        *                        *         * *                  ****                  *** * **              * *       * *             * **    *                                                                 * *                                                      * *  ***  ***    * ****                                                                                                                      *  *  *                                                            ** *               * **                              ** *               * **                                         *   *     *                                              **    **               * *    **                           *                  *                                                                                                                                  *     * **            ** *     *                    * **     *                     **  **     ** *  *                                    **  **             **     *  * **     **  **                                                                                                                                  **        **                       *         *     *     ** **** **                                                                       *  *      *      *  *                         *          *                                                                                                                                                                                                                                             *  **  *                                                                                                                    ** * **                       ** * **                                                                        *                                                                                                                                                            * * * *              * * * *                                                                                                                                                                                                                                                                                                                                                 **     **                                                                                                                   *
      **                                                                                                                                  **         **      *   **         * *      *  *            *  *        *            *    *       * *   *     *       *            ** *           *  *      **   *       ** **          ***         ***  ***        *                 * * * *        *     * * *          **            *    *          *    *         *** ***       *** **           * *              *  *   ***        * **     *                       *         * * *                *    *                *  * * *  *         ** * **     ** * **              *** *                                                                   *                                                                     ***  * *                                                                                                                       * ******                                                         * * **             ** * *                            * * **             ** *  *                                        *   *     *                  *                      **  **    ***             * *                                 * *                * *                                                                                                                                 *     *                  *     *                    ** *    **                                 *****                                                                *****                                                                                                                     *              *                                           **        **    **       *    *                                                                **      *          *          *      **                **        **            **            **                                                                                                                                                                                                                   *  *                                                                                                                 *** ***   *** ***             *** ***   *** ***                                                                   *           *                                         ***                                                                                             *    *         *          *         *    *                                                                                                                                            *     *                                                                                                                                                                                                                                                                                                                  * *
       *                                                                                                                              ** *        *         * *             **       *               *           * * *       * *   *     ***  *  *     ****    *                **        * * *      *     *      * * *      ** *  *      ***  ***                  *        **       **     * * *     *             * **        *    *         *      *          * *           * *                                *     *         * *     * *                     **        * * *             *  *   * *                *** * * **         * **  *     *  ** *              *                     **    ** *        *                             * ** **                            *                         **                                                                                                                                   *  * * *     *                                                        * *     ***   ***     * *                            * *     ***   ***     * **                                       **  **    **                 * *                     **  **    **       * *    *                                  *   **  **         *   **                                                                                                                               *     * **            ** *     *                        **    ** *                               *                                                                    *                                                                                                                       *              *       *              *                      ** *    *     *                      *                                                       **      *          *          *      **              **      ** *              **            **                                                                                                                                                                                                                           **                                                                                                          *  **  * * *  **  *           *  **  * * *  **  *                                                                 ***          *                                                                                                                                        * *  * *** * *** *        * *** * *** *  * *                                                                                                                                          ***   ***                                                                                                                                                                                                                                                                                                                *   *
      *     **      *      **       **       **    **     *      * *      **                                                          * **        **        *  *         **            *           **  *        **   *       *  *  *           *           *   *                 *        *  *          * *      **   **        *  *            *          * * * *  *         * ** ** *      * * * ****              ** *         *  *          *      *          * *           * ***            * *                *****            *     ** *                  **       ** *   * **         * * * * * *  *          ***    * *                **       **                   ***  **               *    * **        ***       **                  **    *                 **         *                         *            **                                                                                                                      **** *  **  **                                                      **  *     * *   * *     *  **                        **  *     * *   * *     *                                      ** *    *     *                 *   **                            **         **                                       *   ** *  *        *   **                                                                                                                           *     ** *   *            *   * **     *                     *    * **                                                                                                                                                                                                                            *      **      *       *              *                      * **     *     *                      **        *    *                                               *                     *                       *      * **                                                                                                                                                                                                                                                         ***                                                                                                         **    *** ***    **           **    *** ***    **                                                                             ***                                                                                                                                        *   *   ** **   *        *   ** **   *   *                                                                                                                                     ***  ** ** ** **  ***                                                                                                                                                                                                                                                                                                          *****                **
      **    * *    * *     * *      * *     *  *   * *   * *     ** *    *  *                                                             **     **          **         * *         *  *               *          ***       **   *           **        **  * *                  *          **          **                     *****             *  *      *** *  * *          *  * *  *       *  *                       **     * *  * *         *    *         *** ***       *** *                                                  *        *                   *       * *    * **          *  * * * * * *         *  * * * *                *  *   *  *                      *                 *         **         *      *                      **                   **** *   *   *       **                   **       *                                                                                                                           ** * *                                                        *    **    ***   ***    **    *                      *    **    ***   ***    **                                      * **     *     *     **         *   **   **                       *          *                                        *   **  **         *   **                                                                                                                         ** *        ***              ***        * **                  *   **    **               **  **                                                **  **                                **  **                                                                                                                **              *      **      *                    **    **  **    **                     **       ** **** **                                              *  *             *  *                       *     **                                                                                                                                                                                                                                                             ** *                                                                 **         **                                                                                                                                                                                                   ***                                                                                                  *** *** ***          *** *** ***                                                                                                                                                ***   ***                                                                                                                                                                                                                                                                                                               **   **               * *
             * *    * *       * *      *    *  *     *    * *       *     *  *                                                            *      ***                    *          * **          *   **           *           ***            *         * * *                    **                                            *                  * *                           **   **           * **                     *     **    **          *  *            * *           * *                * **               *             ** *******                   *           ****                 * *   *  *             *    *                  ***   ***                    ** * * *             **        *         **    * *                   *** **                  * *  ***  ***    * ****                 *    *                                                                                                                           * ** *  ** * **                                                     *****                     *****                      *****                           *                                   **  **    **     **         *   **   **                                                                  **        * *                * *    **                                                                                         **                         *              * *          * *              *                 **  *     *      **       **                **                      **                **       **         **                **       **                                                                                                                             **                           *     *   *     *                                 *    *                                                  **             **                         **    *                  * *                                                                                                                                                                                                                                           * *                                                                 *         *                                *  * *  *                     *  * *  *                                                                      ***                                                                                                                                                  *****    *     *              *     *    *****                                                                                                                                **        *     *        **                                                                                                                                                                                                                                                                                                       *****           **      *           * *
      **      **     * *       **       *    **     *       *       **     **                                                              *                           **          *            * **                          *              *          ** **                                                                                                                                     *  *                   *                         **            ** **         ** ***                                * *             * *   *                     **                                *    *                 ****                                                ** * * ***                      *              **             ** ** *      *  **                       ***  ***  * *                                                                                                                                                  ** * ***** ** *                                                         *                     *                              *                         ***                                   *   *     *                  * *                                                                        * *         *                  *     * *                                  **                                    **             *  *                       * *  *           **          **           *  * *                     *     *     **        **               **                      **               **        **         **               **        **                                                                                         *                                                                 *     *   *     *                                                                                                                                **       *                *                  **                                                                                                                                                                                                                  ***    *  *                                                                *           *                              *   ***   *                   *   ***   *                                                                      *          ***                                       *   *                                                                                         *    *                                    *    *                                                                                                                              * *                       * *                                                                                                                                                                                                                                                                                                       ***        ** *  *  *  *          *  *    *
       *              *                **           **      **                                                                            **                                      **            *                                                                                                                                                                                                  **                    **                                       * *           * *                  * *              *              *  *                      **              **                   ****                                        * **   ** *                       **    *          **        **           **                *   * *  **** *  *                 **                                 * *  * *                                                                                                                                                                                            ****                           ****                  ****                           *                                       *   *     *                  *                                                                         *                                      *                                   *                                   *  *            * * *                      *  *                                        *  *                    **    **                *                                                        *                                     *                                                        *    *                                     * *   ***            ***                           *              **    **  **    **                                                                                                                                 *      **           **  *    *          ** *  * **                                                                                                                                                                                                                      **                                                                 **         **                             *  *******  *                 *  *******  *                                                                     *           *                                        *   *                                                                                        *  *        *   *                *   *        *  *                                                                                                                             *                           *                                                                                                                                                                                                                                                                                                        *         **  **      *         **     **
      *                                                                                                                               ** *                                                     **                                                                               **                                                                                                                                   * **                                         * *           * **                  **                              **                        *              **                                           **                  ** *   * **                         ****            *    ** *             **                 ***  * *     **                   *            **                  **** ** ****                                                                             **                                             *****  ***                             ** *      ** *         *  *                           *  *                  *  *                           **                                     **  **    **                                                                                           **                                      **            ** *      ** *        * *                                * * *             *  *                       **                                          **                 **    ** *                                                                                                                                                                        ***    ***                                    *    * *            * *     ***            ***   * *               ** *      ** *                                                                                                                                  *         ** *       ** *  * **          **  *    *                                                                                                                                                                                              **            *     *                                                                         ** * **                                **         **                 **         **                                                                     *           *                                                                                                                                  *  * **          *                    *          ** *  *                                                                                                                         **                           **                                                                                                                                                                                                                                                                                                                          * *        **   *        **
      **                                                                                                                              * **                                                                                                                                      **                                                                                                                                   ** *                                          *           ** *                                                                            *                                      **                    **                                                      *              *     * **             **                   * *  *   *  * *                               *               * *    *  *    * *                                             **                           *                                             *          *                            * **      * **                                                                                                                                ** *      ** *                                                                      **                                                                           * **      * **         **                                *  *                  *                             ***                          ***                        **    * **                                                                                                                                                                       *          *                                        ***            ***     * *            * *    *                * **      * **                                                                                                                                  **        * **           **                   *                                                                                                                                                                                                 *  *           *     *                                                                    *** ***   *** ***                                                                                                                                           *           *                                         ***                                                                                     * * *     *                                    *     * * *                                                                                                                                                                                                                                                                        *     *                                                    *     *                                                                                                                                       **           **          **
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  *                                                                            **                                     **                                                                             *             **  **             **                         ** *   * *  ***                    **                       ** ** *    * ** **                                              *                         * *                                             **   * *  **                                **  **                           **   **                                              **   **                                             * **      * **                                                                      * *                                                                              **  **                  ***                         *                   * *                              * *                          * *                                                                                                                                                                                                         **        **                                                               ***            ***                                                                                                                                                                                                                    * *                                                                                                                                                                                            *  * *           *     *                                                                   *  **  * * *  **  *                     *                                                   *                                                               ***          *                                                                                                                                  *  *    * *                                  * *    *  *                                                                                                                                **             **                                                                                                                       ***   ***                                                  ***   ***                                                                                                                                           *        *  *
             **      **        **         *        **   **       *      **     *                                                                                                                                                                                                                                                                                                                                                                                                  **                                                                                                                                                                                                **                 *             * *    **                 *  * * **  * *   *              ** *    * **                     * *      * *                                                 * *                       **                                          *       *  *                                    *   *             *    ***        *   *        ***    *                *    ***        *   *        ***                                                                                                                         *                                                                              *   *                   * *                          * *                                                 ***                          ***                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    **                                                **                     *                                                                                      **    *** ***    **                   * *                                                   * *                                                                         ***                                                                                                                                    **  *  *                                  *  *  **                                                                                                                                   **             **                                                                                                                      *   * *   *                                                 * ** ** *                                                                                                                  *                      **          * *
             * *     * *       * *       * *      * *   * *     * *     * *   * *       *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          **   *            *      *                  **  *      * ** **              *          *                  ** * *      * * **                                               **             * *  * *                                             * *               **  ** **                       *   *           * *   * *     *         *     * *   * *              * *   * *     *         *     * *   **                                                                                                                    **                                                                              *   *                  ***                                                                                                                                                                                                                                                                                                                     *              *                                                                                                                                                                                                                                                                                                                                                                                                  **    ** *      ** *        *                                                *                  * **               ***                                                                                                            * *                                                 * *                                                                                                                                                                                                                      **                                    **                                                                                                                                                                                                                                                                               *         *                                                   ** **                                                                                                                      **                    **
              * *       *         *      * *      *      * *    ** *      *    * *   * * *                                                                                                                                                                                                                                                                                          *               *                                                                                                                                                                                                                                                                                               *  **           **       ***                    ** ***                      **      **                   ** *          * **                                                   * *  * *  *  *  *  *                                             *      **        * *  * * *                     **  **           * *   ***     **       **     ***   * *              * *   ***     **       **     ***   **                                                                                                                                                                                                   **  **                                                             ***      ***                                                                                                                                                                                                                                                                 *              *                                      ***            ***                                                                                                                                                                                                                                                                                                                                           *    * **      * **        * *                     **                     * *                   *     *                                                                                        *  * *  *                         *                                                     *                                                              ***                                                                                                                                             **                                                    **                                                                                                                     *   **                           **                                                                                                                ***   ***                                                    ** **                                                                                                                     ***
               * *       * *       *    ** **   * *        *       *     *       *   **  *                                                                                                                                                                                                                                                                                          *               *                                                                                                                                                                                                                                                                                              *     ** *                  *                     **                      ***  ******  ***                   * * **** * *                                                     *  *  *  *  * *  * *                                                     ** **       * *    *                 ** *      ** *        *                                   *                *                                                                                                                                                                                                                                   ** *      ** *                                       ***      ***      * *                                                                                                                                                                                                **                                                                        *      **      *                                 *    * *            * *     ***            ***                                                                                                                                                                                                                                                                                                                   *   **    **  **    **       **        *            **            **       **                          *        *                                                                              *   ***   *                                                                                                                                              *          ***                                                                                                                            **  *  *                                                  *  *  **                                                                                                               * *   *                           *                                                                                                                                                                              ** **                                                                                                                     **
                *         **        *           **         **      **   *       *        **                                                                                                                                                                                                                                                                     **                 ***             ***                                               *               *                                                *    *         **                                                                                                                                                            **    * **                                      *    **                   *  *        *  *                   * *      * *                                                      * *  * *             **                                        *****     * ** *    ** ***  **                * **      * **                                                                                                                                                                                                                                                                                                 * **      * **                                                * *      ***     *   *                                    **      **                                                                                                                                         *                                            **    **  * **                     **                                       * *   ***            ***     * *            * *    *                                          **                      **                      **                      **                       **                                                                                                                                                                 **  *     *   *     *                 **                          * *                     ** **        *        *                                                                             *  *******  *                                                                                                                                             *           *                                                                                                                             * *  * *                        **                        * *  * *                    **                                                                                          *    * *                       * *                                                                                                                                                                                                                                                                                                         *
                                   **                                   **      **                                                                                                                                                                                                                       *                   **               **                **                                                                   *              * *             * *             **            **     *           * *  * *         *                                                                                                                                                                                                            ** ** *                    **          **                   ** * **** * **                      **    ** *                 **                       * *                                      *    *        *  *  **     * *               **        **    **      *                                   *                *                                      **                                                                                                                                                                                               **  **    **                                    *   *     ***              *   *                                   *  *    *  *                                                                                 **                                                     * *                                           *     *  ** *                                                               *                           ***            ***   * *                                       *    *                  *    *                  *    *                  *    *                   *    *                                                                                                                                                                    *     *   *     *               **                             *                     *                     *                                                                             **         **                  **                                                             **                                                                      *                                                                                                                               ** * **                       **                       ** * **                  **  *                                                                                                 **        *     *        **                                                                                                                                                                                                                                                                                                         * *
                                                                                                                                                                                                                                                                                           **            ***                 **               **                                                                                    * *             * *              *              *             *  *  * *       *  **    * *        * *                                                                                                                                                                                                              *                                                       *  ***  ***  *                       *    * **                * *                         *                                     *  **        * *      * * * * * *             *         *     *      * *   ***     **       **     ***   * *              * *   ***     **       **     ***       **     **                                                                                                                                                                                        *   *     *          ***                        *   *                                                              *  *    *  *                                                                                * *               **                                     **                                          *     *       **      *                          *                                                                             *                                       *      *                *      *                *      *                *      *                 *      *                                                                                                                                                              **  **    **  **    **                **  **                      ***                      **  *   ***   ***                         ** **                                                                                   **                                                             **                                                                                                                              *  **    **  *                                                         *   **   *                                            *   **   *                *  * *                                                                                         *****            ***   ***                                                                                                                                                                   **                                                                                                                                              **
                                                                                                                                                                                                                                                                                            *               *                                                   ****                                                                **             ** **                         ** *              ***   * *      ***   *   *          **    **                                                                                                                                                                                                        * *                                                       *  ****  *                        *   **    **              *                           **                                 *  * *               **  *  ** *******            *         *     *     * *   * *     *         *     * *   * *              * *   * *     *         *     * *              *                                                                                                                                                                                          *   *     *         * *                                                   *   *                          ***      *  *    *  *      ***                                                                       *                 **                                                                                 **    **       *     * *   ***            ***   * *                                       **                                                                          *        *              *        *              *        *              *        *               *        *                                                                                                                                                              *  *     *   *     *                                                                       ***             ***   ***       *            *                                                                     *                                                                                                                                                                                                           *   ***  ***   *                         ** *    ** *      ** *        * **  **                                                  **  ** *           ** * *** **                                                                                       *    *      ***  ** ** ** **  ***                                                                                                                       ** **                                 * *                                                                                                                                                           * *
                                                                                                                                                                                                                                                                                            * *            *                 ****             ****             *    *             *****           *****                           **             *       *         *****         *  ** *                  *          ****                     *                                                                                                                                                                                                         **                                                      ** *    * **                       **  *     *              **                                                             * * * *   *    *  * * *  * * *         *          **        **    **      *    ***        *   *        ***    *                *    ***        *   *        ***            * *                                                                                                                                                                                         **  **    **         ***                        *   *                     * *** *                         * *       **      **       * *                                                           *           ***                                                                                                    * **        *       *    * *            * *    *                                 *      **      *              **                                                   *        *              *        *              *        *              *        *               *        *                                                                                                                                                             *    *     *   *     *                                                                      ***        *                    *       *  **                                                                      * *                                                                                                                                                                                                          *  **    **  *                          * **    * **      * **        * *  * *   *                                          *   * *  * *           * ** * * *                                                                                       *  *               ***   ***                                                                                                                              * *                                   **                                                                                                                                                           **
             **       *       **         **        **   **    **       **   **      *      **      **    **       **                                                                                                                                                                         * *           *  *             * *  * **        * *  * **        * * ** * **        * *** *         * *** *                         *   ***         ***   ***        *  *  *         **    *          ****             *    **               ****                                                                                             *  *                                                                                                                                                                 *  *    *  *                            *     *                            **                                        **     *  *      * * *          ** * **** ***             ** *      ** *                       **   **                                              **   **                      **                                                                                                                                                                                      ** *      ** *                 **                  * *** *                    *     *                         ***                        ***                                          **               **                                                                                                                 ** *        **           ***            ***                                      *              *       *      **      *                                            *        *              *        *              *        *              *        *               *        *                                                      *                                                                                                      **  **    **  **    **                                                                     **  *       *        *           *        ***                                                                      * *                                   ***             ***                                                                    *    *                                                                                                                       **      **  **    **       ***  **                                                  **  ***                       *                                                                                  *  * **                *     *                                                                                                                           ** ** ** **                                                       ***                                                                                                              ** * **              *
             * *     * *      * *        * *       *    *     *       * *   * *    * *     * *     * *   * *      * *                                                                                                                                                                          ** **          *             *  * * **        *  * * **        * *    * **        * * * *         * * * *                        *  **   * *                      * ** ** *          * *            *   *             **  *  *             *                                                                                                ****                         **       **                                                                                                                              *  *  *  *                        **  **    **                        **  **                                     **  *        **  * *   **           * **    **               * **      * **                                                                                              ***   ***        **                                                                                                                                                                                * **      * **                 * *                 *     *                   ** * * **                 **                                        **                                   **                **                                                                         *       **                                 **    **                                                                     *              *       *              *                                             *      *                *      *                *      *                *      *                 *      *                                                       *                                                                                                          *     *   *     *                 **  **                      ***                     *            *        *                    ***                                                                        *                                   *  **         **  *                                       **    * **      ** *       ** **** **                         *    *                                                                                      *       *   *     *            **   *                  * *  * *                  *   **                 **** * *** *                                                                                * * *     *                                                                                                                                               *  *   * *           **                                           ***
              * *     * *        *          *       *    *      *     *      * *    * *      *       *     *        *                                                                                                                 **               **                                         **        * *          ** **   *        ** *  * *        ** *    * *          ** * * **       **     **                        **    * **      *********       * *   * *          *   *  *        *  * **            * * * *         *   ***                                                                                                                          **       **                                                                                                                               **    **                          *    ** *                         **                                           * *              *               * *    **                                         *  *                           *  *                  *  *                            * *   * *        *                                                                                                                                                                                                                  *                ** * * **                 *  ** **  *               *  *                                      *  *                                               **  **                                                                         **      *  *            **                   *     *                                                                                            *              *                                              *    *                  *    *                  *    *                  *    *                   *    *                                                       ***                                                                                                     **   *     *   *     *               **                             *                     ** **                 *       ***   ***   *  **                                         *                                               **                **  *         *  **                **                      *    ** *      * **         *    *                         ** **** **                                                                                     *       *   *     *     ***** * **                     **  **                     ** * *****          *   ** **   *                                                                                 *  *    * *                                                                                                                                              *       *             *                                                                                                                                                            *     *      *
               * *     * *        *          *     **   **     **      *       *      *     *       *      * *      * **                                                  **           *             **            *       *           *               * *                                  **              **  **       ** *    *        ** *    *        ** * ** * *         *  ** **  *      *  * *  *                          * * *         *       *      ** *   * **          ** ****         * * *             * * **          ****  *                                   **                     **                               ********                                                                                                                                                                                                  *     * **                          *                                           * **  **                         **  ** *                                          ****                           ****                  ****                            ***   ***          *                                                                                                                                                                                                                **              *  ** **  *                **       **               * *  *           **        **           *  * *                                                               ***                                                            * *     *  **           **                  *     *                                                                         *              *                                                                    **                      **                      **                      **                       **                                                                                                                                                                  *  **    **  **    **                **                          * *                                                                    *                                        ***                                              *                  ***         ***                  *                      *   **        **    **                                        *    *                                                                                      **      **  **    **     *  *  * *                      *    *                      * *  *  *           *** *** ***                                                                                     **  *  *           *       *                                                                                                                          *  *                  * *                                        ** **                                                                                                                           **
                **      * *        * *        *    *    *      *     * *      *      *     *     * *        * *      * *                                              ** * *          * * **       *  *            ***   ***         *                   *                                   *                  * *          ****             ****             *    *          **       **       ** * **                           *   *            ****        *  * * *  *            *              ** * *            * *               *                                     *  *                     *  *  *    **                  *        *                      ****   ****                                                                                                                                                                **  **    **                   **                                              **    * *         *    **              * *                                                *                     *                              *                                        *****                                                                                                                                                                                                                                **       **                                           *              * *        * *              *                                                                *                 **                                                   *  *                                **    **             ***            ***                                         *              *       *              *                                                                                                                                                                                                                                                                                                                 *     ** *      ** *         **        *            **            **       **                                               *        ** **                                           *                              **          ***                                                     ***                   **   *        *     *                              *                                                                                                  ** *    ** *    *     *           ** *  *                                            *  * **                  *     *                                                                                            **           * *     * *                                                                                                                          **                    **                                        *   *                                                                                                              ** **       **
                         *          **         *    *     *      *   **       **    *     *      **          *                                       *                ** *            * ** *       ** * **            * *           * ****        ** **** **                              ***                     *                                             ****                              * * *                             ***             *  **         *     *              * *                **              *              *                                       * *                   *    ******  *                  * ***   ** *                    *    * *    *                                                                                                                                                                   *     *                    **                                           **    ** *            *  *  *  **        *  **                                           *****                     *****                      *****                                        *                                                                                                                                                                                                                                                                                           ** *        ***            ***        * **                                                                 * *               **                                  **                 *                                     **          *    * *            * *    *                                    *      **      *       *              *                                            *                         *                     *                         *                        *                                                         ***                                                                                                     **    * **      * **        * *                     **                     * *                                              *                                                       **                              **          *                                                         *                       *          *     *                              *                                                                                                 * **    * **     *     *           * * * *                                          * * * *                                                                                                        *    *                      *       *                                                                                                                                                                                            ***                                                                                                                 *
                                              **   **    **     **                  **    **                                                         ***   * ***         *          **              * *  *         **** ****        *    *        ** *    * *                             *                       **           **               **                                              *  * *  *                             * *                          *****                **                                **             **                                   *** * **                * ****      * *                  * *      * *                   * *  ** **  * *                                                                                                                                                              **   *     *                                  **                          *** **** * *    **    ***  * *    *  *     **                                              *    **    ***   ***    **    *                      *          ***   ***                            ****                                                                                                                                                                                                                                                                                       *     ** *   *          *   * **     *                                                   **  **           **                                    **            *  *                                                       *         * *   ***            ***   * *                                          **              *      **      *                                           *  *                      *  *                  *  *                      *  *                     *  *                 * **      * **                         *                                                                                                                                  *                                                *                                              *   * *                                                                                                                                                                           **  **        **    **                            ***                                                               **                              **            **  **    **         *   * * *            *       **       *            * * *   *                  *   *                                                                             ***    ***                                                                                                                                                                                                                   **     *
                                                                                                                                                    * *   * *            *  *        * * **         *    * **      *  * *  *       ** *              * *  * *                                                                  **               **                **                            ** * * **                              **                            *                                                                                                       *    * * *               * *  *  * *** * **            ** * *        * **             *  * *         * *  *                                                                                                                                                            *  **    **     **                           *                          *       * * *  * ***         *     * * *                                                     **  *     * *   * *     *  **                         *        * *   * *                            *  *                                                                                                                                                                                                                                                                                           *     * **          ** *     *                                          **                **                                                **           **  *                *                                 **  *           *                          *                                                                  **                                                  *  *                      *  *                  *  *                      *  *                     *  *                 ** *      ** *                         *                                                                                                                                 **                                                **                                                    *                                                                                                                                                                           *    * **    *     *                    **            **                                                         * * *                             *             *   *     *          ***** * **            **     **     **            ** * *****                    *                                                                              *          *                                                                                                                                                                                                                  **
                                                                                                                                                 *** *   ***              ** *       * *  *          *** * **        ** **          * * ****         * *    * **                                                                                                  **                               * *                                                                                                                                                                       *  ***   *            ** * * * *  *  * * **             * *          * *             * * * *  ** **  * * * *                                                                                                                                                          *     ** *        *                         * *                           ******  ** * *      *          ** *  *                                                        * *     ***   ***     * *                          **        ***   ***                                                                              *                                                                                                                                                                                                                                            *     *                *     *                                          **               **                                                               *  *              *  *                                **  **                                                                    *                                                                                         *                         *                     *                         *                        *                      **  **                             *                                                                                                                                                                                                                                     *  *                                                         ***                                                                                                               *     ** *     *     *                   **            **                                                       * * *                                *             *   *     *               **   *         **              **         *   **                                                                                                         **        **                                                     *    *                                                                                                                                                                                                                                                                                                                 *
                                                                                                                                                           *                 *        *  *              *             * *         * * *    *          ** **** **                                                                                                                                   * *                                                                                                                                                                    ** *     ***             *  ****   * * ** *                * *          * *              *  * *         * *  *                                      ** *                     * **                                                                                        **    * **        * *                       **                              * * ****       **   *        *  *                                                           * * **             ** * *                                **                      **   **                                                           * *                                 * *                                                                                                                                                                                                       *     * **          ** *     *                                                           *                                                                 *                *  **           **                                               **                                          * *   ***            ***                           *                                                                                                                                                                  *   *                             *                                                                                                                                                                                                                     *              * * *                                                       **  *                                                                                                               **        **  **    **                            ***                                                            **                                 **            **  **    **           ***  **                                          **  ***                    * *   * *                                                                                                                                       ***    ***                                                                                                                                                                                                                                                                                                             ***
                       *                **                                           **      **      *                                                                       **        **              *            * * * *       **   ***              *                                                                                                                                           *                                                                                                                                                                      *  ** * *                 *    **** * *  *               ** *        * * **                * *  ** **  * *                                             *   *           *   *                                                                                                               **             * *  * *                                    * *      **  ****       *    *                                                             ** *               * **                                * *            ***        *   *        ***    *                                **         *   **   **                          *   *                                                                                                                                                                                                       ** *   *          *   * **                                                                                                                                                *  *            **                                        *      **      *                                    *    * *            * *     ***            ***   * *                                     **                       **                       **                       **                        **                    *   *                             ***                                                                                                                                                                                                                    *              *  *                                             **         *  **                **                                                                                                        *  *     *                               *                                                                                                 ** *    ** *      ** *            * *  * *   *                                  *   * *  * *                     *   *        * *  **                                                         *              *                                                *          *                                                                                                                                        **                                                                                                                                    **               * *         *
              **      * *        *       *       **                    *      **     **     *  *    * *                                                                                                **           **   **              **             * *                                                                                                                                                                                                                                                                                                                *    **                    ****    ** * *                   * *      * *                    *    * *    *                                          *       **         **       *                                                                                                               * *  * *  *  *  *  *                                  **  *** *          *     *****                                                                 *               *                                   *              * *     *         *     * *   * *                               **         *   **   **                              *                                                                                                                                                                                                           ***            ***                                                                                 *                                                 *                 **                                                       *              *                                         ***            ***     * *            * *    *                                    *    *                   *    *                   *    *                   *    *                    *    *                  **  **                                                                                                                                                                                                                                                  * *              **                   **    ** *    **    **     **         ***                  *                *                                                         *                   **        *    *     *                             *                                                                                                  * **    * **      * **            * **  **                                          **  ** *                 *           *   *   * ***    **                                                  *              *                                                **        **                                                                                                                                        **                                                                                                                                    **                **         **
             *  *      * *      * *      * *     *  *         *       * *    *  *           * * *    **                                                                                                                                                  **                                                                                                                                                                                                                                                                                                                 ***   *                     *  **     *                    * **   *** *                     ****   ****                                            ** **  *           *  ** **                                                                                                               *  *  *  *  * *  * *                                    *    * *      *                                                                               **   **   **   **                                  **     **       ***     **       **     ***   * *                                          *   **                     **        *    *                                                                                                                                                                                                            * *        * *                                                                                    **                                              *  *                                                                        *              *                                                                ***            ***                                        *      *                 *      *                 *      *                 *      *                  *      *               **      * **                                                                                                                                                                                                                                       **                                            *    * **     *     *                                      ***             ***                                                     ***                    *        **  **    **                                        *    *                                                                                                                     *   **   *                                    *   **   *                 *   *     *   *   *      **   **                                                  *      **      *                                                                                                                                                         **                                                                                                                                                                                                 *
              ** *      * *    * * *      * *     ** *       * *     *  *     * *    ****    * *       **                                                                                                                                                                                                                                                                                                                           *  *                                                                         **                                                           ** **                       ** *****                      *        *                                                                                 *  ** **   ** **  *                                                                                                                    * *  * *             **                                * * *  * *     * **       *                                                                       *  * *  *                                             **                                      *                                            * *                       **            *                                                                                                                                                                                                              **        **                                                                                    **                                 **           **  *     * *                                                                                                                                                                                                         *        *               *        *               *        *               *        *                *        *               *      ** *                        ***                                                                                                                                                                                                           *  *                                          *         **  *     *                                         *                *                  ***         ***                  *                      *     * **      ** *         *    *                         ** **** **                                                                                                                    ** * **                                        ** * **                   *           *     ***** *                                                               **                                                     *              *                                                                                           **
                 *        *     *  *        *        *    * *  *    *   **   ** **   *  *     *        * *                                                                                                                                                                                                                                                                                                                                            *              **      **                   **             **                                                                                            *                         ********                       **       **                                               **       * *       **                                                                                                               **                       * *                                ** **  **       *       * *                                                                       **   **                                                                                                                                    *                                  *   *   **                                   *  * ** *  *           *  * ** *  *                                                                                                                                                                                                                                                                      **            *  *      **                                                                  **        **                                                                                                                           *        *               *        *               *        *               *        *                *        *              *           **                       *                                                                                                                                                                                                            * * *                                         **        *   **    **          *                                             **                **  *         *  **                **                     **    ** *      * **       ** **** **                         *    *                                                                                                                    * *  * *                                          * *  * *                     *   *            ***                                                                                                                       *              *
                 **       **       **       **       **   **   **   **                                  *                                                                                                                                                                                                                                                                                                                          *    *           *   *           * *      * *          **     * *                                   **                                                                                                                               **       **                                                *   *         *   *                                                                                                               * *                         *                                                         *                                                                                                                                                                     *                                                   *                            * *    *  *                                  **** ** ****           **** ** ****                                                                                                                                                                                                                                                                                     **       *                                                                   *          *                                           ***            ***                                                              *        *               *        *               *        *               *        *                *        *              **           *        ****           *                                                                                                                                                                                                             * ***                                                   *    * **            * *                                                             *  **         **  *                                                                    *    *                                                                                                                                                     **  *  *                                          *  *  **                   * *   * *                                ** *      ** *      ** *        *     *              *     *                                        *      **      *                 **    **    ** *      ** *                                                                                                                                             *
                                                                                                                                                                                                                                                                                               **                                                                     **            *                                            *** ** ***                         *          *          * *    *                                    *  *                                                                                                 ****                                                                                         * ** ** *                                                                                                                    *                           **                                         **  *  *  **                                                                                                                                     **   ***     **       **     ***   * *                                                  *                                   * *      * *                          *  * ** *  *   ** **   *  * ** *  *                                                                                                                                                                                                                                        **                                                                                                                         ***    ***                                       *    * *            * *     ***            ***                                        *      *                 *      *                 *      *                 *      *                  *      *             **            *        ******                                                                                                                                                                                                                          ***                                        **        **    ** *           * *                                                              ***             ***                                                                                                                                                  *  **    **  *                                                                    **                                            **                                           ***                   * **      * **      * **       * *   ***            ***   * *                                              **                         *     *    * **      * **                                                                                                                                  **        **               **
                                                                                                                                                                                                                                                                                              * *                                                 **                  *            * *                                          *   *  *   *       *     *       ** *          * **         *   ** *             ***  **             *  *                                                                                                  *  *                                                                                                                                                                                                                     **                                                                      *  **** *  *                                                                                                                                     **   * *     *         *     * *   * *                                                  *                                    *       *   *                                       ** **                                                                                                                                                                                                                                                       * *                                                                                                                          *    *                                        * *   ***            ***     * *            * *    *                                    *    *                   *    *                   *    *                   *    *                    *    *               *            **      ********                                                                                                                                                                                                                                                                     *    ** *          **           *                                                                                                                                                                                                                                  *   ***  ***   *                                                                           **             **             **                                                ***** *                      **  **    **        **      *   ** **          ** **   *                                                                         *     *   **        **    **                                                                                                                                **       **                **
                                                                                                                                                                                                                                                                                           *  *                                 **               * *                   *            *              *                             ****  ****      *** *** ***     ** * *  **  * * **       * **     ***       ** *      *            * ** ***                                                                                                                                                                                                                                                                                                                                                                                                 ***   ****                                                                                                                                           ***        *   *        ***    *                                        *                                                           *     **                                                                                                                                                                                                                                                                                              *                                                        **                                                                                                               *                           ***            ***   * *                                     **                       **                       **                       **                        **                *         * **       **      **                                                                                                                                                                                                                              *  *                                 *     * **           *                     ***                                                                                                                                                                                                                       *  **    **  *                                                                       **  *  *            **            *  *  **                           **             *      **                     *   *     *         *            ***            ***                                       *     *              *     *           **    **  *         *     *                                                                                                                                           **  **                                                                                                **
             **           **      **        **     **       **                                      **                                                                                                                                                                                    * * *                 *              *  *              *                    **                         *****                                          *   ** **   *       * * *  * * *        ***     * *   *    *  * *    * * **      *  *    *  * *                                                                                                                                                                     * *                                                     *                                                                                                                                                                    *                                                                                                                                                          **   **                                                      * *                                                      *    *    **                                                                                                                                                                                                                                                                                              **                                                       * *                                                                                                                                                                *                                                                                                                                                             **        ** *        ********                                                                                                                                                                                                                             *  **  *                               **  **              *                 ** ******* **                      **                                                             **                                                                      *                                                                                                                                      *  *    * *                          * *    *  *                        **            *   * ***                       *   *     *         *            *              *                                       * *   ***            ***   * *            * **     *         *     *                                                                                                                                                                                                                                                *
             * *         *  *    *  *      *  *   *  *      * *      ** **   **     **    *   *     **        *   *                                                                                                                                                                        *  *               *****  **       * *  *  **      ** *                 **   **        *****       * *     * *                        ** *  * **     * *** * ****        * * *  * * *       *   * *     ***     ** * *    * *  *     * * *   ** * **                                                                                                                                                                     *  *                 *** ***                           **                                                                                                                                                               * **  **** * **                                                                                                                                                                                                            **   *                                                         *                                                                                                                                                                                                                                                                                                                                                                *                                                                                                                           **                                                                                                                                                                                                                        ******                                                                                                                                                                                                                              *  **  *                                   *               **                *   * * *   *                      **                                                             **                                                          *           *                                                                                                                                     * * *     *                            *     * * *                                      * *  **                       **  **    **        **                                                                    *   ** **          ** **   *             ** *    **        **    **                                                                                                                                                                                                                                                 ***
              **         * *     * **      * **   *  *       **       * *    *       *   * * * *             * * * *                                                                                                                                                                          * **  **     * *     *  *      *  *   *  *      ** *  *  **         *  ***  *      *     *      ** * * * **                        *        *      *               ** * *  **  * * **     ***     ** *          *      * **        *  *    * *                                                                                                                                                                           *                                                    *                                                                                                                                                               ** * **  * ** *                                                                                                                                     **                           *  *                                 **   **   *         **                                          *   *                                                                                                                                                                                                                                                                                                                                                                **                                                                                                                   *      **      *              **                                                                                                                                                                                                  ****                                                                                                                                                                                                                                 ****                                 **   *                                 ****   ****                                                                                                                                                  *          ***                                                                                                                                     *  * **          *            *          ** *  *                                                                 ** *      ** *      ** *              *              *                                             ***            ***                      **    ** *    *     *                       **                                                                                                                                                                                                                           *
                **     ** *     ** *    ** *       ** **       **     * *     *** ***    * * * *    ****     * * * *                                                                                                                                                                           *  *  *     ** *  *** *       **  ******          * * *  *         *     **      * *   * *        *   *                            ***  ***         * * * ** *    ** *          * **       * **   *            **  ***               * **** *                                                                                                                                                                        *                     *   *                         ** *                  ***                 * ** ** *                                                                                                                    *    *                                                                                                                                            *                           ****                                 **   **   *         **                                          * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       *              *       *      **      *                                                                                                                                                                                                                                                                                                                                                                                                                              * *  * *                                *  **                                   *     *                                                                                                                                                   ***                                                                                                                                                    *  *        *   *   **   *   *        *  *                                                                    * **      * **      * **             ***            ***                                             *              *                        *    * **     *     *     **               * *                                                                                                                 **  **
                * *   *  *      *  *    *  *         *  *      * *   ** **      * *       ** **    *    *   ** * * **                                                                                                                                                                           *****         * *  * **                          *  ****           *   *         *     *         * * *                              *  *          ** *** * **       *          *            *    * *                                 *    *                                                                                                                                                                          * * *                *   *                        *    *                  **                 ** * * **                                                                                                                 **  *** * ****                                                                                                                                    ***                         *                                              * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                *              *       *              *                                                                                                                                                                                                                  *  *    *  *                                                                                                                                                                                                **    **                               *     ** *          **                   *     *                              *                                                     *                                                                                                                                                                                                                      *    *             **             *    *                                                                   **        **    **  **            *   ** **          ** **   *                                                                               *   **    **  **    **     **                 *                                                                                                                **                **                        ** *    * **      ** *      ** *
                 **   * *        **      **          *  *       *                *                 **  **       *                                                                                                                                                                                             *  **                **           **            ** * *   *          *****           * *                           **** ** ****       * *  *           * *      * *          * *     **                                  ***                                                                                                                                                                              ****              *** ***                           *                  **                                                                                                                                            *     * * *  *                                                                                                                                    *                           *****                                           *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        *              *                                                                                                                              **                                                                             *  ***  ******  ***                                                                                                                                                                                                                                     **    * **          **             **   **     **   **                        * *                                                 * *                                                                          ***                                                                                                                                          *****    *     *      *     *    *****                                                                    *         *     *   *            * *   ***            ***   * *                                       *              *                       **  *     *   *     *                       ***                                                                                                                 **               **                        * **    ** *      * **      * **
                       *                              **                                                                                                                                                                                                                                          *          **                    **               **        * ** * **                            *                            *  *    *  *       *  **             **      **           **                       **                   **                                                                                                                                                                                                                             **                      *                  ***   ***                                                                                                                  ****** *                                                                                                                                                **    ***   ***    **    *                                                                                                                                                                                                                                                                                                                                                                                                                                  **     **                                                                                                                                                    **        **                                                                                          *                                                          *  *                                                                              *   *  *    *  *                                                                                                                                                                                                                                                                          *  ***** * *****  *                       * *                                                   * *                                                             ***          *                                                                                                                                                  *** *** ******** *** ***                                                                            *         *     *   *            *     *              *     *                                       ***            ***                           *     *   *     *                                                                                                                                           *                                             **      **  **    **  **    **
                                                                                                                                                                                                                                                                                                 * *                                                **            * *               *                                                             **                                                               **                                                                                                                                                                                                                                                      **              **                     *  * *  *                                                                                                                    *  *  *                                                                                                                                               *     * *   * *     *  **                                                                                                                                                                                                                                                                                                                                                                                                                                   **     **                                                                                                                                                    *          *           **        **                                                                  * *                                                        *               * *                                                              ***                                                                                                                                                                                                                                                                                          ***    ***    ***                          *                                                   *                                                                *           *                                                                             ***                                                             *   *   ** **        ** **   *   *                                                                      **        **    **  **                                                                          *   ** **          ** **   *                     **    **  **    **                                                                                                                                                                                         *        *  *     *   *     *
                                                                                                                                                                                                                                                       * *                                        *                                                               * *              * *                                              *  *                                                                                                                                                                                                                                                                             ****                 *   *                         *                   * **                    ** **                                                                                                                        ** **                                                                                                                                            ** *     ***   ***     * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   ***    ***            *          *                                                        **       * **                                            *           *          ***  *   *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         *           *                                                                                                                                            * *  * *** * ****  **** * *** *  * *                                                                       ** *      ** *      ** *                     **                                              * *   ***            ***   * *                **    ** *      ** *                                                                                                                                                                                            *      *    *     *   *     *
                                                                                                                                                     * **              *                *                **                                            ** *                                                                                                        *                *                                                                                                                                                                                                                                                                                                                                 * * *              * * * *                       *    *                 *                                                                                                                                                   * *                                                                                                                                             *  * **             ** * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     *    *               ***    ***                                                        * *      ** **          **                              * *           *                   *                                                                                                                                                                                                                                                                                                                                                           **         **                                 **         **                 **         **                                                                     *           *                                                                            *   *                                                            *    *         *  *         *    *                                                                        * **      * **      * **              *      **      *                                        *     *              *     *                 **    * **      * **                        ***                                                                                                                                                                **      **  **    **  **    **
                                                                                                                                                     ** *             * *              * *               **                           ** *                ***                                                                                                                                                                                                                                                                                                                                                                                                                                                              *             * * * *                        * **                  *           **   **           **   **                                                                                                               * *                                                                                                                                               ** *               * **                                                                                                                                                                                                                                                                                            **       **                                                                                                                                                                                                                                                                                                                      *    *                                                         *      *** * **          **                    **      **               *  *  **       *    *    **                                                                                                                                                                                         *                                                                                                                                                          *           *                                 *  *******  *                 *  *******  *                                                                     *          ***                                                                           *   *                                                                   * * * *      * * * *                                                                                                                     *              *                                                                                                                **                 *       **                                                                                                                                                   ** *      **    *     *   *     *
                        **         *                           **                         **    *                                                                     * *              * *                               *            * **             **    *                                                                                                                                                                                                                                                                                                                                                                                                                                                          *      *   *   **  * *  **   *   *     *   *   *                                  **  *  * **   ** *  *  **                                                                                                                *                                                                                                                                                   *               *                                                                                                                                                                                                                                                                                               *  ** **  *                **       **                                                                                                                                                                                                                                                                                                                                                 **       *  *  *  *  * *                               *   *    **                 **  *  * *       *     **                                                                                                                                                          **    ** *      * **          * *                                                                                                                                                          *         *                                   *   ***   *                   *   ***   *                                                                     ***                                                                                                                                                              ** *** **    ** *** **                                                                                                                    *              *                                                     **                                                         **               * *       **                                                                                                                                                   * **       *     *     *   *     *
             **   **   *  *      ***          **    **   **   *  *      **         *       *  ***                                                    ***  **         ** **            ** **            ****             * *        ** *            ** *  **  *                                                                                                                                                                                                                                                                                                                                                                                                                                                          *  *   * ***  *    * *    *  *** *     * ***   **                                     * *  **   **  * *                                                                                                                                                                                                                                                                        **   **   **   **                                                                                                                                                                                                                                                                                                ** * * **                 *  ** **  *                                       **              ***        **                                                                                                                                                                                                                                                                             **       *      **    *                               *     *   **                      ***     *   *                                                                                                                                                                  *    * **      ** *          * *      *  *    *  *                                                                                                                                       **         **                                   *  * *  *                     *  * *  *                                                                                                                                                                 ***                                                                    * *  *  *  *  *  * *                                                                                                                                                                                   *      **      *                                                                   **                                                                                                                                                           **          *     **    **  **    **
             * * * *    **      *   **    **  * *   * * * *   ****     *  *      *****     * *                                                      *   *  *      * *     * *      * *     * *      * *    *           * * *        * * ****        * *    * **                                                                                                                                                                        *                                                                                               **    **                                                                                                                                                                          * *   *   *   ****   ****   *   *     *   *   *              **   **                  *             *                                                                                                                                                                                                                                                                             *  * *  *                                                                                                                                                                                                                  **                **              **                **                             * * * *                   ** * * **                                        **            *   *        **                                                                                                                                                                                                                                                                                       * *                               **        *   * **    * *                           * *                                                                                                                                                                   *   **    **  **           ** * **   ***  ******  ***                                                                                                                                                                                                                                                                                                              ***                                                                                                                                                   *  **  **  **  **  *                                                                                                                       **        **                                                *              *                                                                                                                                                                                                                                *           **    *     *   *     *
               * *              * * * *   *     *     * *             * ** *    *     *     * *                                                   ***   * *       ** * * * **      ** * * * **      ** *   *           * * *       *       *       *   *   *   *                                                                                                                                 **                                    ***                  **                       ** *                     **                       * *  * *                                                                                                                                                                                                                                       **  *  * **                                                                                                                                                                                                                                                                                                           **   **                                                                                                                                                                                                                    *       **       *                *       **       *                              *     *                    * * * *                                                      *    *                                                                                                                                                                                                                                                                                                  **                               **        *     *       *                                                                                                                                                                                                 **  *     *    *           * **    *   *  *    *  *                                                                                                                                                                                  **    *** ***    **           **    *** ***    **                                                                 ***          *                                                                                                                                                   **                  **                                                                                                                      *          *                                           *    *              *                                                                                                                                                                                                                                 *        **       *     *   *     *
             * * * *    ****     ** * *    *****     ** **    ****    *    *     *****       * *                                                 *      * **         *   *            *   *            *   * **      **    **      **** * *         ** *    * *                                 **         ** ** **                                *                           **                 *                                       *                  *     **                 ** *                     ***   **                  *  *                  ** *                        *  *                                                                                                                          * *   *   *   ****   ****   *   *     *   *   *                  * *  **              *             *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         * *   *    *   * *                * *   *    *   * *                               *   *                     *     *                                                      *   *                                                                                                                                                                                                                                                                                                                                               *   *                                                                                                                                                                                                               *     *  *                *** *                                                                                                                                                                                                 *  **  * * *  **  *           *  **  * * *  **  *                                                                  *           *                                                                             ***                                                                                                                                                                                                                ***    ***                                          * *                                                                                                                                                                                                                                                    **         *      **    **  **    **
             **   **   *    *        *       *                *  *   **    **      *      ***  *                                                  *** **             * * *            *   *            *    * *       * * *             * **         *  **  * **                              *** *        *   * *           **                ** * *            *             * * *             *                                   ***  *  **             *   *  *                *    *                   *    *  *                  *    *                 * **                            *                                                                              ***                                       *  *   * ***  *    * *    *  *** *     * ***   **                  *                  * *  **   **  * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         **  *      *  **                  **  *      *  **                                 ***                       *   *                                                                                                                                                                                                                                                                                                                                                                           * *                              **                       *                                                                                                                                                                                    **  **    **  **               *                                                                                                                                                                                                      *** ***   *** ***             *** ***   *** ***                                                                   *                                                                                                                                                                                                                                                                                                              *    *                                             **      **        **                                                                             **              ***        **                                                                                                                          ** *    *         ** *      ** *
                       **  **                                                             *    **                                                   * *               * *              ***              ****          * * *          ** *            *    **                                 *  *  *        ** * *            *               * * *  *          * *              ***            * ***                               * * * * * *            * ****   *              * **** **                * **** * *                  *    *               **    **       **                  **                  **                              **                                                                  *      *   *   **  * *  **   *   *     *   *   *                                  **  *  * **   ** *  *  **                                   **                                                                                                                                                                                                                                                                                                                                                                                                                                                                   *        *                        *        *                                                               ***                                                        *   *                                                                                                                                                                                                                                                                                                                **                                         *            *                                                                                                                                                                                      *  *     *     * **            ***  **                                                                                                                                                                                                    ** * **                       ** * **                                                                                                                                                                 *   *                                                                                                                                                                                                                                                                            *          *                                                                             **            *   *        **                     * *                                                                                                  * **    **        * **      * **
                                                                                                                                                    * *                *                                               * *           * **             ***                                  *    * **              **        * * **           *  * ***         *** *             *               *    *                              *   * * *           *  *     *** *             *    * * *            *  *      *  **                *    *               *     *      *  *            * **      *                             ** * **          *                                                                       *             * * * *                        * **            *                 **   **           **   **                                 *  *                                                                                                                                                                                                                                                                                                                                                                                                                                                                   *        *                        *        *                                     *                                                                                    *    *                                                                                                                                                                                                                                                                                                               *                                           **          ***                                                                   **             **                                                                                               *    *     *    ** *               *                                                                                                                                                                                                    **         **                 **         **                                                                                                                                                              *   *                                                                                                                                                                                                                                                                             ***    ***                                                                                           *    *                                **
                                                                                                                                                     *                                 ** *             **              *                               * **                              *  * * *          **  * *        *** * *  *        ***             *    ***          *    *        ** * *  *                           ** * * * * **         * * *  **     *  *         ** *   ** *           * * *  * *  * * *        **       **                  *     *                     *  *   *                 *   *             *              *   *               ** *       * **                               * * *              * * * *                       *    *           *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  *        *                        *        *                           **       ***                         *                                            **            *   *                                                                                                                                                                                                                                                                                                                                                          **                                                                                *                 *                                                                                              **  **    **        **          ** * * *                                                                                                                                                                                                *           *                 *           *                                                                                                                                                                                                                                                                                                                                                                                                                   *       *      *               *    *                                                                                             *   *                                 *
                                                                                                                                                                                       * **             **                                               * *                              *      *              * *        **    * * *        *  * **        * * *   *        *** *  *       ** * * ** **                         * * *   *             *  *     **  * * *         *    * *  **          **  *      *  *         *  ***                      **    **     *  *           *   * ***                *    *          *     *           *   **              *             *                              ****                 *   *                         *              ** *                         ** **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               **  *      *  **                  **  *      *  **                       * *                                  ***       **                                  **              ***                                                                                                                                                                                                                                                                                                          *                                                                                                                                    *           *                                                                                                     *     *          *          ** * * ***                                                                                                                                                                                               *         *                   *         *                                                                                                                                                                ***                                                                                                                                                                                                                                                * *     * *      *    **
                                                                                        **               *                                                                                                                                                                                 * ** * **         * *  **       *  *  *  *         ** *  *            * **         *     **           *    * *                       * * * * * *                * ***     *  *          * **** ***  *           * * **** *             **        *                  ** *        *  *         *           *            * * *             *****              * *                **         **                                                                                     **             **                      *  * *  *                                         ** *            *                                                                                                                                                                                *  * *  *                                                                                                            *       *                                                                 *              *                                                   * *   *    *   * *                * *   *    *   * *                      * * **                                         * *                                                                         * *                                                                                                                                                                                                                                                                                  **                                                                                                                                 **  **     **  **                                                                                               **   *     *        *               **    *                                                                                                                                                                                             **         **                 **         **                                                                                                                                                                                                                                                                                                                                                                                                                   *       *     ***   *  *  **                                                                                                      *   *
                                                                 **                      *              * *                                                                                                                                                                                   * *  *         **  *            * **               * *          *    *         *  *                 ****                          **  *  ***                  *   **** *              *    *    **           *  *    *                   *   * *                 * **         * *            *** *   *            * * *                                **   *           ***  *********  ***                                                                              **              *                          ***   ***                                           * *  **      * ****                                                                                                                                                                            **** ****                                                                                                           * *     * *                                                               * *   ***      * *                                                  *       **       *                *       **       *                       * * *    *                                 ** * *                                                                          **                                                                                                                                              **         **  **         **               **         **  **         **                                                 * *        * *                                                                                                                                                                                                                                                  *  **    **        **                ****                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                * *    *  *                                                                                                   *    *
                                         **      **             *  *  **                 * **           * ***                                                                                                                                                                                   * *        *   * *          * *                   *            *** *          *                                                     *                        *  *   *                 **  *               **   ***                     *  * *                **    **        *             *   *  *           *    *                                  *   *           *  *           *  *                              ****              *** ***                           *           **                                                                              *    *     * * ***                                                                                                                                                                          **         **                                                                                                          *       *              *       *                                          *    * *       *                                                  **                **              **                **                        *                                   *    * * *                                                                           *                  ** *   * **                                                                                                                   *         *    *         *                 *         *    *         *                                                  *   *                                                                                                                                               *     *                                                                                                    *     ** *      * **                  *                                                                                                                                                                 ** **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              *     * * *                                                                                     **            *   *
                *  *      **        **   * *   *  *   ** *      * *    *  *             **  *          **    *                                                                                                                                                                                   *         ** ** **          **                                  **                               **                                 ***                    **     *                 ** **                       **               **     * *                 *     *                    *      ** *           *   *               *** ***                  *           **             **                             * * *                *   *                        *    *         **                          ** * * **                                             *        * *                                                                                                                                                **   **                    ** * * ******* * * **                                                                                                                            * *     * *                                              ***                                                                    *                               *                                 *  *      **      ***                        *                                                                                                *  *   *  *                                                                                                                  *           *  *           *               *           *  *           *                                       **            *          **                                                                                                                                                                                                                                              **    * **      ** *                   *                                                                                                                                                               * * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           *     *                ** *  *                                                                                      **              ***
                ****      *  *    *  *     *   ***    ** ***     *     * * *         *    **          *   ***       *                                                                                                                                                                                                                                                                             **                                   *                           **                                                            *  ***   *                   *     *       **             **                                                            **                                                         *                     *   *                         ** *          ***                         * ** ** *                                             *  *      *                                                                                                                                                *  * *  *                   ** *  **  *  **  * **                                                                                                                             *       *                                                                                                                     *  *                            *  *                                  *      ***     * *      ***      **      *  *                                                                                               ***   ***                                                                                                                   **         **  **         **               **         **  **         **                                       **        *    *       *  *                                                  * *                                                                          ***         ***                                                                                                                                      **                                                                                                                                                              *    *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          ***   ***               *  *                                                                                                                                              **
              **    **      **    **      ** **             *       ** *  *          *****            *****        * * * **                                                                                                                                                                                                                                                                                                                                                                                                      **                          **    **       **               *                  **                                                            ***                                      *                                                    *                                                                                                     **                                                                                                                                           **   **   **   **          **      **           **      **               **   **                                                                                                                                         *  *    *  *                *  *    *  *                                               *  *                            *  *                              *   *   *  **      ***      * *     ***      *                                                                                   **                                                                                                                                             ** **          ** **                       ** **          ** **                                                         *       *                                                       **                                                                 *                               *                                                                                                                                                                                                                                                                                             * **  **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  ***  ** ** ** **  ***      *    *                                                                                                                                               **
             * * ** * *      * ** *         *  *      ** ***        *  *           **    *          **            * ** ** *                                                                                                                                                                                                                                                                                                                                                                                                                                    ** *                           *  *                                                                                                                  *  *                 *** ***                           **                                                                                               **    **                                                                                                                                           *               *          *    ***               ***    *              *  * *  *                                                   *       *              ***   ***                                                   ***  ******  ***            ***  ******  ***                                               *                               *                               *   *                       ***      **  *   *   *                                                                               * *                                                                                                                                      *** *       * **** *       * ***           *** *       * **** *       * ***                                               *   *       *                                                       *                                                                 *  *        * *     * *        *  *                                                                                                                                                                                                                                                                                          * * **    *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       ***   ***            *****                                                                                                                                                                                                                                                                                                                                                           **      **
             * * ** * *      * ** *         *  *       * *       *    *             *  **          * *  ***       *                                                                                                                                                                                                        *                                                                                                                                                                                                                                   * **                                                                                                                                                 * *                                                     *                                                                                               **    **                                                                                                                                        ** *               * **         * *  *               *  * *            **   **   **   **                                              * *     * *             * *   * *                                                     *  *    *  *     ***        *  *    *  *                                      **                **               **                **                        *     *                                  *   *                                                                                 *                                                                                                                                     *  **    *    **  **    *    **  *         *  **    *    **  **    *    **  *                                              * *         *                                                                                                    ** *      ** *       *  *   *    * *     * *    *   *  *                                                                                                                                                                                                                                                                                         * * *  ** **                                                                                                                                                                                                                                                                                                                                                                                                                                                                              **        *     *        **                                                                                                                                               ** *          ***                                                                                                                                                                                           *      *  *    *  *
              **    **      **    **         ** **     * *       *****              * *          *** * *  *      **                                                                                                                                                                                                       **                                                                        **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     * * **             ** *  *      ** **                   ** **           *               *                                               *       *              ***   ***                                                                      * *                                                           *       **       *                 *       **       *                      *  *                                  *     *                                                                                     **                                                                                                        **          **              **    *******        *******    **         **    *******        *******    **                                                           *  *     **      **                                                                                 * **      * **         *    *      *     *      *    *    *  **                                                                                                                                                                                                                                                                                  * * *  **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                * *                       * *    *                                                                                                                                         * **          *                                                                                                                                                                                              **    *  *    *  *
                ****      *  *    *  *    ***   *       *                      *  * * *         *    * *                                                                                                                                                                                     **     **               *    **  *                                                                 ** * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                      **                                                                                                                                             * *     ***   ***     * **        *  *    ***   ***    *  *          ** *               * **                                                                                                                                                  ***                                                           * *   *    *   * *                 * *   *    *   * *                        *                                         *  *                                                                                                                                       *  *                                                *  *        *  *                   * * * *        * * * *                     * * * *        * * * *                                                                   **     * *     * *                                        **                                    **    **  **    **            * **             ** *        * *  *                                                                                                                                                                                                                                                                                   * * **   **                                                                                                                                                                                                                                                                                                                            *                                                                                                                                                *                           *   * *                                                                                                                                                       *                                                                                                                                                                                            **     *  *    *  *
                *  *      **        **   *  *   * *                *           **** **           ** ** **                                                                                                                                                                                    *       *               **  *  ***             **  **                            **                 * *                                     **                          **                                                                                                                                                                                                                                                                 * ** ** *                                                                                                                           **                                                                                                                                           **  *     * *   * *     *           * **    * *   * *    ** *        *  * **             ** * *                                                                                                                                                                                                                **  *      *  **                   **  *      *  **                       * * *    ***                                 *                                                                  ***     ***                                      ****                      *                                               ***  ******  ***                     * *            * *                         * *            * *                                                                              *       *                                        * *                                   *     *   *     *         *                           *    * * *                                                                                                                                                                                                                                                                                      * *  ** *                                           **                                                                                                                                                                                                                                                                              **                                                                                                                                               **                           **   *                                                                                                                                                                                                                                                                                                                                                             **      **
                                         **      **               * *              *              * *                                                                                                                                                                                     ** *       * **         *  **  *                 * *  * *                  *** * *                     * *   **                                 *                        *  *                                                                                                                                                                                                                                                            *   *         *   *                                                                                                                                                                                                                                                                  *    **    ***   ***    **          ** *     ***   ***     * **       ** *     ***   ***     * *                                                                                         ***   ***                                                                                                                 *        *                         *        *                         * * **     *                         ***    * * *                                                               ** **   ** **                                    *   *                  *   *                                                  **      **                    ***     ***    ***     ***                 ***     ***    ***     ***                                                                          **      **                                         *                                    *     *   *     *        * *   ***           ***   * *   ** * **                                                                                                                                                                                                                                                                                     *  *  *                                            *  *   **                                                                                                                                                                                                                                                                       *** *         **
                                                                   *             * *              * *                                                                                                                                                                                     ** * ***** * **         ***  * ****              *      *              ** *      * *  * **            **   *  *                                *                         ***                        **                  *                      ** **                                                                                                                                                                                    **       * *       **                                                                                                                                                                                                                                                                 *****                               *  *                   *  *          *     * *   * *     *  **                                         ***   ***                                     * *   * *                                                                                                                 *        *                         *        *                         * *                                   *     ** * *                                                              ** * * * * **                   **                   *                   ****                                                 *          *                  * * *   * * *  * * *   * * *               * * *   * * *  * * *   * * *                                                                                                                            **                                  **    **  **    **                                      *   **   *                                                                                                         *               *  *               *                                                          *               *                                                          **   * **                                            ** *   *  ** **                                                                                                                                                                                                                                      *                         **             **                                                                                                                                         **             **
                                                                                 **                *                                                                                                                                                                                          *  *  *                  *     *          ** **     * **         *  * *   *    **** *  *          *  *****                                 **                                                  * *                 * *                      * * *                                                                                                                                                                                    *  ** **   ** **  *                                                                                                                                                                                                                                                                      *                        **   * *  **                 **  * *        **    ***   ***    **    *                                        * *   * *                                     ***   ***                              *  *    *  *     ***        *  *    *  *                                           *        *                         *        *                          **       ***                                  * *                                                               *   * *   *                    **               *  *                                **                                       ** *    * **                  **  *****  **  **  *****  **               **  *****  **  **  *****  **                                                                                                                                                                  ** *    *     *                                          **  ** *                                                                                                        ***           ***  ***           ***                                       *               *  ***           ***                                                         *  ***  * ** *                                         * **   ** * *                                                                           *                                                                                                                                                           **                         **                                                                                                                                                       **             **
                                                                                                                                                                                                                                                      **                                       *****              ***  * ****           *  *  * * *  *         ** * *             * **           **                                        *                     *******               **    *             **    * *                      *  **                                                                                                                                                                                ** **  *           *  ** **                                                                                                                                                                                                                                                            ****                           * * * *                           * *                            *****                                        ***   ***                                                                          ***  ******  ***   * *      ***  ******  ***                                      **  *      *  **                   **  *      *  **                               *   *                       ***       **                                                                *  *   *  *                                                                         * *                                           **                                                                                                                                                                                                                                                                * **     *     *                                     *   * *  * *                                                                                                           *         *        *         *                                          ***           ***     *         *                                                             **       * **                                        *    *   * * * *  *                                                                      *     *                                                                                                                                        **         * ***                         *
                                                                                                                                                                                                                                                       *       *                                                  *  **  *               * * *  * * *             *               *               * ****                               **** *                   *       *               *  ** *             *  ** * **                 * **                                                                                          *                                    *                                                   *       **         **       *                                                                                                                                                                                                                                                           *  *                             * *                               *  **                        *                                                                                                                                 *  *    *  *     ***        *  *    *  *                                       * *   *    *   * *                 * *   *    *   * *                             *     *                     *   *                                                                         ***   ***                                                                            *                                                    *                                                                                                                                                                                                                                                      **    **  **    **                                         **  ***                                                                                                           **         **      **         **                                            *         *       **         **                                                             * ** * *                                           * ***    *  ** ***** **                                                                   *     ***                                                                                                                                      **             **                                                                                                                                                                         **                           **
                                                                                                                                                                                                                                                       * *   ***                                 *                   **  *  ***           ** *  * **              **             **               * *  *                              *     *                  * **   ** *              * * * *             * * * * *  *              *    ****                                                                                     * *                                   ***                                                     *   *           *   *                                                                                                                                                                                                                                                                                               ** **                             ** * *                           ****                                                                                                          *                                                                                               *       **       *                 *       **       *                             * * * *                    *     *                                                                                                                                                             **                                     *            **                     ***          ***                           ***          ***                                                                                                                                                                      *     *   *     *                                       *   **                                                                                                                                                                                          **         **                                                                                * *   *                                            * *  * *   * * *   ****                                                           **      **       *                                                                                                                                                   **                         *                                                                                                                                                 *                           *
                                                                                                                                                                                                                                                  **    **  *                                   * *                  *    **  *               **                                                   *                                 * **    **            **  * *     * *           ** *  *  * **       ** *  * *  * **              *    *  *                                *                * **                                 *                  **                   *                                                ** *                     * **                                                                                                                                                                                                                                                                         **   **                           **   **              *                             *  *                                                                                    *           ***      * *                                                                                             **                **               **                **                           ** * * **                   * * * *                                                                                                                                          ***        **                                             **                                  * *  **  **  * *                           * *  **  **  * *                                                                                                                                                                       *     *   *     *        * *   ***           ***   * *   ** * *****                                                                                                                                                                                                                                                                                ** *                                           * ** *   ** **   *    *   **                                                          * *         *    **                                                                                                                                                   *                         **                                                                                                                                                 * *                       * *                                                                                                                                                                                                                                                                                                                                                            *
                                                                                                                                                                                                         **           *  *                         *       * *                                   *                        **                                                                                                         * *       *           * * *         * **        ** *    ** **       ** *       * *              **                                       * *               ** *                                                        **              **         **                                                                                                                                                                                                                                                                                                                            *    ***        *   *        ***       ***        *   *        ***    **                                                                                                                   * *          * *       *                                                                                                                                                                               *  ** **  *                 ** * * **                                                                                                                         **            *   *        **                                                   ***  ***  * *                 ***          ***                           ***          ***                                                                                                                                    **      **                        **    **  **    **        *                           *    * *  *  *                                                                                                                                                                                                                                                                                  * ****                                       ** *  * * *      *  * *                                                               * * **  *    *                                                                                                                                                                                 **             **                                                                                                                                    **        *     *        **                                                                                                                                                                 ***                                                                                                                                                                                         *
  ** *                                                                    **      ***                       *           *                                                                               * *           *  *                         * *     * *                                                             *                                                                                                    * ** *        * * **         * *         * *            *     *             *       * *              **    *                                   *                                  ** **            *****               ** *  *                         *                                                                                                                                                                                                                                                                                                                            * *   * *     *         *     * *       * *     *         *     * *                 **   **                                                                                                  *           ***                                         ***                                                                                                                                           **       **                *  ** **  *                                                                                                               *       **            *    *                                                   * *  ***  ***    * ****                        **                                         **                                                                                                                                           *  *  *  *                          ** *      ** *              * **             ** *        *  *                                                                                                                                                                                                                                                                                       *   **   **                                      * * ** * * *     * ****                                                            * * *       *                                                                                                                                                        *                         *** *         **                                                                                                                                             ***   ***                                                                                                                                                   **        ***        ** * **                                                                                                                                                                                      * *
  * **                                             **         **           *                  ***         * *           * *                            *                                                *          ****  ****                 **    **      *                                                                                                                                                                   ** * *        * ** *        ** *         * * *       ** * * * * **       ** * * * * * **               ****                                                     ***              * * *            *     *               * ***                        * *                                                                                                                                                                                                                                                                                                                            * *   ***     **       **     ***       ***     **       **     ***       ***        *   *        ***    *                                                                                                                                           * *                                                                                                                                                                      **       **                                                                                                    **        **         *           *   *                                                    **** *   *   *       **                     *      *                                   *      *                                                           * *                                                                                                              * **      * **         *    *      *     *      *    *    **                                                                                  **    ** *      ** *                                                                                                                                                                                   *       *                                        * *   * * ***** *   **   **                                                         *     ***                                                                                                                                                          **                         **                                                                                                                                                    ***  ** ** ** **  ***                                                                                                                                             **        *   *     *     **                                                                                                                                                                                       *
      **                        **      *           *        * *        * *      **  *      *                 *       *                               * *                                            ** **                                     *       ***                                                                                                                                                                          *       * *                * *     * *  **       ** * * * * **       ** * * * * *             ***  **                                    *****          ** * * *             * * *           * * *  *                *                    ***    **                                                                                                                                                                                                                                                                                                                              *                                                                        * *     *         *     * *   * *                                    *       *              ***   ***                                                     *  *    *  *     ***        *  *    *  *                                                                                                                                                                                                                                   **     **                     **       **                                                        **    **    ** *       **         *                                                                                                                                         *    *  *                                                                                                                                  *  *   *    * *     * *    *   *  *                                                                                       *    * **      * **           ***   ***          ***   ***                                                                  ***   ***                                                 *                *    * *                                          * ** * *     * *       *                                                         *  *                         *                                                                                                                        **             **                         *                                                                                                                                                          ***   ***                                                                                                                                                             *    *     ** * **                                                                                                                                                                                       *
      *      ***      ***        *       **      * *                                        *   *       **             *****                         * * *              **                *           * *              **                      * *     ***                                                                                                                                                                           **    ** *                * **   ** *              * *   *             * *   * *                *                                    * *     * *       ** *   *          ** *   * **        * *  * **          *    ****                *   *                                                                                                                                                                                                                                                                                                                                                                                                            ***     **       **     ***   * *                                   * *     * *             * *   * *                                                   ***  ******  ***            ***  ******  ***                                                                                                                                                                                                                                 **     **                               **  **                 *   *                              *     *    * **                  *                                               **                                         **                                              **     **        *                                                               * **  ** *                                               *  *        * *     * *        *  *                                                                                      *   **    **  **    **         *  * *  *          *  * *  *                                               ***   ***          *  * *  *                                                * *                    **          **                               ** * * *  ** *  *    * *                            **    * **      ** *         *                            *                                                                                                                        **         * ***                                                                                                                                                                                      *     *                                                                                                                                                               *   *       ***                                                                                                                                                                                         *
       *             ***      *        **       *          * *        * *         *  **     * *               **      *                              *   *             *  *           ** * *          * * **                              **    **         **                                                                                                                                                                          *     *                  *       *               *  ** *             *  ** * **            *  *                                    ** *   * **          *   * **       ** *   * **       ** *  * *         * **   *  *               *     *                                                                                                                                                                                                                                                                                                                                  *                                                                                                       *                                     *       *              ***   ***                          ***                        *  *    *  *                *  *    *  *                                                                                                                                                                                                                                                                                                  *    *                            *     *   **    **                                         *        *    *       *  *                 *        *    *       *  *                                        **        *   **     * *                                                         **  * *      * *  **                                           *                               *                                                                                       **  *     *   *     *         *         *   **   *         *                                              *  * *  *         *         *                                                *                                 * *                                    *   * **       **      *                       *    ** *      * **         *   *  **                    *                                                                                                                                     **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     *
      **                      **         *      **        *          *                        *  **      *              * *                        **  *  **           * *  *          * *  *        ** *             ****                 *       ***     * *                                      ***                  *                                                                                                             * ****                    *******               **    *             **    * *               * *                                       *   *             *   * **          *   *           *  * * *         *   *** **                 *   *                                                                                                                          *                                                                                                                                                                                                       * *   ***     **       **     ***       ***     **       **     ***                                                                                                                                 *    * *       *                                                                                                                                                                                                                                                                                                                                                           *   *        **                  **    **  *     *                **                                   **        *  *                             **        *  *                                         **          **      * **                                                  *      *    *        *    *      *                                             ***         ***                                                                                                     *     *   *     *                        *                                                          *         *                                                                                                  ** * *                                                           * *                    *   **        **             *   *  ***                  **                                                                                                                                     *                                                   *     **                                                                                                                                                                                                                                                                                                   *   *                                    **                                                                                                                                                            * *
  ** *                                                    **         **            ***          *          * *          *                         *    *    *         ** * **         *  * **           * *         ***  ***               * *     ***       *                                   ** **                  * * **                                *                 *                * *                                    *                                                    * *                 * *            **                                           *   *              ***              * * *           *     *            ** * *              **    ***                                                                                          *          *         **         * *                                                                                                                                                                                                      * *   * *     *         *     * *       * *     *         *     * *                                      *                                                                                         * *   ***      * *                                ***                                                                                                                                                                                                                                                                                                                         ***        **                    * **     *     *              *  *                     *** *                 *       *            *** *                 *        *                                             *  *      ** **          **                                     * *         *          *         * *                                                                                                                                                           **  **    **  **    **       *           * *    *           *                                                              *           *                                             *****                            * * *                                                           * *                     **   *        *              *     *****               *                                                                                                                                                                                           ***    **                                                                                                                            *       *                                                                                                                                                             *    *                                    * *                                                                                                                                                            *
  * **                                                                                                     *                                     * * ** ** * *        *               **             **             *      *          **    **         **    **                                  ** **                 *  * *            **                 ***                * *             *** ***                                   **                        ***                        **                  *            * *                                            ***                                 ** **           *****              * * *             * *                                                                                                * *        * *        **          *                                                                                                                                                                                                        *    ***        *   *        ***       ***        *   *        ***       ***     **       **     ***   * *                                                                                         *              *                            *    * *       *                                                                                                                                                                                                                                                                                       **  **                                                     ** *    **    **               **                     * **           *       * *                 * **           *       * *                                                    * *        * **          **                                      *       *  *          *  *       *                                                 *     *                                                                                                     *  *     *     ** *         *    * *    *  **  *    * *    *                                           *           *  **  *    * *    *                                            *    *                              *                                                               *                         *          *             *  *   ***      ***      *    *                                                                                                                                                                                      ** **                                                                                                                                * *     * *                                                                                                                                                  **        *   *            **                         *                                                                                                                                                            *
**                                                                                                                                                *    *    *          *** ****          * **        *  * *         ***  ***           *       ***     * *                                        *                    * ** *  *         *                 * **                * *            *       *                                   *                       *  *                                                         **                                                              * **                                                * * **              *                                                                                                   *          *                                                                                                                                                                     **    *    **                                                           **   **                           **   **                 * *     *         *     * *   * *                                                           *       *                                                                * *   ***      * *                                                                                                                                                                                                                                                                            **       **                                                              **    ** *                                        ** *          *  *      *    *** *         ** *          *  *      *     *** *                                                       * *                                                                                                                                                                                                                                                *    *     *    * **              * *                * *                                                *    * *    *    *      * *                                                *  *                                **                                                                                     **  **        **              *     **       * *      *         **                                                                                                                                                                                                                                                                                                                      *       *                                                                                                                                                   **        ***              **                         **
*                                                                                                                                                  **  *  **               *  *       ** *  *         * *             ****             * *     ***       *                                                          ** *   * ***          *                **                 ** **          * * ***** *                                 *                        **                                                                                                          ** *             ** *                                 *              **                 **         **                                 * * *                                                                     *                             *** ***                                                                                                                        *  * *   * *  *                                                                            ** **                             **    ***        *   *        ***    *                                                           * *     * *                                                                *              *                                                                                                                                                                                                                                                                             **        **                                                              *    * **                 **                   * ***    *      *  *          * **         * ***     *     *  *           * **                                                *         *                                                    *     *                  *     *                                             **  **     **  **                                                                                               **  **    **  **    **        *   * *   *        *   * *   *                                                 * *      *     *   * *   *                                         *  * **                               ***                                                                                      *    * **      ** *        * * *            ***        ***     * *                                                                                                                                                                              * * * *
 *                                                                                                                                                   *   *            * **            ** * *         ** * **                            **         **    **                               **                      *  * **** *          ****             ** *  ***            *     *         * *   *   *                                 **                                                                                                                                   * **                                                 * *                                           *                                  * * *           *** ***          *** ***                                 * *  * *    * *  **     *   **    *                                                                                                                           ***         ***                                            *  *                             * *                               *              **   **                                                                           *       *                                                                                                                                                                                                                                                                                                                                                                         *                                                             *   **    **              *  *                          * *       *           ** *                  * *      *            ** *                                      **       *                                                              ***   ***                ***   ***                                              *           *                                                                                                     *     *   *     *         **  * *  **        **  * *  **                                             *   * *   *   **   **  * *  **                                        * * *     *                            ***                           ** **                                   **                *     ** *      * **       * * **                            ** * *
**                                                                                                                   *                               * * *            ** **               *           * *              **                  ***     * *                                    ** **   *               ** *     * ***       *                *  *  * *           * * * * *       ** **    * **                                                                                                                                                                                                                           *                                             ***                               *   *    *   **    *                *    **   *     **  * *    * *  **   *  * *  *  *  * *  *    ** *** **   **                                                                                 **    *    **                             **     **                                               ****                           * * * *                           * * **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             **  *     *                **                     *       *                 * ***            *        *                 * ***                                      ***       ***                                                           * * * * * *              * * * * * *                                          *                 *                                                                                              **   *     *   *     *        ***** *****        ***** *****                                             **  * *  **        ***** *****                                         *  *    * *                           ***                           ** *                                    **                **        **  **    **     * *     ***                       * * *                                                                                                                                                                                ** **
  ** *                                               *                ** **       *         * **        *          ***                                * *                                           * * **                                 ***       *                                     *  *  ** **** **          *     * *  *        ****             ** * ** ***       * *   * *          *     *                                                                                                                                                                                                                                                                              *                                * *     ** *** **   **          **   ** *** **    *  * *  *  *  * *  *   **  * *    * *  **     *   **    *                                        **         **                              *  * *   * *  *                      **   *  *****  *                                                    *                        **   **                           **  *                             *  *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  *     *                                          *  *        **                              *  *        **                                                  * **               **                                                   *** ** ** ***    ***     *** ** ** ***                                          **             **                                                                                                *  **    **  **    **         *  * *  *          *  * *  *                                              ***** *****         *  * *  *                                             **  *  *                            **                       **      *                                                                *  *     *       **         *                       *                                                                                                                                  **                                        **    ** **
  * **                      ***       *            ***                *   *      * *        ** *      ***         *                                    *                                            **  *          ****  ****           *      **    **                                    ** **** **  *  *          **    *   *             * **          *  *   **       ** *   * **      ** *    ** **                                                                                                                                                                                                                                                                                                           *   *    *   **    *                *    **   *     **  * *    * *  * *                                 *** ***                                    *  *       *  *                             ***         ***                     * *   **       **   *  **                                        *****                                                              * *                           ****                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 **    **                *                        *  *       *    *        *                  *  *       *    *        *                                      * *             ***  *                                                    * * * * * *     * *      * * * * * *                                                                                                                                                           *     ** *      ** *            **   **            **   **                                                *  * *  *           **   **                                                   **        ***                   *                    **  ******* *                                                    **        *    *     *            *    *                *     *  *                                                                                                                                **                                       * *      *
             ** ***     **            * *         *       **    **     ***      *  *                 *            *  ***                                                                                * *           *  *             * *     * *                                                 *   ** **               ****             ** *  *        *     * *       *  * * *  *       *   *   * *                                                             **                  *                                                                                                                                                                                                                          * * *           *** ***          *** ***                             *                                                                             ***         ***                                **     **                        * * **             * *  *                                        *    **    ***   ***    **             **    ***   ***    **        **                        *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   **    ** *       **         *                         **                                          **                                                             *  *               **                                                      ***   ***      ***       ***   ***                                                                                                                                                            **    * **      * **                                                                                       **   **                                                                              **  *                 * * *                 * **       * *          ***                                        *        **  **    **                *                 **    *                                                                                                                                                                              *                                                                                                                                                                                                                                       **
             *          * * **      *              *      * *  * *             *    **      ***      ******      ** *   *                                                                                **           *  *             * *       *                                                        **            *               * **   * **         *******          *     *         * ***** * *                                                             *                 ***                       **                                                                                                                                                                                                 * * *                                                                        *          *                                  ** *      ** *        **   *********                                  *  *****  *                        * * *             * * *                                          **  *     * *   * *     *             *     * *   * *     *                                  *****                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               **    * **       **** *   *   *       **                                                                                                                          **            *                                                            *     *                  *     *                                                                                                                                                                                                                                                                                                                                                             *  **                 ** * *               *    ***   ** **       **  *                                       *     * **      ** *               **                   *     *   *                                                                                                                                                                                                                                                                                                                                                                                                                  **
              *   *                * *****      *  *        *  *                **    *    *   *           *        *   *                                                                                                               *  **    **                                                                     *****            *     *              *               ** **           *       *                                                            * *                *                         * *                                                                                                                                                                                                                                                        *          **        * *        * *                                 * **      * **       * *  *  *****  *    **                  **       **       **                          *              ** * **                                           * *     ***   ***     * **       ** *     ***   ***     * **          **    ***   ***    **    *                                                                                                                                                                                                                                                                                                                                                                                                                                 **     **                                                                                      * *  ***  ***    * ****                       *      *                                    *      *                                                             *                                                                                                                                                                                                                                                                                                                                                                                                                                                         ***                      * *               * **    ** **   *      *  **                **                     **    ** *      * **               *                          *   *                                                                                                                                                                                                                                                                                                                                                                                                                  **                          *
                   *      * *       *          * **         *  *       ***        *  *     *   *       *   *        *   * **                                                                                                         ***   * *                                                     *                        *                 **                *              * *             *** ***                                                             **                * *****                  ***                         *                                                                                                                                                                                                                               * *         **         *          *                                      **  **    **     * * * *  ***  **   *  *                 * *                          **              *  *          *   **   *                                          * * **             ** *  *        * * **             ** * *           *     * *   * *     *  **                                                                                                                                                                                                                                                                                                                                                                                                                                  **     **                                                                                                ***  ***  * *                          **                                          **                                                         * *        **                                                                                                                                                                                                                                                                                                                                                                                                                                                                             **                 **   *      * *       ***                  *                                                         *                          *                                                                                                                                                                                                                                                                                                                                                                                                                      *          **               **        **
              *** **     *            * *      *             **       *   *       * *       * *        ** *          ***  *                                                                                                          *       *                                                  ** **                     *                                    **              * *               * *                                       **                  **                    * *    *                *   *                       * *                                                                                                                                                                                                                               *                                                                       *   *     *       * * *             * *  *  *              ***                       * *              *       *        **  ** *                                          ** *               * **          * * *               * * *        ** *     ***   ***     * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       **                                    ***          ***                            ***          ***                                                   **     ***  *                                                                                                                                                                                                                                                                                **         **      **         **                                                              **         **                                                                                                      ** * **   ***                             ***                                                      *                          *  *                                                                                                                                                                                                                                                                                                                                                                                                                  * *         **                **       **
                         **           *       **                      ** **        *      * * * *          ***            *                                                                                                                  **                                                 ** **                     **                                                    *                                                          *                    *                 ** *  **  *               * ****                        *                                                                                                                                                                                                                                                                                                         *   *     *        *              ** * *****             *   *                    ***                *   *  * *   *   * *  * *                                             *               *              *  *               *  *         *  * **             ** * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       *            **                       * *  **  **  * *                            * *  **  **  * *                                                   *          **                                                                                                                                                                                                                                                                                 *         *        *         *                                            **         **       *         *                                                             *                                         ** * **   ***                               *                                                                          ***     *                                                                                                                                                                                                                                                                                                                                                                                                                    * **                     **  **
                                                                                          **   **            *         ***                                                                                                                                                                     ***                                                                                                                                       * *                    *                * * * *  * * **            *                                                                                                                                                                                                                                                                                                                                      **  **    **       **             *  **                   ***  *  *            ** *   *               *      *  *      **  ***                                              **   **   **   **                 **   **   **   **              ** *               * **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      *                       ***          ***                            ***          ***                                                                                                                     *       *                *       *                                                                                                                                                                                       ***           ***  ***           ***                                          *         *     ***           ***                                                         *                                        **   *      * *                                                                                                        *       * * *                                                                                                                                ***   ***
                                                                                                                       *                                                                                                                                                                                                                                                                                                                 **                     **               **  *    * * *           **    **     **               *****                                                       *                                                                                                                                                                                                                                          ** *    *     *       ***       ***  ***   ** *                    * **          *     * **               *  *    **    *   **                                                      *  * *  *                         *  * *  *                     *               *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                **                                                                                                                                                                                                               * *     * *    ******    * *     * *                                                                                                                                                                                      *               *  *               *                                       ***           ***  *               *                                                          *                                      * **    ** **   *                                                                                                       *    *  ** * *                                                                                                                               *  * *  *                                                                                                                                                                                                                                                                                         *
                                                                                                                                                                                                                                                                                                                                                                                                                                     **                    **                        *   * ** *          *     *  * **  *               *    *                                                     * *                                                  *                     **                                                                                                                                                               * **     *     *      ***       * *  ***  ** * *              ***  *  *    ***   *     *                   *              ** * *****                                                 **   **                           **   **                      **   **   **   **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           ** *    * **                                                                                                                                                                                                           *       *    * *  * *    *       *                                                        **          **                                                                                                                                                                                            *               *                                                                                                                    *    ***   ** **                                                                                                   **    *         * *                                                                                                                              *   * *   *                                      ** *   * **                                                                                                                                                                                                                        **           *****
                                                                                                                                                                                                                                                                                                                                                                                                                                      *                     *                  ******        *          * *       * * **                 ** * *                           **       **               *                                       **        ***                      *                                                                                                                                                             **        **    **      ***       ***  ***   **  *              *   *        * *   *     * **              * * *     *       * *  *  *                                                                                                                    *  * *  *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               *          *                    **  *****  **  **  *****  **                **  *****  **  **  *****  **                                                                                                                          ***      ***                                                                  *  *        *  *                                                                                                                                                                                                                                                                                              *****                              * **       * *                                                                                                    *       **      **                                                                                                                               ****   ****                                      *  *   *  *                                                                                                                                                                                                                        **          *  * **     **  **
                                                                                                                                                                                                                                                                                                                                                                                                                                      *                     *                 *        ******           * *  *   *  * *                  *  * *                           *  ** **  *                                   *                    *       *                        *                                                                                                                                                              *         *     *        **             *  **   *                ***         ***     ** *   *             * * **   *   *     *  *                                                                                                                          **   **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 **      **                     * * *   * * *  * * *   * * *                * * *   * * *  * * *   * * *                                        ** * **                                                                          *    *  *    *                                                                 ***  ******  ***                                                                                                                                                                                                                                                                                             *     *                              **  ******* *             ***                                                                                     ***     *                                                                                                                                        *       *                                        ***   ***                                                                                                                                                                                                                                    *       *         **       **
                                                              *                                                        *                                                                                                                                                                                                                                                                                                              **                    **               * ** *   *                ** * *       * *             **   **  *                             ** * * **              *****                 ***        **        * *     **                       ****                                                                                                                                                            *         *     *        *              ** * **               * *                       ***              * *                 **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                ***  ******  ***                   ***     ***    ***     ***                  ***     ***    ***     ***                                                                                                                         * *    **    * *                                                                   **      **                                                                                                                                                                                                                                                                                                                                        **      *         ** ******* **                                                                                  *     *                                                                                                                                                            **                                                                                                                                                                                                                                                                         *  * **         **        **
             **  **          ** **            *               * *                *               **   **              * *                                                                                                                                                                         *                                    **                                                                                         **                   **                    * * *    *  **           *  ** *  *     *           *  * ***                                   * * * *              *    *                    *       *          **             *              **    *                                                                                                          * * *                                           **        **    **      * * *             * * *                **              *           * *             **     *     *                                                                                                                                                                                                                  **                                                                                                                                                                                                                                                                                                                                   **     **                                                                                                                       *  *        *  *                       * *            * *                          * *            * *                                             *     *                                                                         * *  *    *  * *                                                                  *          *                                                                                                                                                                                                                                                                                              **     **                                    ** *          *   * * *   *                                                                                        *                                                                                                                                                            **                                                                                                                                                                                                                             * **      * **      ** *                     *****          *
             *  * *         * **  *           * *           *                 ** * **              * *  *          **  *  **                                                                                                                                                                    ***                                    **               *  **                                *                                   * *                    *                   ** * *  * * * *           **     **    **           * * * * *                                   * *** *             *  *                      *      * *              ***      ***             * * ***                                  *** ***                   *** ***                                        * * *                          *** ***            ** *      ** *       * * * *  ***  **   * *  *                          ** *   * **       **                  *** *** ***                                                                                                                                                                                                                **                                                                                                                                                                                                                                                                                                                                   **     **                                                                                                                        **          **                      * * * *        * * * *                      * * * *        * * * *                                                                                                                          ** * ***  *** * **                                                                 ** *    * **                                                                                                                                                                                                                                                                                             *    *    *                                   ** **          ****   ****                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     ** *      ** *      * **                       *
              *             **    *         *    *               **          *   *   *          *     **           *    ** *                                                                                                                                                                   *                    **                                 * *  *           ** **                ***    *                            *                      *                      *  **  * **                        *              *  *                                        *****           *  * **                      *   *  **               *  *    *             *  *  **    *                                  *    **   *     *   **    *                                           *   *    *   **  **     *   **    *               * **      * **       * *  *  *****  *    *  **                          *         *                          *   ** **   *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   **    *******        *******    **          **    *******        *******    **                                      ** **                                                                       *  * **   **   ** *  *                                                                    **                                                                                                                                                                                                                                                                                                 **         **                                                   *     *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     **        **              **
                 *           *   *          ******         **                * * * * *          * ****               ** **                                                                                                                                                                     *  ***    **          *               ******           *  * *             * * *                  *  * *                          **                      **                     *    * *                      **** *                 * **                                                    * * *    **                        *                  *       **           * * *       * *                              **   ** *** **     ** *** **   **                                         * *     ** *** *  *    ** *** **   **                                  **   *********                                     **     **                            **** * *** *                                                                                                                                                                                                                                                                                     **                                                                                                                                                                                                                                                                                                                                                                                                                            *  **    *    **  **    *    **  *          *  **    *    **  **    *    **  *                                        *                                                                         **   * ** ** ** *   **                                                                                                                                                                                                                                                                                                                                                                       **         **                                                   *     *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      *         *              *
             * *  *         *    **                              *            *  *  *            **   **           * **    *                                                                                                                                                                ** * * * * *  *          * **           *      *         *    ** * *       *    * *              ** *  *  *                                             **                          ***** *                      *   *                   *  *                                                    *  *   *  *  **                *  *                   *                    *  *       * *                                 *    **   *     *   **    *                                           *   *    *   **  **     *   **    *                                       ***         ***                               ***  *****  ***                                   *                                                                                                                                                                                                                                                                                      * *                                                                                                                                                                                                                                                                                                                                                                                                                            *** *       * **** *       * ***            *** *       * **** *       * ***                                                                                                                        * *      * *                                                                                                                                                                                                                     **    **                                                    **    **                                                                                ** ***       *** **                                          **   **     **   **                                                                                                                                                                                                                                                                                                                                                                                                                                                                               *         *                *
             **  **         *  ** *           **             *                  * *              **  *  *          **  *  **                                                                                                                                                                 * *  *  * ***        ***  * *           *   * *        *   **  * **       **  *** *             * * ** * *                                            * *                               *                        ***                     **                                                        **  * *    *  *              ***                       *                   * *    ** * **                           *** ***                   *** ***                                        * * *                          *** ***                                    *  *       *  *                               *  *       *  *                        * ** * * *                                                                                                                                                                                                                  ***                                                                      *           * *                                                                                                                                                                                                                                                                                                                                                                                                                   ** **          ** **                        ** **          ** **                                                                                                                             ** *  **  * **                                                                             **                                                                                                                                     * *  * *                                                    * *  * *                                                                                *  *  *     *  *  *                                          *  ***** * *****  *                                                                                                                                                                                                                                                                                                                                                                                                                                                                               **        **              **
                             ** **            **            *  * *                                *   **              * *                                                                                                                                                                    *    ****             **    *         * * * **          ** * * *            * *  * *                ** *  **                                          *                              ***                       * *                                                               ***                    *     * * *                               **       *                   **    *  ** *                                                                                                    * * *                                                                      **         **                                 **         **                         ** * *** **                                                                                                                                                                                                                 ***                                                       **          *  *          *  *    *                                                                                                                                                                                                                                                                       *       *                                                                                                                          **         **  **         **                **         **  **         **                                             **            **                                                            *  ***  ***  *                                                **                           **                                                                                                                                       ****                                                        ****                                                                                   * *   *   *   * *                                            ***    ***    ***                                                                                                                                                                                                                                                                                **     **                                                                                                                                                                                         * **      * **      ** *
                                                            **  **                                                     *                                                                                                                                                                      *** *   ****           ****         * * **               * *  *            * *    *             **     * *                                          **                              *                         **                                                                 *                        ** *  *          **                     *    *  *                     **   **                                                                                                                                                                                                                                                                           *  * *                                                                                                                                                                                                                 *   *                                                     ***             *         **     **                                                                                                                                                                                                                                                                       ****   ****                                                                                                                         *           *  *           *                *           *  *           *                                             *             *                                                               *  ****  *                                                 ***                                                                                                                                                                  *  **  *                                                    *  **  *                                                                                ** *           * **                                                                                                                                                                                                                                                                                                                                            **     **                                                                                                                                                                                         ** *      ** *      * **
                                                                                                                                                                                                                      **                                                                   ***  *   * *  *                       *  * * ** *        * **     **         ** **** **            *    *** *                                                                                                                                                                       *                        ** *            * *     **           ***      ***                     *     *                                                                                                                                                                                                                                                                            **  *                                                                                                                                                                                                                *     *                                        *        * **            * *        **   *        **                                                                                                                                                                                                                                                                  *   * *   *                                                                                                                          *         *    *         *                  *         *    *         *                                               ***           ***                                                           ** *    * **                                               * **                                                                                                                                                            **    *  **  *                                              **    *  **  *                                                                               *  *    *   *    *  *                                            **         **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        **        **  **
                                                                                                                                                                                                                     *  *                         **                                      *   ** *  **               **          * *      **        **  ***    *               *         ** ** *****  *                                                                                                                                                                    *       *                 *    *             *       *            *             **                  *****                                                                                                                                                                                                                                                                                 **                                                                                                                                                                                                                *   *                                         * *      *  *     *      **           **          **                                                                                                                                                                                                                                     *     *                       *  * *  *                                                                                                                          **         **  **         **                **         **  **         **                                                *             *                                                           *  *    *  *                                              * *                                                                                                                                                             *  *     *  *                                               *  *     *  *                                                                                  * * * **   ** * * *                                             *           *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         *         *  *
                                                                                                                                                                                                                      * *                          *                                      **  * *   *                  *          ** *  *              *   *  *              * *         * ** *     **                                                                                                                                                                    * * **  * *                *****             **        ***                **     * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          ***                                           * *     * **     *           *        *  *                                                                                                                                                                      **                                                                     ***   ***               **     ***   ***                                                                                                                                                                                                                                                                                                                             *  *  *  *                                               *  *                                                                                                                                                           *    *                                                      *    *                                                                                           *  ** *   * **  *                                               *         *                                                                                                                                                                                                                                                                                                                                                                                                     **                                                                                  *         *    *                                        * *
             **              ** **                                                                 *                   ***                                                                                        **   *                          *                                         * * * ** ***            *                **** **            *  * *               **               *  ***                                                                                                                                                                      **  **   **                                              *                 *       *                   *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       **           *  *       ***             **          * *                                                                                                                                                                     *  *                                                                   ** *   * **               *                                                      *                                                                                                                                                                                                                                                                                     **    **                           ** *      ** *        **                                                                                                                                                           *      *                                                    *      *                                                                                              * *   * *                                                  **         **                                                                                                                                                                                                                                                                                                                                                                                                  *    *                                                                                **        **  **                                         **
             *   **          ** *   **            **             **         **        *            *   ***          **                                **            * *              *     *                       * **                           **                                        **   *  * *  *           **              *  * **           **   *                                 * *  *                                      *                                                                                                                                                            *                                          ***        **                 * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            *                                         **           * *         **              **                                                                **                    **                                                                                         * *  *                                                                                           * *                                                  *   *                                                                                                                                                                                                                                                                                                                      * **      * **                                  *                                                                                                                                  *      *                                                    *      *                                                                                            ** *     * **                                                                                                                                                                                                                                                                                                                                              *                                                                                                               *      *                                                                           * **      * **      ** *                                     *
              * * *               *  *       *** * *       ***  * *        * *      * * *        *  *               *   * **                       * * *           *   *            * *   **                         *                               **                                           * *   **                            **                                                       **                                        * *                                    **                                                                                                                    * *                                         *                              *                                                                                                                                                                                                                                                                                                                                                                                                    **                                                                                      * *                                                    * *                                                                                           *  *                   **                                                               * *                        *                                                                                                **                            *****                      *                                                                                                                                                                                                                                                                                                                   **    **  **    **                               ***            **                                                                                                                    *    *    *                                                 *    *    *                                                                                         * ******* *                                                                                                                                                                                                                                                                                               **     **           **     **                 * *                                                                                                              *        *                                                                          ** *      ** *      * **
                           ****** ***                                        * ** * * *               *  **          ** **                         *              *   *            *  *                              *                            *** *                                            **                                                                                                                             *    *** *     *                               *   *  *      *        **               ** **  **     **                                                              *                                                                                                                                                                                                                                                                                                                                                                                                                                                                             * *                                                                                     *   **                                                  *         *                                                                                   *                                                                                          *                        ** *                                                                    *   *                                                *    *                 *    *                                                                                                                                                                                                                                                                                                                   *     *   *     *                               *   *           **                                                                                                                     *  *     *                                                  *  *     *                 **                                                                    * *         * *                                                                                                                                       *                                                                                                                                                     **     **           * ** ** *                  **                                                                                                              *        *                                                                                                                               *
              **  *       *  * *              * *  *        * **  *       ** * *   ** * **       **  *              ** **                          * *             **             *     ***  *                                              * ** *                                                                                                                                                                               * *  *    **   * *                              * ***  ***   * *      * *               * **  * *     * *   **                                                                                                                                                                                                                                                                                                                                                                                                                                                ** *      ** *                                                                        *                                                                            **         *   **   *                                                         **                                                                                 *                                                                                      *    *  **               *     *                                                                     *   *                                                     *                  *****                                                                                                                                                                                                              **         **                                                                                         *     *   *     *                              ** **                                                                                                                                   **      *                                                   **      *                *  *                                                                 *** *  ** **  * ***                                                                                                                                    * *                                                                                                                                                                         * * * *                                                                                                                                   *        *                                                                                                              **               **
                *  *      **   * **          *    *        *     *           *  *     *                *  *       ** *   *                                                         **     * * *          **        ***      *               ** * *                                                                                                                                                                               * *  * **       *                                *   **   * *  *      *           ** ** *    **         ***  *                                                                                                                                                                                                                                                                                                                                                                                                                                                * **      * **                                                                      ** ****                                                                        **         *   **  **                                                        **                                                                                  * **                    **                                                             ** *  * **      *        *                                                                                                                                *   *                            **                                                                                                                                                                                                        **         **                                                                                        **    **  **    **                                                                                                                                                                                                                                                          *    *                                                               *     *  * *  *     *                                                                                                                                  *   *                                                                                                                                                                        * * * *                                                                                ** *      ** *      ** *                            *      *                                                                                                               **                **
                  **          ** **          **   *        **    *          * *       **          ***   *               **                          *                *                     *  *          **** *        *   **                    *   *                                                                                                                                                                          ** ** * * ** *    ***                              **   * ** * ** **  **            * * * ****  *    ****   **                                                                                                                                                                                                                                                             ***                                                                                                                                                                                     **  **    **                                         **                        * * *  *                                                                                    * *    * *                                                                                                                    **    **    ** *         **                  * **                                                                 **          *        *                                                                                                                        **        *                              * *                                                                                                                                                                                                                                                                                                              ** *      ** *                                                                                                                                                                            ***   ***                                                   ***   ***          *      *                                                               * ** * *   * * ** *                                                                                                                                   *   *                                                                                                                                                                       *       *                                                                               * **      * **      * **                             *    *                                                                                                                             **  **                   **
                                                                                                        *           ***                             *                *               *      **           * *  *** *    *                        *   **    **                                                                                                                                                                     *    * * *  ** * **     **   **   **   **   **      * **    *    *  *             *      *   * *    *    *                                                                                                                                                                                   *   **                                                                        *                                                                                                                                                                                      *   *     *             **                    **     **        * *             * *       **                                * *                                              *                                                                          * *                                                *     *    * **                             *                                                                                *                                                                                                                                **                                          *                                                                                                                                                                                                                                                                                                              * **      * **                                                                                                                                                                                                                                                           *      *                                                                ** * *     * * **                                                                                                                                    *   *                                                                                                                                                                                                                                                                   **  **    **  **    **                             **                                                                                                                                                        **
                                                                                                                                                  * **             * **              *                            *    * ***  * *               **    **   *                                                                                                                                                                     * * *     * * ** ** * **   **   **   **   **   **     * * ** * *  * ***           * *** **  **   *   ***** **                                                                                                                                                                               * *  *      **                                                                                                                                                                                                                                                         *   *     *     **     **        * *          *              *              **  *       **     **                        *                                                                                                                            **                                                *     *   **    **                           *                                                                                     ***   ***    ***                                                                                              *     *         *                                         **                                                                                                                                                                                                      ***       ***                                                                                        **    **  **    **                                                                                                                                                                              *                                                           *               *    *                                                                     *       *                                                                                                                                        *   *                                                                                                                                                                                                                                                                   *   *     *   *     *      **                                                **                                                                                                                              **
                                                                                                                                                 **               **               * **                      **   *        * ****                     *   *                                                                                                     ***                    **  **  **                                 *  ** * * ** **      **   **   **   **   **   ** ****  * * ** **      *           *    * *   ********  ***  *                                                                                                                                                                               **   *     *      **                                                        ** **                                                                                                                                                                                    **  **    **      *              *             * *             *  *         *    **             *          * *             *  *                                                         *                                                               *                                                **    **  *     *       **             **    *  *                                                ***                      ***   ***            *                                                                                                ***   ***                                                                                                                                                                                                                                                          ***       ***                                                                                        *     *   *     *                               ** **                                                                                                                                           *                                                           *                *  *                                                                                                                                                                                                                       *   *                                                                                                                                                                                                                                                                    *   *     *   *     *      *                        *                       *                                                                                                                               *
                                                                                                                                                     *                *           **   *                     *      ***        **                         * * **                                                                                                                       **  **  **                                  **   * *  *     **    **   **   **   **   **   *   **        **     **            *** *  ***        **    **                                                                                                                                                                                 *** *     *     *      **                                              **       **                                                                                                                                                                             ** *      ** *        * *             *  *          **             * * *        *****             * *             *            * * *                                                * *    * *                                                                                                                 * **     *     *      **            *  *    **                                                *                                      *       *   *                                                                                           *  ** **  *                                                                                                                                                                                **                                                                                                                                                                             *     *   *     *                              *   *           **                                                                                                                              *                                                           *                 **                                                                                                                                                                                                                        *   *                                                                                                                                                                         ** **                             **                                                      **  **    **  **    **      * *                     * *                    * *                                                                                                      **  **                  * *
                                                                                                                         *                          **               **               * *                                                                 * ** *                                                     *                    **                   *   *                                                                 ** * ** * **  *                                  *                                * *    *  * ****  *                                                                                                                                                                                    **  * *  *** *     *     *      **                                       *         *                                                                                                                                                                             * **      * **         **             * * *             ***   ***   *  *      **    *             **          *  *        ***   *  *                                                 **  **   *         **                                             * *                          *  *                       ** *    **    **                    *  *                                                      *   *                   *     *        *       *  * *                                                                    *                     ***     ***                                                                                                                                                                                 *  **  **                                                                                                                                                                    **    **  **    **                               ***            **                                                                                                                                                                                                      ***                                                                                                                                                                                                                              * *                                                                                                                                                                        *  * *  *                           * *                                                 ** *    *     *   *     *        **            *   **   * *  **   *            **                                                                                          **                **       **        * **
                                                                                        **        **             ***   *  **                         **               **             *  *                           *                                * ***                                  ** *  * **          ** *   * **          ** *    * **          ** *     * **         ** *              * **                              * ** *  * **    *                             ** * *                               *        ** *   **                                                                                                     **          **                 **                                     **      *  *** * *  * *  *** *     *     *                                         *********                                                                                                                                                                            **        **    **           ***   ***   *  *             * *   * *    **      *  **     ***   ***             * * *        * *    **                                                  *   **   *         **                                              **            ****              *                          **  *     *                    ** **                                                      *  * *         *        *     *        *         * *  *                                           **                      **                                                                                                                                                                                                               * *  *  *                                                                                                                                                                      ** *      ** *                                  *                                                                                                                                                             *                                                                 ** **                                                                                                                                                                                                                   *                                                                                                                                                                         ***   ***                             *                                                 * **     *     *   *     *                    *              **  * *                                                                                                       **               **        **
                                                      *             ** **         *   *  *        * *   **             *                            ***              ***              **                            *                                **                                     *        *          *         *          *          *          *           *         *                    *                                    **       **                              *  **                                                                                    ** **                                   *             *          *  *        *  *               *  *                                   * *     * *   * *  *** * *  * *  *** *     *     **                                                                                                                                                                                                                      *         *     *            * *   * *    **              ***   ***            ** *      * *   * *             *  *   ***   ***                                                            **   *                                                         *            *   *          *   *                           *   *     *                    **                                                          * *  *       *        *     *                   *   *                                 **       * *                     **                                                                                                                                                                                                               ** *** **                                                              **   **   **   **                                                                                        * **      * **        **                                                                                                                                                                                      *                                               *     *     *         *                                                                                                                                                                                                                                                                                                                                                                                              *     *                              **                                                    **  **    **  **    **                    *  ** *         **   *                                                                                                                        *
             **       **      **   ** **   **        * * **        * * **        * *  **              *  *        ** *   *                                                                                         ** *                                 **                                   **    **            **     **            **      **            **       **           **                **                                                                            * *                                                                                        ** **                                  * *           * *         ***  ******  ***              * * *                                   * * **   *   ** **   * *  *** * *  * *  *** *   * *                                 *********                                                                                                                                                                             *         *     *           ***   ***              **                 **         *      ***   ***     **       **    * *                                                                    * *                                                              **           *           ****                          *   **    **                                                                                 *   *       *                                      *                                 **       *                                                                                                                                                                                                                                         * * * *                                                                *****     *****                                                                                                              *  *                                                                                                                                                ** **                                *          ***                                 * *    *     *    *  **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          *   *     *   *     *                      **          *   *  *                                                                                                                                              **
             * *  *  * *      * * * **  * * *       *  * * *      *  *          *  ***  ****        *                                                                                                             *   **                                 *                                ***  ****  ***      ***  *****  ***      ***  ******  ***      ***  *******  ***     ***  ****************  ***                                                                         **                                                                                                                 *             *   *         *   *           **      **                 *  *                                     * * *    ** *      ** **   * *  *** * *  * *  *                                   *         *                                                             **         *                                                                                                  **        **    **                                  *                   *         **                    *             ***          **                                                         *                                                              * *       *  *                      **                  **  *     *             *          *                                                             *            ***   ***                      ***                                           ***                                                                                                                                                                                                                                *    *         *                                                               ***       ***                                                                                                               * *                                                                                                                                                 *                      *                                 ***                       *   *   *     *     ***                                                                                                                                                                         **    ** *      * **                                                                                                                                                                                                  **     **                                                                                    *   *     *   *     *                      ***        *   ***                                                                                                                                               **
               ****  *          * **    * *        *    *  *      **   **      *    **  *  *         ** *          * * * *                                                                                       * *                                    *                                 *  *      *  *      *  *       *  *      *  *        *  *      *  *         *  *     *  *                  *  *                                                                                                                                                                  *********                * *             *   *       *   *           *          *               *                                           *       *     ** *      ** **   * *  *** * * **                                 **       **                                                              *         *                                                                                                    ** *      ** *                          **     ** *                   * **                            * **                      *  *                                                                                                             *           *                                 * *                      *     *           * *        * *                                                         ***    ***   ***                                                                                                                                                                                                                                                                                                               * *  * *** * *** *                                                               *         *                                                                                                                 * **                                                                                                                                                **  *             *    *        ***   ***    *    ***   *              ***         * *                ***                                                                                *                                                                                         *    * **      ** *                                                                                                                                                                                                  **     **                                                                                   **  **    **  **    **
             * *  *  * *      * * * **  * * *      * * ** *          *  *      ****    ** *          **                                                                                                          *  *                                   **                                 **        **        **         **        **          **        **     *     **       **                    **                                                                                                                                                                  *    *    *              *   *             *   *     *   *            ** *    * **                * *                                       *  *     *      *     ** *      ** **   * * * * *                                   ** **                                                                *          *                                                                                                    * **      * **                         *  *    *  * **             ** *  *                           **  *    **              *  * *                                             ***                                                             * *                                             *                     **    **            *    **    *                                                                              *                                                                                                                                                   *                                                                                                                                                       *   *   ** **   *                                                  *                                   *                                                                                                     ***                                                                                                                                                 ***            *                            *         **   *                       *       ***      *  **                                                                              * *                                                                                       *   **        **                                                                                                                                                                                                                                                                                              ** *      ** *      ** *                        ***        *   ***
             **       **      **   ** **   **       ** * *        ** * *           **  * *         **  * *         *   * **                                                                                       **                                                                                                                                            ***                    **  **  **                                                                                                                   *                                                      ***   ***                *   *             *   *   *   *                  **                  *                                            *               *      *     ** *      ** *  *   *                                                                                                       ****      **                                                                                                                           **            *  * *      ** *               * **           **             *    **    *  *                 *                                             *   *                                                 **            **         **                                **                **    ** *                 *    *                                                                        *        *          **                                                                                           **                                         **                                                                                                                                                            *** *** ***                                                  * *                                 * *                                                                                                     **                           **                                                                                                                    ***    * *   **      * **          *        *   **         *        *     *                              *                                                                            *   *                                                                                      **  *          *                                                                                                                                                                                                                                                                                              * **      * **      * **                       **          *   *  *
                                                        *         ** **          *  *   *          **     *          *                                                                                                                                                                                                                                                                 **  **  **                                     **                  **        **                                             * *                                                       * * *                   *   *             * *     * *                                     ** *     **                                    *   *     *            *      *     ** *   *   ***                                    *                                                                **    *   *                                                                                                                             * *                *          *               *             * *             *****      * *  *           * **                                             *     *                                                **            **         **                                                  **    * **                 *    *                                                                        *        *      ** *  * **                                                        ***                            * *                                        * *                                                                                                                                                    *****    *     *    **                                             * **                                 ** *                                                                                                                                 **                                                                                                                   **  *   ** *      **   * *          *            *   ***    *        *     *                          ** **                                                                             *   *                                                                                          *        *              **      **                                                                                                                                                                                                                                                                                                                     *  ** *         **   *
                                                                                 **                      **      **  *   ***                                                                                                                                                                                                                                                                                                           *                  *  *      **                                           *** *                                                                                *   *             *       *                   *                 *        *  *   **                              *   *   **                    *      *     ****                                      ***        **   **                        ** *    **          ** * * ***   *    *                                                                                                                         *              * **           **   **   **   **             *             **    *       *                *                                                *   *                                                               **      **      *   **                                                                    *    *                                                                  *     *               **  *    *                                               **       *                 **             *                                                                                                                                                                                              *    *              *  *  **                                  **   ** **                                 ** **   **                                            *                                                                                                                                                                             **  **    ** *       *                 *                  *          ***                   *     *                                                                                                             *   *                                                                                    **  **        **           *    *  *    *                                                                                                                                                                                                                                                                                                                   *              **  * *
                                                                                                                   *                                                                                                                                                                                                                                                                                                                ***                    ***          *                                       *    ** *                                                                      *       * *                  *                      *  *              * *  *   *  *   *  *                             *       ** ** **                     *      *  *                       **   **                  * * * *                        * **     *          ** * * *     *                                                                                                                             **     **        *                 *  * *  *                **     **       *  **         ** *                                                              ***                                                             * *       ***     *   * *                                                                     *  *                                                                  * **                        *                                                   **       * *               **             **                                                                                                           ** **                    *                 ** **                                 *  *        *   *    * *  * *                                  **    * **                                 ** *    **                                          * *                                                                                                                                                                              *   *    * **       ** **      *    *                                        ***                                                                                                         * ** **               *   *                                                                                    *    ** *      * **       *    *  *    *                                                                                                                                                                                                                                                                                                      **            *   **   * *  **   *            **                                                                                               **
                                                                                                                                                                                                                                                                                                                                                                                                                                    *    *  *  *  *  *  *         *******                                       * **   **      **                                                             * *       *                  * *                     *  *              *  *    *     *  * *                             *  *    **    ***   ****    * *               **                       * * * *                   *   *                             **  *              *           ***                                                                                                                                **                           **   **                        **       * *             *                                                               ***                                                             *          **      *****                                                                    * *  * *                                                                    *                        * *                                                          **                                                                                        **              **            * **      ** *       *                        *        *            *                              *  * **          *     ** * **                                           * *                                 * *                                        *       * *                                                                          **                                                                                                  *   *   **    **                 *                                                           ***                                                                                         ** **  **               * *                                                                                    *     * **      ** *       *    *  *    *                                                                                                                                                                                                                                                                                                     * *                     * *                    * *                                                                                            *****
                                                                                                                                                                                                                                                                                                                                                                                                                                  * * **************************  *                                            ** * **         * *                                                           *   *                          *                        *                **    *          *                               *        *   **    ** *       *      *                                 *   *                                                      *   **          ***  **                                                                                                                                                                                                           *  * * *                                                                                                                                                           **    ***                                                                     **    **                                                                *  * *                                                                                                                                                                             **               **            ** *      * **        **  *                   *        *       *  **                              * * *     *           *   **   *                                           *                                   *                                        **      *  *           **                                                        ** *    * **                                                                                             **  **  *     *             **                 *                                                                                                                                         *                        *                                                                                     **  **    **        **       **      **                                                                                                                                                                                                                                                                                                       *                        *                       *                                                                                    **     *    *              **                                                                                                                                                                                                                 *
                                                                                                                                                                                                                                                                                                                                                                                                                                 * * *                          * * **  ***                                         * *****      *  * **                                     * * *            *   *                     *       *                                           * *    * **                              * * *                 ***   *   *    **                                                      * * *     * * *                         *             *                          *                                                                                                                                                                                       **** **                                                                                                                                                            **                                                                                                                                                      *  *                                                                                                                                                                              *****                       **        **    **       ***                             *        ***                                *  *    * *             **  ** *                                                         * *                                                          **    **  * *           **                                                        *          *                                                                                                      *     *           *  *                *                                                                                                                                                **                                                                                                          *     *          *                                     *  **    **  *                                                                                                                                                                                                                                                                    **                                                **                                                                                   **     *  ***              **                                                                                                                                                                                                               * *
                   *                                **  **                                                                                                                                                                                                                                   **    **                                                         *                 *                                                * * * *  ***  ***  ***  ***   ** *   * *  * **                              * ** ** *     *    ** * ** *                                  ***   ***           *   *      *            * *     * *                   **                      *      *                               * * **    *                      *    ** **                          * * *     * * *    *** *** * **   ** * ***                      **  **         *** *                     * *                                                                                                                                                                                          *                                                                                                                                                                                                                                                                                                                       **                                                                                                                                                **              ***             ****                        *        *     *        ***       *        ***   ***             ***                                   **  *  *         *   * *  * *                                                        *                                                   **       ***    **   * *                                                                     **      **                                                                                              **  **  **    **          *    *               *                                                                                                                                         **     **                                                                                                      **   *     *        *                                     *   ***  ***   *                                                                                                                                                                                                                                                                                                                                                                           ** *      ** *      ** *              **  *                                                                                                                                                                                                                      **      **
                  * *               **              * *  *             *             *                                                                                                                                                                                                      **  **  **                                                       * *              * *   ** **  **                                   ** *     **   **   **   **   ** *    **  * * *                                  **     ****        *    *                                 *    *    *           *   *    * *          *   *   *   *             ** *    * **                   * *                                  * *       *      *            * *     **                           *** * **   ** * ***    *   * * *     * * *                    ** *     *     * **    *   *          *      * *                                                                                                                                                                                        * *                                                                                 **                                                                                                                                                                                                                                                                                                                                                                                      **            *   *                                        *          *     *      **  *       **               ***   ***   *  **                                       **              **  ***                                                         *                                                   **        **    **     *                                                                  ***  ******  ***                                                                                            *   *  *     *          *      *                                                                                                                                                        **                                                                                                              *  **    **        **                                     *  **    **  *                                                                                                                                                                                                                                                                                                                                                                            * **      * **      * **                **                                                                                                                                                                                                                      *   *    **            **
               **  *  **           *  *                 *             * *          *****         *    *         **      **                                                                                                                                                                 *          *         **    **                             ** **   * *               * *  ** **  **   **                               * * * *  ***  ***  ***  ***  ** *** *  *  *  *                            *   * *  *   * *    ** * **** **                                *********             * *    * *          *   *     *   *            *          *                      *                                  **     * **     *      *               *                            * * *     * * *     **                                      * **    *      ** * **   ** **      ** **   ** * **                                                                                                                                                                                     **                                                                                  **                                                                                                                                                                                                                                                                                                                                                                         **     **                 *    *             ****                       **        **    **     *           *            *                     *                              **               *   *   **                                                             *  *                                                           **                                                                             *  *        *  *                                                                                           *   *    *     *         *      *          ***   ***                                                                       **                                                                    *                                                                                                      *     ** *      * **                                                                                                                                                                                                                                                                                                                                                                                                                               **        **    **  **    **                           *   *                                                                                                                                                                                                     *     *   **            **
               * **    *          * * *              *                 *          *     *        * **  **       * * ** * *                                                                                                                                                                *            *       **  **  **          ***           **  ** **  ** ** ***          *                *                                * * *                           *   *  ***  **                            *   * *  ** * ** **    * *    * *                                                      *    * *          *   *       *   *            **      **                   *  *                                         **      * **     *      *                                                                   *   *                       **        **        * *      *          *   *    ** *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    **     **                 *   *             *****                         * **    *     *      ** **                    *        *        ** **                             *  *               **   ** * *****                                                       ***                                                             *                                                                              **          **                                                                                            **  **  **    **          *    *                                                                         *                *  *                                                           **  ** **                                                                                                      **    * **      ** *                                                                                                                                                                                                                                                                                                                                                                                                                               *         *     *   *     *               **         ** * * **                                                                                                                                                                                                   *   * **    * *
                 *** **                 *       **     * *  **                   *  ***  *      * ***              **   *                                                                                                                                                                  * *      * *       *          *                      **                                                                                * * ************************* * ***                                           **   *** ** * *** *  ***   *                                 ** **                      *          *   *         *   *        ***  ******  ***               * * *                                        *    ** **      * **     *      *                                   *   *                   * * * *                      *                   * *                     * ***                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   **               **            ** *     *     *                              *        *                                     *  *  * *              **     * *  *  *                                                                                                                                   *                                                                                                                                                                                    *     *            *  *                *                                                        * *              *    *                                                           ** ** *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           *         *     *   *     *            **  *       * **   ** *                                                                                                                                                                                                  *     *       *
              *      ** *       **       *      *  * *     * *       *****        **   **         *   **       *  **   ** *                                                                                                                                                                   ******         *            *     **     **      *                      **         *****************                                  *    *  *  *  *  *  *  *  * * *    * **                                  * ** ** **             * *  * * **                              ** **                                  * *           * *         *  *        *  *               *  *                                           **  * *   ** **      * **     *                                  * * * *                  **   **                       *        **         *                          *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  *   *             **              **                **  **    **            **                         *    **                               ***** * **                    *  *                                                            ***                                                                          *                                                                                                                                                                           **  **   *     *            **                 *                                                       *   *            *      *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           **        **    **  **    **     **     *  ***     *  *     *  *                                                                                                                                                                                                  *   *
             * * *   * * *     *        * *      *       *          *   * *          **             **        * * *  * * * *                                                                                                                                                                                  * *      * *      **     **     *                       **      * *                 *                                 ***                        * *  **** *                                            *      * * * *  ** * * *                                                                       *             *           **          **                 **                                        * *   * * ***  * *   ** **      * **                                 **   **        ***                                    **         *                             **  ***                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   *    *                                               *  *     *            *  *                            *  *                                    **   *                   **                                                             *  *                                                                       ***                                                                                                                                                                            *   *  **    **                               *                                                        * *             *      *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             ** *      ** *    *     *      **     *    *      * **   ** *                                                                                                                                                                                                    **
              * **      *      * *        *         *       *       *   * *          **             **        * * *  * * * *                                                                                                                                                                                     ******          *     *       * *                    *      *                     *                                   *                         * **     *                                    ** * * **      ** * * *   * * *                                                                                                                                                                          *     * * *  * * ***  * *   ** **   *                                                *                                       ** *    *                   ***           *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         **            *   *                                              *    *     *          *    *                          *    *                               ***  **              **                                                                     *                                                                                                                                                                                                                                                        *   *     ** *                                                                                           *               *    *                                                                                            * ** **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           * **      * **     *     *             *****       ** * * **
                ** ***          *       **      * *     * *  *       *****        **   **         *   **       *  **   ** *                                                                                                        *                                                          ******                             *******          *********************       *                     *  *                              **                         *     ***                                      * ** *  *       * **  **** **                                                                                                                                                                            **** * * ***  * *  * * ***  * *   * *                                                                                       * **    **                      *     * * * **                                                                                                                                                               **   **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                **              ***                                              **  **    **         *      *                        *      *                             * *  * *   *    * *  *  *  **                                                                *                                                                                                                                                                                                                                                        **  **    * **                                                                                                            *  *                                                                                            ** **  **                                                                                                                                      **                                                                                                                                                                                                                                                                                                                                                                                **    **        **  **    **               **          *   *
               *    ** *         *              **  * *     **                   *  ***  *      * ***              **   *                             **   *                       **                         *                ** * *                                                      * *      * *        *        *        *     *                              *        **                   * **                                                        **     *                                        *    * *        *   **                                                                                                                                                                                    * **   *     * ***  * *  * * ***  *                                              ** **                                                                *    *   *** * * **                                                                                                                                                              *  * *  *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * **      ** *           *      *                        *      *                             * **  **         **  * *    *  *                                                              * *                                                                                                                                                                                                                                                                                                               *                                                           *    **                                                         **                                  *                                                                                                                                            * * *                                                                                                                                                                                                                                                                                                                                                                               *     *         *   *     *
               **  *  **           * * *                *              *          *     *        * **  **       * * ** * *                           *  *  ***                    *  *  **                    ***               * *  *                   *    **                          *            *       * *    * *                       *                               **  ** ** **  **    *                                                                                                          **    **        **   *  *                                                                                                                                                                                  *       *     *     * ***  * *  **                                            **       **                                                                 *   *    **                                                                                                                                                              **   **   **   **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ** *      * **            *    *                          *    *                               *   **   *      *    *     * * *                                              *                                   *                                                          *                                                                                                                                                                                                                        *        *                                                           *                                                       *      ***          * **                           **                                                                                                                                  * * *                                                                                                                                                                                                                                                                                                                                                                                  *     *         *   *     *                                **
                  * *              *  *              *                * *          *****         *    *         **      **                           ** *     *                   ** *   *              **  **   *              * ** *                   ***  *                            *          *       * *      * *         ***          * *  ** **  ** ** ***               ** ** **  **    *                                                                                                                                 **                                                                                                                                                                                 * ***   **      *     *     * ***                                              *         *                                                              **      ****                                                                                                                               **                               *               *                                                                                                                                                                                                                                                                                                                                                                                                                                               **     **                                                                                                                           *  *                            *  *                                 ** * **     *          ** *  *                                              * *                                 * *                                                        * * * **                                                                                                                                                                                                                  *        *          ***          *                                   *        ** **                                         * *      **          *   * *                 **     **                                                                                                                                   **                                                                                                                                                                                                                                                                                                                                                                                   **    **        **  **    **                              *    *
                   *                **              *  * *             *             *                                                                 * **** *                     * ***    *           * * * **            ** *    ***               **   * *                             **  **  **          *      *                       * *   ** **   * *                                    *                                                                                                                                                                                                                                                                                                                      *  *         **      *     *   **                                             *********                                                               *          *                                                                                                                        **     **        * *                 ** *               * **                                                                                                                                                                                                                                                                                                                                                                                                                                            **     **                                                                                                                            **                              **                                * *  * *    *   *        *  *                                          **    * **                                 ** *    **                                                  ** ** *                                                                                                                                                                                                                  *                                *                                                *                                        *   *      *       **       *                 **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 ** *      ** *      ** *                               *      *                                                                                                                                                                                                  **
                                                    **  **                                                                                         *** * *   * **               *** * *    ***              ** *             ** * * *   *             *  ** * **                             **    **                                            *           * *                              **    *  **                                                                                                                                                                                                                                                                                                               * *  **                **      *  * *                                                                                                                    *         *                                                                                                                          *              *                  *  * **             ** *  *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 **  *  *              *    *                                           **   ** **                                 ** **   **                                                                                                                                                                                       **                                                         ** **                         ***   ***    *     *        *              *****   **       ***   ***   *  **                                        *   *        **      *     * *                         *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          * **      * **      * **                              *        *                                                                                                                                                                                        ***     * *
                                                                                                                                                  *  *  *   *  * *             *  *  *    *               * *  *                * *   *  *             *      *                                                                                               *                               **    *  **                                                                        **   **                                                                                                                                                                                                                               **                             **   *                                             *********                                                               *         **                                                                                                                         * *             *  *              ** *     ***   ***     * **                                **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    **    *     *    *****                                                  * **                                 ** *                                                                                                                                                                                             **                                                         *            *       ***   ***             *     *                     **    * **  *                   ***                                        *   *          *     * ** *                     **  ** **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                *        *                                                                                                                                                                                       *   *      *
                                                                                                                                                 * *  *   * **    *           * *  *   *  **              *  *** **             *  ** ***             ** * **  *                                                                                                                                    *                                **   **                                     * * * *                                                                                                                                                                                   **      **                                  **                                                                               *         *                                                                                                                                                                                                    **             * * *                *     * *   * *     *                                  * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        *** *** ***                                                          * *                                 * *                                                                                                                       *                                                                                                                                  **  *       *                    *        *     *    ***   ***                ** ***         *        ***            **    ** *      ** *       *   *                                             ** ** *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 *        *                                                                                                                                                                                      *     *
                                                                                                                                                  *          ** ***            *                        ** **   * *            **                      * *   **                                                                                                                                     *                                * * * *                                       * *                                                                                                                                                                                    *  *    *  *                                  * *                                                                             **       **                                                                                                                                                                                                        ***   ***   *  *                **    ***   ***    **                       **       ***       **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                *   ** **   *   *                                                      *                                   *                                                                                                                        *                                                                                                                                   ***        *           *        *                                  **    **   * * *         *       *  **            *    * **      * **        * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       *      *                                                                                                                                                                                       *     *
                                                                                  **                                                               ** ** **   *                 ** ** ** **                *  * *                ********              *  ***                                                                                                                                    *  *                                  * *                                         * *                                                                                                                                                                                    * *      * *                                                                                                                     ** **                                                                                                                                                                                                           * *   * *    **                                                      **     **      *   *      **     **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         * *** * *** *  * *                                                                  *         *                                                                                                                                    * *                                                                                                                                  ***                    *        *          ***          *            * * *   **    **       *            *          *         **  **    **       *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         *    *
                                                                                 * *                         *          *                           *   *     * ***              *   *   *                * *   *                *      *             **    *                                                                                                                                      *                                   * *                                         * *                                                                                        **   **                      **   **                      **         **                   **  ***  ***  **                                *  *                                                                                                                                                                                                                                                                                               ***   ***                                                             *             ** **             *                                                                                                                                               **                                                              **   **                                                                                                                                                                                                                                                                                                                                                                                     *         *    *                                                                  ***       ***                                                                                                                                    *                                                                                                                                  **  *   ***   ***       *                                *            *** **                          ** **          **        *   *     *                                                                                                                                                                                             *  **    **  *                                                                                                                                                                                                                                                                                                                                                                                                                                         **                                                                                                                                                                                                *
                                                         **      **                * ***       *            * *        * *                          *   *      **  *             *   *   *              **    **                    **                                                                                                                                                           * * *                                 * *                                  **    *   *    **                                                                                * *   * *                    * *   * *                    * *         * *                 *      *  *      *                               * *                                                                                  *                                                                                                                                                                                                                                            **                   **                * *                           * *                                                                                                                                               *         **                                                    * * * *                                                                                                                                                                                                                                                                                                                                                                                       * * * *                                                                        *****     *****                                                                                                                                   *                                                                                                                                 *                                                         *             *  ** *    **                                            *   *     *                                                                                                                                                                                           *   ***  ***   *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         **
                                                         * *    * *             ** *  ***    * *           *  *        ** *                                       **                                                                **                                                                                                                                                          * * **                          **    *   *    **                           *    *     *    *                                                                                *       *                    *       *                    *             *                 * **          ** *                                *                                                                                  ***                                                                                                                                                                                                                                           *  **             **  *                 **                           **                                                                                                                                    **        * *         **                                       **             * *             **                                                                                                                                                                                                                                                                                                                                                                         ** *** **                                                                      **   **   **   **                                                                                                                                  *                                                                                                                                 ** **        *                                                           **   *****                                   **        **  **    **                                                                                                                                                                                            *  **    **  *                                                                                                              *  **    **  *                                    *  **    **  *                                                                                                                                                                                                                                                                                                                                                                                                                                                            **
                  * *             ** **  ** **                                     *             *        *    ** ** **  * *                                                                                                                                                                                                                                                                    * *                             *    *     *    *                            ****       ****                                                                              ** **     ** **              ** **     ** **              ** **           ** **               * *          * *                                                                                                                                                                                                                                                                                                                                                **                 ** *             * **                      ***   ***     ***   ***                                                                                                                                        *  *      **                                                   ** *          ** **          * **                                                                                                                                                                                                                                                                                                                                                                        *  *  * *                                                                                                                                                                                                                          *                                                                                                                                              *                                                                                                         *    ** *      ** *                    **                                                                                                                                                                                                          **      **                                                                               *   ***  ***   *                                  *   ***  ***   *                                                                                                                                                                                                                                                                                                                                                                                                                                                         *  **
                *** ***           ** *    * **        **   * ** *   **            *         ******         **    **   *  **                                                                                                                                                                                                                                                                      **                              ****       ****                                                                                                                          ** *   *   * **              ** *       * **              ** *             * **                 **        **                                                                                                                                                                                                                                                                                                                                 **             *  *                  *                 *                       * *   * *     * *   * *                                                                                                                                *****       *                                                              *                       *                                                                                                                                                                                                                                                                                                                                                                            **  **  *                                                                                                                                                                                                                         * *                                                                     ***                                                               **    *                                                                                                        *     * **      * **                    **                                 **                                                                                                                                                                     *    *  *    *                                                                              *  **    **  *                                    *  **    **  *                                                                                                                                                                                                                                                                                                                                                                                                                                                           * *
               *   *   *              *  *            * * *      * * *              *     *                  *  **   * **                                                                                                                                                                                                                                                                                                                                           **     ****           ****     **                                                                        * *   * *                    * **  * *                    * **  * *  ** *                                                                                                                                                                                                                                                                                                                                                                * *             ***                   * *             * *                       ***   ***     ***   ***                                                                                                                               *     *      *                                                           *                             *                                                                                                                                                                                                                                                                                                                                                                                 **                                                                                                                                                                                                                         *                                                                     *   *                                                             *  *                                                                           ***                              **  **        **    **                                                     **                                                                                                                                                                     *    *  *    *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         **
               **  * ***          ***      ***             **  **                    *    *   **             * *  *** * *                                                                                                                                                                                                                                                                                                        ****       ****             **     * *   *    *         *    *   * *     **                                                                 * *   * *                    * *   * *                    * *   * *   * *                                                                                                                                                                                                                                                                                                                                                                *                                      **             **                                                                                                                                                                              *   **       *                                                            * **                     ** *                                                                                                                                                            *   *                                                                                                                                                                                                                                                                                           ***       ***                                                                                                                                    *                                                                    *     *                                                           *    *                                                                                                               *         *     *                                                                                                                                                                                                                             *    *  *    *                                                                                                                                                                                                                                                                                                                                                                                                                                               *
             **  ***    **        *    **    *          *          *                 *   *      *             **   * *                                                                                                                                                                                                                                                                                                          *    *     *    *             *      *   *    **         **    *   *      *                                                                 ** *   * **                  ** *   * **                  ** *   * *   * **                   **        **                                                                                                                                                                                                                                                                                                                               ** *             ***                                                                                                                                                                                                                    *       *  *                                                               **      ***   ***      **                                                                                                                                                              *   *                ***   *                                                                                                                                                                                                                                                                    ***       ***                                                                                                                                                                                                         ** * **                                                          *      *              *                                                        *     *                            **   *         *     *                                                                                                                                                                                                                              **      **                                                                                                               **                                                                                                                                                                                                                                                                                                                                **
              *  **   * *            *    *               *      *              **     *     *               ** *   **  *                                                                                                                                                                                                                                                                                                       **    *   *    **             * **      *                       *      ** *                                                                  *  ***  *                    *  ***                       *  ***   ***  *                  * *          * *                                                                                                                                                                                                                                                                                                                            *  **             *  *                                                                                                                                                           **    **                                                        **                                                                         * *   * *                                                                                                                                                                                    **   *****  * *            **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            *      *              *                                                        *     *                             *  **        **    **                                                                                                                                                                                                                                                                                        ** *    **    **    ** *                                       **                                                                                                                                                                                                                                                                                                       *                       ** *                               **                                                                                                                    **   **
              * *   **  *            *    *               *      *                *     *     **             *  **   * **                                                                                                                                                                                                         ***                                                     *       *                                    * *                     *   *    *                       *    *   *                                                                   *       * *                  *                          * *             * *               * **          ** *                                                                                                                                                                                                                                                                                                                           **                  **                **                   **                 **                           **                                                                    * *  * *                           **                                *                ***                                                  ***   ***                                                                                                                                                                                    **  **   **   *            **                                                                                                                                                                                                                                                                                                                                                            ** *      ** *                                                                                                                                                                   *    *              * *                                                       *     *                            *     ** *      ** *                                                                   *                                                                                                                                                                                                                      * **     *     *    * **                                                                                                                                                                                    *       *                                                                                                                                                   ***                    *  ***                              *                                                                                                                     **   **
             **    ***  **        *    **    *          *          *           *      *   *                     * *   **                                                                                                                                                                      *        *                           *                                                      **     **                                    * *                       * * ** *                       * ** * *                                                                      ***     **                   ***                       **   ** * * **   **               *      *  *      *                                                                                                                                                                                                                                                                                                                                                                 *      ***   ***      *                * *                           * *                                                                     *  *      **    **        **   *  *                                * *             *   *                                                                                                                                                                                                                             ** *   * **           **   *  *                                                                                                                                                                                                                                                                    **         **                                                                                          * **      * **                                                                                                    *                                                               *  *                       **                                                          **                       **    * **      * **                                                                  * *                                                                                                                                                                                                                         **  *     *   **    **                                                                                                                                                                                 * *     * *                                                                                                                                                     *                  * * *                              * *
               *** *  **          ***      ***             **  **               **   *    *                  * * ***  * *                                                                                                                                                                     ***    ***                  **                                   **                         **     **                                    * *                       * *  * * *                   * * *  * *                                                                        *                            *                            * ** ** *                     **  ***  ***  **                                                                                                                                                                                                                                                                                                                                                               ** *      * *   * *      * **             *             ** **             *                                                                    *    *      *    * *        *   **                                  **       **                                                                                                                                                                                                                                        ***   ***             *   ***                                                                                                                                                                                                                                                                     **         **                                                                                        **    **  **    **       *  *    *  *                                                                              * *                                                               **                       *  *                                                 ***    *  *                                                       * ** **                                             *   *                                                                                                                                                                                                                        *   **    **  *     *                                                                                                                                                                                   *       *                                                                                                                                                     **                 * * *                               **                                                                                                                        ***
               *   *   *              *  *            * * *      * * *               *     *                 ** *   **  *                                                                                                                                                                        *  *                      *      ***                          **                          *     *                                   * * * *                   * * ** *  **                   **  * ** * *                                                                                                                                                                * *      * *                                                                                                                                                                                                                                                                                                                                     ***   ***                   *  **     ***   ***     **  *            **     **      *   *      **     **                                                         *         *    *      * ** *  *       * **  **** **                                   **     *     *                                                                                                                                                                                                                              *     *                                                                                                                                                                                                                                                                                                                                                                                               *     *   *     *      ***  ******  ***  *                                                      **                 * *                                                                                       *    *                                                      *    *                                                     ** **  **                     * ** *     *          *   *                                                                                                                                                                                                                          *    * **     *     *                                                                                                                                                                                                                                                                                                                                           **                    ***  *                                                                                                                                                          ***
                *** ***           ** *    * **        **   * ** *   **        ******         *             **  *   **    **                                                                                                                                                                     **  **                     * *   *   *    ***                                                                                        **   **                   **     *                           *     **                                                                                                                                                                *  *    *  *                                                                                                                                                                                                                                                                                                                                     * *   * *    **              **    *             *    **                    **       ***       **                                                               * *        *    *     ** * * **      ** * * *   * * *                                    *    **   **                                       ***                     ***                                                                                                                                                                                 *   ***                                                                                                                                                                                                                                                                                                                                                                           *     *   *     *       *  *    *  *     *                                                     * *                 *    **                                                                                 *      *                                                    *      *                                                    *                         * *     *      **        *   *                                                                                                                                                                                                                          **    ** *    **    **                                                                                                                                                                                                                                                                                                                                            *                     * **                                                                                                                                                            *
                  * *             ** **  ** **                                *             *             * *  ** ** **    *                                                                                                                                                              **                **              **  *     *  ***                  ****                          *****                                                                     **                         **                                                                                                                                                                        **      **                **  ** *           *               *                                                                                                                                                                                                                                                                                  ***   ***   *  *               *****             *****                                 * *                                                                      * ***        **              *      * * * *  ** * * *                                                                                          *                   *                                                                                                                                                                                   **   *  *                                                                                                                                                                                                                                                                                                                                                                         **    **  **    **                      ***                                                **      *                     * *                                                                                *      *                                                    *      *                                                           **                 *       **       *      *   *                                                                                                                                                       *                                                               ** *          **  *     *                                                                                                                                                                                                                                                                                                                                             * *                    **
                                                         * *    * *             * *    ***  * **           * **        *  *                                                                                                                                                                *      **        *                  *       *                     *    *                        *     *    ***                                                                                                                                                                                                                                                                                             *  * **          * *             * *                                                                                                                                                                                                                                                                             **             * * *               *    **         **    *                                  **                                                                   * **    *              * ** ** **             * *  * * **          *                                                                          *   *                   *   *                                                                                                                                                                              **   **   *            **                                                                                                                                                                                                                                                                                             **                                                             ** *    *     *                                                                      ** *  *  *  *          *     **      *       **                                                                       *    *                                                      *    *                                                     **     **                 * *   *          **      * *                                                                                                                                                       * *                                                              * **           *   *     *                                                                                                                                                                           * *                 * *                                                                                                                                           **                     *    *  **
                                                         **      **             *       *** *               * *        * *                                                                                                                                **                               * *   *  *     * *                  *       *                    *      *                      *       *  ***                                                                                                                                                                                                                                                                                             *       **        * *             * *                                                                                                                                                                                                                    **          **                                          * *             *  *                 **  *           *  **                                                                                                **      **   ** *                 **   *** ** * *** *  ***   *             ***     *                        *                                        * *  *                   *  * *                                                                                                                                                 **                           *****  * *            **                                                                                                                                                                                                                                                                                              *                                                             * **     *     *                                                                     **  **      *           *   *  *  *  *       **                                                               *  *     *  *                                               *  *     *  *                                                      **                           ** *          ***      *                                                                                                                                                       *   *                                                           **              *   **    **                                    *  *                                                                                                                                      *               *                                                                                                                                                                         *   **  **
                                                                                            * *              *          *                            **                                                       ****                                         *  *                             **  *    *   * *                   *       *                   *        *                 *  *         *                                                                                                                                                                                                                                                                                                 **      *       *** **           ** ***                                                                                                                                                                                                                 *  *        *  *                                         *              *                       * *           * *                                                                                                 * *         ** * **           *   * *  ** * ** **    * *    * *                *   *                        *                                       *  * *                       * *  *                                                                                                                              **               * *                            ***   *                                                                                                                                                                                                  **                                                                                                         * *     **                                                        **  **    **                                                                              * *          ***    **      *                                                                      *  **  *    **                                              *  **  *    **                                                               *                                  **                                                                                                                                                               *   *                                                           *               **  *     *                                   * *  * *                                                                                                                                   *    *       *    *                                                                                                                                                                        *       **
                                                                                            **                                                    **** * **           ****             ** **** **           ***  ***                                       * * *                               *      * **                  **  *     *  ***            ** *        * **            *  * *    *    *                                                                                                                                                                                                                                                                                                          *     *                       *                                                                                                                                                                                                                ***  ******  ***                                        **     **        * *                    * * *  * *  * * *                                                                                           ** *  *      ***** *                *   * *  *   * *    ** * **** **                **   ***                      *                                       *   *          ** **          *   *                                                                                                                              **                 *                                                                                                                                                                                                                                    *  *                                                                                                         **     * *                                                       *   *     *                                                                               **                       * *                                                                       *  **  *                                                    *  **  *                                                             **  ** **                                                                                                                                                                                                   *   *                                                            *                   *     *                                   **  **                                                                                                                                *       *  *   *  *       *                                                                                                                                                                     ****
                                                                                                                                                 * **  * **        ****  ****         * ***  *** *          ***  ***           ** **** **** **** **** **** *  *                                *      *                    * *   *   *    ***           ** *        * **            *    *   * *   *                                                                                                                                                                                                                                                                                                 **      **      *** **           ** ***                                                                                                                                                                                                                    **      **                                                  **                                ** **** **** **                                                                                           * ** * **    *     * ** ** *    **        **     ****        *    *                                                                                        *               * *               *                                                                                                                                               ***                                                                                                                                                                                                                                   * * *                                                                                                  *                *           * *                                         *   *     *                                    *  *    *  *                                                       **                                                                          ****                                                        ****                                                                ** ** *                                                                                                                                                                                                    *   *                                                           **                  **    **                                                                                                                                ** *      ** *      ** *                * **      ***   ***      ** *                                                                                                                                                               **                                                                                                                                                            **
                                                                                                                                                  *    *          * **    ** *         ***    ***         * *      * *        * ***  * *  * *  * *  * *  * *                                **  *    *     **              *      ***                      *        *               *  * *    *    *                 ** *                                                                                                                **                                                                                                                                                           *  ** *          * **           ** *                                                                                                                                                                                                                     *          *                                                                                     *         *                                                                                             *    *        ****     **      *  *    * ** ** *     *    ** * ** *                      *                      ***   **                                    ***          * * * *          ***                                                                                                                                                                              *                                            **                     ***                                                                                                                                *** *                                                                                                 * *             *  *          *  *    *                                   **  **    **                                  ***  ******  ***                                                                                                                               * *  * *                                                    * *  * *                                                                                                                                                                                                                                                                         *   *                                                             ** *          **    ** *                                                                                                                                  * **      * **      * **                *         ***   ***         *                                                                                                                                                              *  *                                                                                                                                                           **
                                                             *                                                                                        **           *        *                             **        **         ***   ***  ***   *    *    *                                * *   *  *      *              **                                *      *                  *  *         *                 * **                                                                                                                *                                                                                                                                                           *   * **                 *   *                                                                                                                                                      *          *                                                          ** *    * **                                                                                     * *     * *                                                                                           ** **** * **    * *   *  * *   *  **            * *****      *  * **                       *                        *   *                                                  **   **                                                                                                                                                                                    *    *   *                                        *    *                  ***                                                                                                                                 ***                                                                                         **      **                   *         **     **                                ** *      ** *                                      *  *    *  *                                                                                                                                 **    **                                                    **    **                                                                                                                                                                                                                                                                         *   *                                                             * **          **    * **                                       **                                                                                             **        **  **    **             **                           **                                                                                                                                     **                       **
                                                           * *                                                                                                                                                                                                                             *      **        ***                  *   *                       *    *                       *       *  **            **            **                **              ***                **                **              *                 *                                                                                                                                                          **      **                * *                                                                                                                                                      * *        * *                                                              **                                                                                           **     **                                                                                           * *    * *    ** ** * **  * *   *           ** * **         * *                            *                        *     ***                                                                                                                                                                                                                                        * *         *                 ******                      *                                                                    *                                                                        * *                                                                                                *   *    **                * *        **   *        **                           * **      * **                                                                                                                                                                                                                                                                                                                                                      * ** **                                                                                                                                                                    * *                                                                                                                             **                                                                                             *         *   *     *                                                                                                                                                                                  **
                                                          *    *                                       ***              **                                                                                                                                                                **                  *                 *     *                       ****                         *     *   * *           *             **               *  *                 *              *                * *             * *             *** *                                 *                                                          **                                           **                      *                ** **                                                                                                                                                      *          *                                                                        *                                                                                                                                                                                       *   ***  * *** * ** ***   **                 * **   **      **                                                              *                                                                                                                                                                                                                   ***                   **   *     *                *     *                *     *                                                                  ***                                                                           *                                                            *     *                           *     *   **                **           **          **                                                                                                                                                                                                                                                                                                                                                                                              ** **  **                                                                                                                                                                    *                                                                                                                                                                                                                              *         *   *     *                    **             **                                                                                                        *
                                                          *****                   **                                    * *                                                                                                                                                                     **  **                          *******                                                     *****      *            *                             ****              * * *              *               *           ** * * * **        *  * *                                **                                      **                                                                               **       *             *  * *  *                                                                                                                               * * *                                            * * *                                     *            **                                                                                                                                                                                    ** * *  * *             ** ** ** *              *    ** *                                                                                                                                                                                                                                                                         **                 *       **    *           ******                      *                 ******                                 * **      ** *       **         *                                                                          *  *                                                             **   **                 **        *   * **    * *       **         *        *  *                                                                                                                                         ***                                                                                                                                                                                                                                                           *                                                                                                                                                                                                                                                                                                                                                                                                          **        **  **    **                    **             **                                                                                                        ***                                  *
                                                               *                  **                  *  **         *** *                                                                                                                                                                        *  *                                                          **                                      **          **            *              * *  * *        *   *  *            *** *            ** *          ** * * * *       *  * * * **                            * **              ***                                       *   *                     **                 *   *             *      **            * * * * * *                                                                                                                              * * *                                            * * *                                     **                                                                                                                                                                                                  * * * **  * * * *      *              **        *** *                                     **   **    *                                                                                                                                                                                                                           **               * *       **    **                                *    *                                         ***             ** *      * **        *         **                                                                        * * *   **  * * **                                                **   **                 **        *     *       *       * *      **          * *                                                                                                                                        *   *                                                                                                                                                                                                                                                                 **                                                                                                                                                                                                                                                                    *  **    **  *                                    *  **    **  *                                                          ** *      ** *      ** *                                                                                                                                                  *                                * *
                                                            **                                                     ***  * **                                                                                                                                                                  ***    ***                          ***                          **                            *   **                  ** *       * *            *        *       * **     *       * *  * *           * * *  *          *   *  *      ** *   *  *                           ***  *             ***                  *   *               *    *                                       *    *            *   ** *              **  * *  **                                                                                                                              *   *    *   **  **     **  **     **  **   *    *   *                                           ***  ***  * *                                                                                                                                                                                 * * *   * * * **      ** * * **     *    *        * *                                     *     *     **                                                                                                                                                                                                                                          **             * *                                  **                                            ***          **              **      * *                                                                                 *  *    **  * * **                                                 *   *                             *   *                  *       **                                                                                            *                                                      *     *                                                                                                                                                                                                                                                         **     **                                                                                                                                                                                                                                                                   *   ***  ***   *                                  *   ***  ***   *                                                         * **      * **      * **               **                           **                                                                                                   **                               *  *
                                      **  *                 * *                 ****                ** *  *             *                                                                                                                                                                     *        *                          *  *                                                      **   *                   * **       *  *  **       *        *       *     ** *       ** * * * **        *   * * *         *    **        * *    **                              * * *            ***                  *    *             * * *                     *   *              * * *              **  * **                  * *                                                                                                             ** *    **    **      * *     ** *** *  *   *  **  *   *  * *** **     * *                                  * *  ***  ***    * ****                                                                                                                                                                                  ** ****  ** *       *  * ** *      *    *         *                                                 **       **                                                                                                                                                                                                                                                                                                                                                  *              *        **                                                                                  **          *                                                                                        **                    **                                                                                                    *                                                      ** * **                                                                                                                                                                                                                                                         **                                                                                                                                                                                                                                                                           *  **    **  *                                    *  **    **  *                                                              **  **              **         *    *         ***   ***         *                                                                                                                                    *  *
                                      * * *                                     *   *                   *                *                                                                                                                                                                                                          **                                                            ***              **    **         * **        * *  * *          *  *   *          *   *  *       **   *  *           ****          * *****                                 * * *        ***                       * * *     **    * * *                      *    *            * * *                                          *                                                                                                              * **     *     *     *   *    *   **  **     **  **     **  **   *    *   *                                 **** *   *   *       **                                                                                                                             **                                                          **   *        * *    *      *    *                                                 *   *             * *                                                                                                                                                                                                                                                                                                                                                 *                *                                                                                                  **                                                                                                       *                      **         **                                                                            * *                                                                                                                                                                                                                                                                                                    *                        *                                                                                                                                                                                                                                                                                                                                                                                                  *   *               *         * *   * **      ***   ***      ** *
                       **                 *                 *                      * * **          **   *              *                                                                                                                                                                                                                                                                            *              *     *        **              ****           * * *              *    *         *    *                 *           *    *                                  *  ***      ***                        * * *      * *    *                         * * *     **  *    *                                                                                                                                                              **  *     *      * * *                                            * * *                                 **         *                                                                                                                                 **     **        * *                                             *  *   **        **    **      *  *                                                   ***                *                                                                                                                                                                                                                                                                                               **     **                                         **              **            *                                                                                     **                                                                       *                                **                   *  *       *  *                                                                            *                                                                                                                                                                                                                                                                                                    * *               **  ** **                                                                                                                                                                                                                                                                                                                                                                                                   *   *               *        * *    *       *  *   *  *       *                                                                                                                              * *    *  *                                                    **                                                                                                                                                                                                                              **
                      * *               *                  *                     * * * **                                                                                                                                                                                                                                                                                                                           *     *                       *  *            *                  ****           ****             *****             ****                                    ** *       ***                         *    * *    *   *                           * * *      * *   *                                                                                                                                                               *   **    **     * * *                                            * * *                                            *                                                                                                                                  *              *                                                **                           * *  * *                                                                        **                                                                                                                                                                                                                                                                                          **     **                                           * **      ** *              * *                                                                                           **                                                             *  *                              **                    ***         ***                                                                            *                                                         *                                                                                                                                                                                                                                         *   *               ** ** *                                                                                                                                                                                                                                                                                                                                                                                                   **  **              **     ** * **       *    *       *    *                                                                                                                                 *         **                                                   *  *                                                                                                                                                                                                                             **
                                        *                  *                     *   *            **                  **                                                                                                                                                                                                                                                                                           **    **                        **               ***                                              *                                                          **   *                                 *   *  **                                   *    * *                                                                                                                                                                         *    * **                            *                                                                            *                                                          **                                     **                               * *             *  *                                                                         **    **                                                                      *  *       *                                                                                                                                                                                                                         **                                                                                                           ** *      * **             *                                                                                              **                                                             *  *                                                       *********                                                                               *                                                        * *                                                                                                                                                                                                                                         *   *                                                                                                                                                                                                                                                                                                                                                                                                                    ** *      ** *      ** *       * **    *      *               *                                                                                                                             **  *    *                                                          *
                    * *               *                  *                     **   **                                                                                                                                                                                                                                                                                                                               ** *                                                              **             **               *                 **                                     *    **                                             **                              *   *  **    **                                                                                                                                                                **    ** *                          ***         ***                                                                *                                                          **     **                     *        **     **                         **             * * *                                                                                                                                                     *       **   *                                                                                                                                                                                                       **               * *                                                                                                              **  **                  *                                                                                                    **                                   *       ***   ***   *                                           * *          *  *****  *                                                                              *                                                        * *                                                                                                                                          **                                                                                              *   *                                                                                                                                                                                                                                                                                                                                                                                                                   * **      * **      * **           *** *   * *                 * *                                                                                                                          ** *  * **  **                                                      *
                                      *                 *                                        **                  *                                                                                                                                                                                                         **  **  **                                                                            * **                                                              **             **              **                 **                                          *                                  **                                                                                                                                                                                                                     ** *          **                       *       ***       **                                                            *                                                                 *                    ** *              *                      **      ***   ***   *  *                                                                                                                                                     *      *     *                                                                                                                                                                                                       **                 *                                    *                                                                          *  *                    **   **                                                                              ** **   **    *  *                                 *  *     * *   * *                                               **           **  ***  **                                                                             * *                                                        *                                                                                                                                           **                                                                                               *   *                                                                                                                                                                                                                                                                                                                                                                                                                                                     *                                                                                                                                                            **       *                                                      * **
                  * *               *                   *                     **                                                                                                                                                                                                                 **      **                    **  **  **                      *      *                                                                                                                                                                                                                                                                                              **                                                                                                                                                                        * **           *                       **       ***       *                                                                                                              *             * *                   *                * *                     *  *     * *   * *    **    *                                                                                                                                                 *       *****                                                                                                                                                                                                                         ***                                   **                                                                         *    *                        * *                                                                             ** **   **  *  * *                                 *  *     ***   ***   *                                            *                                                                                                    *                                                                                                                                                                                                                                                                                                       * *                                                                                                                                                                                                                                                                                                                                                                                                                                                       ***  **                                                                                                                                                              * *                                                      **
                                    *                 *                      *                  **                  **                                                                                        **** **** ****                                                                      *      *              **                    **             ***      ***                                                            **                                                                                                                                                                                                                                                                                                                                                                                                      **              *                            ***         ***                                                                                                             ** *            **                   * *  *            **                    *  * *     ***   ***        ***                                                                                                                                          **      *  *                                                                                                                                                                                                                                                                       * *                                                                        **  **               **         *                                                                                             *                                    *                 *  *                                                                                                                                               *                                                         **                                                                                                                                                                                                                                             *                                                                                                                                                                                                                                                                                                                                                                                                                                                           *                                                                                                                                                                  **
                * *               *                 **                     * *                                                                                                                                *  * *  * *  *             *           **   *   **                                                       *  * *              * *  *           *            *                                                      *  *  *                                                                                                                                                                                                                                                                                                                                                                                                      *               **                                       *                                                                                                              *                                     *  *                                        *                      *                                                                                                                                 **         * *        **                                                                                                                                                                                                                                                                                                                                              * **      ** *            *         **                                                                                        * **                                                       *  *                                     * *                          *  *                                                                                                                                   **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ** * * *      *       *                                                                                                                                                                                                                                                                                                                                                                                                                                                        **
                                  *                                   **   *                   **                  *                                                                            ****        ***  ***  ***  ***          ***          **  ***  **                                 **********            ***                    ***           *  ***  ***  *                 **         **                        ******                                                                                                                                                                                                                                                                                                                                                                                                        *                       * * *                                            * * *                                   *                                                    * *  *                    *             **                       *             * **                       **                                                                                                                                **         *                                                                                                                                                                                                                                                           **                                                                                             ** *      * **         ***                                                                                      **             *                                       *                   *                                       **            ****              *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           **                                                                                                                                                                                                                                                                                                             ** * * ***   * *     * *                                                                                                                                                                                                     **                                                                           **    * **      ** *    **    **    ** *                                                                                                                             **
              * *               *                  *                  *  **                                                                                           **   **   **              *  *        *                *        *** ***          *** ***                                  *          *              **                **             ** *  *  *  * **               *  *       *  *                                                 **        **                *     **                 **      **             *      **                                                                                                                                                                                                                                                                                              **                       * * *                                            * * *                              ****   *    *      *                                      *  *                    ***                                    ***              *                                                                                                                                                                     **                                                                                                                                                                                                                                             ***           **                                                                                                                    *                                                                                        ***                                                  *  *                                                          *            *   *          *   *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           **                                                                                                                                                                                                                                                                                                                 **    *   *       *                                                                                                                                                                                                      **                                                                            *    ** *      * **     *     *    * **
             *                  *                **                ** *                       **                  **                             ** **               *  * *  * *  * **        ***  ***      *                *        *     *          *     *                                 *            *          **   ****************   **         *   *        *   *              ***  *****  ***                         ** ***                  * *      * *               * *    *  **              * *     *             * *     *                                                                                                                                                                                                                                                                                                 ** *          **       *   *    *   **  **     **  **     **  **   *    *   *                                 *   *    *    *   ****                                  **          ***       *                      ***   ***       *                                                                                                                                                                                                                                                                                                                                                                                                                     **                 *                           ***                                                                                                                                                                                            ** *                                                 *  *                                                              **           *           ****                                                                                                                                                                                                                                          **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    ****                                                                                                                                                                                             **                                                                                                 *   **              **  *     *   **    **                                                                                                                            *
             **               *                                    ** * **                  *                                                    ** *                **** **** **** *         *      *      ***            ***       **     **        **     **                            *  *              *  *      * **                  ** *       ***   * ****** *   ***               **     **                            ** *  *                   *      *                 * *     * *                 *  ** *             * *  ** *                                                                                                                                                     **  **    **                                                                                                                                * **          **        * *     ** *** *  *   *  **  *   *  * *** **     * *                                      *   * *   *   *                                                 * *       **                     * *   * *       **                   ***                 ***                                                                                                                                                                                                                                                                                                                                                                          **               * *                           *                                                                                                                                                                                                * *                                                 *                                                               * *       *  *                            **                                                                                                                                                                                                                            *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     *                                                                                                                                                                                                **                                                                                                 **   *              *   **    **  *     *                                                                                                        **   **             * *
                              * * *             *                      *   *                 * *                 *                                  *                               *         *      *        *            *        **       **      **       **                           ** *   ** ** **   * **        *                    *        *       ********       *             *         *                                 *  **             * **    ** *              ** **   ** *               * **   *           ** * **   *                                                                                                                                                       *   *     *                                                                                                                                                       *   *    *   **  **     **  **     **  **   *    *   *                                  *       *    *                                               ***   ***                              ***   ***                            * *                 * *   **                                                                                                                                                                                                                                                                                                                                                                                      **                             *                                                                                                                                                                                              *  *                                                                                                       *           *                                       * *                                                                                                                                                                                                               *         * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      *                                                                                                                                                                                                                     *                                                                                *                *    * **     *     *                                                                                                                           * *
                              *  **              *                      ****              ** * ***             * *   *                              * **** **** ****                * **      ***  ***      ***            ***       **     **        **     **                               *   ** ** **   *         *  *                  *  *      *  ***            ***  *             ** *   * **                           *    ** * *           ***          ***             *         * **          ***                  ** *                                                                                                                                                             *   *     *                                                                                                                                                        * * *                                            * * *                                   **     *       *                                            * *                                **                                       ***                 ***   **                                                                                                                                                                                                                                                                                                                                                                                                                                                 *   *                                                                                                                                                               **                                                                                                        * *                                                   *                                                                   **                                                                                                                                         * *        **                                     *                                                                                                                                                                  **          **                                                                                                                                                                                                                                                                                                                                                                                **                                                                                                                                                                                                                   ***                                                                            **  **              **    ** *    **    **                                                                                                        *   *               *
                                               ***                                           *    *              * *  *                            ** *  * *  * *  *               ** **        *  *        *                *        *     *          *     *                                *              *         ***  ****************  ***     ** *   *          *   * **                 *                               * *      *            *   * *    * *   *          *  ***    ***  *         *   * *  *               ** *  *                                                                                                                                                       **  **    **                                                                                                                                                       * * *                                            * * *                                         *      **                                             ***       ***                     * *            ***                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     *   *                                                                                                                                                                                                                             *   *                            **            **         **                                      **                                                                    *                                                                                                                              **       * **                                              ***                                                                                                                                                                *  *        *  *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               **                  *        **  *                                                                   *    * **      ** *          **  *     *                                                                                                          ***
                                                                        **                 * * ***            ** * *  *                                **   **   **                             ****        *                *        *** ***          *** ***                                *              *            **                **           *   ***      ***   *                                                    *  *  ** **            ***          ***           ** *         *            ***                  ** *                                                                                                                                                                   * **        ** **                                                                                                                                                                 *          *                                                                                                                **            * *      **             *              * *      **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              **   **                           **            **         **                                                                                               **            *                                                                                                                            * *      ** **                                             *****                                                                                                 **                                                            ***  ******  ***                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               ** *                **   **  **   *        *                                                        *     ** *      * **           *   *     *                                                                                                         ***
                                              ******                    **                  ** *                 *  *                                                                                       ***  ***  ***  ***          ***          **  ***  **                          **  *   **    **   *  **     **                      **        **  ***      ***  **                  **                                    * ** *               * **    ** *                * **   ** **             * **   *           ** * **   *                                                                                                                                                      **    ** *        ** **                                                                                                                                                                * *        * *                                                       **        **                                           * *            ***      **            **     **       ***      **                                                                                                                                                                                                                                                                                                                                                                                                                                          *     *                                   **                                                                                                                                                                                                                                        **   **                                         **      **      *   **                                                                                      **    *       *        **                                                                                                                 *      *** * **                                            **   **                                                                                                **                                                               **      **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     *                     **       *      ***                                                        **        **  **              *   **    **                                                                                                                         ** * **
                                                   *                                                            **                                                                                            *  * *  * *  *             *           **   *   **                          **  *   **    **   *  **     * ** *              * ** *            ************                     *                                    **     *                 *      *                  * *     * *                *  ** *             * *  ** *                                                                                                                                                      *        **       * *                                                                                                                                                                  *          *                                                        *          *                                           *                                            **                             **   ***                 ***                                                                                                                                                                                                                                                                                                                                                                                                  ***   ***                                 **     ** *   * **                                                                                                                                                                                                                         *     *                                      * *       ***     *   * *                                                                                   **     **        *        **                                                                                                        **       *  *  *  *  * *         **                                  *****                                                                                                                                                                 *          *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    *                          ****      *                                                                      *  *               **  *     *                                                                                                                          *     *
                                               * *                                                                                                                                                            **** **** ****                                                                  *              *           *                    *              ************                     *                                           **              * *      * *               **  *    * *              * *     *             * *     *                                                                                                                                                     *          *     * * * *                                                                                                                                                                                                                                     **********                                           **      **                                                                   **   * *                 * *                                                                                                                                                                                                                                                                                                                                                                                                 *  ** **  *                                  *     ***   ***                                                                                                                                                                                                                                                                       *          **      *****                                                                            **     ***     *  **    *                                                                                                                   **       *      **    *          *  *                                *   *                                                                                *                                                                                ** *    * **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          ***               **                   *  *                                    **    **                                                    **        *    *                   *     *                                                                                                                          *   *
                                                 *                                                                                                                                                                                                                                        **  *   **    **   *  **     *  * *              * *  *        **  ***      ***  **                 ***                                                         **        **                  **     *               **      **             *      **                                                                                                                                                    **        *      * * * *                                                                                                                                                                                                                                  ***  ******  ***                                                * *                                                                       ***                 ***                                                                                                                                                                                                                                                                                                                                                                                                 ***     ***                                         *     *                                                                                                                                                                                                                                                                                      **    ***                                                                             **      **      ***** **                                                                                                                              * *                                                           *                                                                                 *                ***                                            *                     **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           **               *    *              *  *  **               **                                           *                                                      *        **  **                  **    **                                                                                                                           ***
                                                                                                                                                                                                                                                                                          **  *   **    **   *  **     ***                    ***        *   ***      ***   *                 *                                                                                                                                                                                                                                                                                                              **     **   **                                                                                                                                                                                                                                  *  *  ****  *  *                                                 **   ***                                 **   ***                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 **                                                                                               **    *                                                                                                                                     **                    *  *                   *  **    **    *                                                                                  *           **  * **                                            ***                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              *  *              **   *               * *    *  *                                                       * *                                                     *     * **      ** *          **    ** *
                                                                                                                                                                                                                                                                                              *              *            **                **        ** *   *          *   * **                                                                                                                                                                                                                                                                                                                   **                                                                                                                                                                                                                                                         **          **                                                       * *                                 **   * *                                                 *                                                                                                                                                                                                                                                                                                                                                                                                                                  **                                     *                                                                                                                                                                                                                                                                                                                                                                      **                                                                                                 **    ** *      ** *                                          *  *                   *   ***  ***   *  ***                                                                      **      **          **  **                                                 *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              **                     *     * * *                                                      **                                                      **    ** *      * **          **    * **                                                                                                          *     *
                                                                                                                                                                                                                                                                                              *              *         **   ****************   **      *  ***            ***  *       **         **                                                                                                                                                                                                                                                                          **                     *                                                                                                                                                                                                                                                                                                                              ***                                      ***                      **                       ** *                                                                                                                                                                                                                                                                                                                                                                                                                                 * *                          **        **                                                                                                                                                                                                                                                                                                                                                                                                                                                                         *    * **      * **                                 * *      * *                     *  **    **  *   *                                                                       * *         *            **                                                **                       **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    *  *              *  *                     ** *  *                                                                                                                                                                                                                                                                ***     *
                *                                      **                  **                                                                                                                                                                                                                 *   ** ** **   *         * **                  ** *      *       ********       *      *  *       *  *                                                                                                                                                                                                                                                                        * *                    *         **                                                                                                                                                                                                                                                                                                                                                                                       *                      *                                                                                                                                                                                                                                                                                                                                                                                                                                     *                           *  *     * ***           **                                                                                                                                                                                                                                                                                                                                                                     *                                                                                    *         **  **    **                                **       *                                        *                                                                      * * **  *    *                                                                                      **                         **    ** *    **    **                                                                                                                                                                                                                                                                                                                                                                                                                                                                      *  *              **        **            *  *                                                                                                                                                                                                                                                                   ***   ***
               **                                     *                **  *    *     *       *     *                                                                                                                                                                                      ** *   ** ** **   * **        *                    *         ***   * ****** *   ***       ***  *****  ***                                                                                                                                                                                                                                                                        *                      **        **                                                                                                                                                                                                                                                                                                                          * *                                      * *              ***        ***   ***     * *  *                                                                                                                                                                                                                                                                                                                                                                                                                                                            *** **        **          **                                                                                                                                                                                                                                                                                                                                                                      *                                                                                   **        *   *     *                                 *                                                                                                                         * * *       *                                                                                                                  *    * **     *     *                                                                                                                                                                                                                                                                                                                                                                                                                                                                       * *                    ** *  * **     *    *                     **
               **                                        *             * * *  **  * *  **   **  * *  **               **                                                                                                                                                                   *  *              *  *      *  *                  *  *         *   *        *   *            **     **                                   *           *                                                                               **           **                                                                                                                           ** ****                                                                                                                                                                                                                                                                                                                                                **         *                             **         *             *    **    * *   * *     *  *                                                            *                                                                                                                                                                                                                                                                                                                                                                                                  * **        **                                                                                                                                **                         **                                                                                                                                                                                                                    ***                                                                                              *   *     *                                         **                                                                                                                 *     ***                                                                                                                   *   **    **  *     *      ** *   * **                                                                                                                                                                                                                                                                                                                                                                                                                                                        *                     *    *  **     *****                 **  *  *                                                                                                                                                                                                                                          **   **
               *     *   * * * *   * * * *   * * * *   **                * * ***  * *  *** ***  * *  ***    *     *    *  **                                                                                                                                                                   *            *          ***  ****************  ***          ** *  *  *  * **            *         *                                 * *         * *                                                                              *  *       *  *                                                                                                                          * * *  *                                                                                                                                                                                                                                                                                                                                                 *     *  *                               *     *  *                  *  *   ***   ***      **                                                            * *                                                                                                                                                           **                                                                                                                                                                                                                                     *          *                                               **                         **                                                      *                         *                                                                                **                                                                                                                                                                                                                         **        **  **    **                           *             **                                                                                                               *  *                          *                                                                                               **  *     *   **    **     *  *   *  *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  *                             *  *    * *                                                                                                                                                                                                                                          **   **              *
                   * * * *     * * *     * * *     *                    ** *  **  * *  **   **  * *  **   **  * *  **  * * *                                                                                                                                                                    *          *              **                **              *  ***  ***  *             ** *   * **                                 * *           **            **    **                                            *     *       *****   *****                                                                                    **                                     * * *                                                                                                                                                                                                                                                                                                                                                 ***     * * *                            ***     * * *                  * * *             **                                                                * ***                                        **                                                                                                               **                                                                                                                                                                                                                                                                           * **    **    **      *                         *                                                       * *                     * *                                                                                ***                                                                                                                                                                                                                         *    ** *    *     *                            **                                                                                                                                *                          *                                                                                                    *     *    * **        ***   ***                                                                                                                                                        *           *              *           *                                                                                                                                                                                                                                                 *      **                      * *             *               * * *     *                                                                                                                                                                                                                                                               *
             *****     *    *    *    *    *    *    ******                *    *     *       *     *    ***  * *  *** * *                                                                                                                                                                       **********              *                    *             *            *                  *                                      *             *            *  *  *  *                                           **   **            * *                      ** *                                                                *                     **            **  **                                                                                                                                                                                                                                                                                                                                                  *       *  *                             *       *  *                    *  *             * *                                                            * **    *                **    **        **   *  *                                                                                                   *           **                                                                                                                                                                                                                                                *                          ** *     *     *      * *                     * *                                  **                    **            **       **                                                                   *               ** *                                                                                                                                                                                                                     *     * **     *     *               * *        * *                                                                                                   **  ** *      ** *       *   *                          *                                                                                               **  **    **    ** *                                                                                                                                                                        * *         * ****      **** *         * *                                                                                                                                                                                                               ** *      ** *      ** *        ***     **                                     * *               *  * **                                                                                                                                                                                                                                                                  ***
             *    *    ******    ******    ******         *                **                             **  * *  **  * **                                                                                                                                                                                              ** *              * **              ***      ***                                                         ** *          * *           *   **   *              **                **         **   **         **** ****                   * **       **            **      **                    **          *                  **  *            *    *                                                                                                                                                                                                                                                                                                                                                            **                                       **                         *              *                                                    **      **   ** *                 *    * *        *   **                                                                                                    * *           *                                                                                                                                                                                                                                                **                       **        *     *        **       **            **                                    *                                 *                                                                            * *    ***        *  *            *                                                                                                                                                                                                        **  **        **    **               *   *                                                                                                             *  * **      * **       *   *     *                   **                                                               *                                *    ** *          **                                                                                                                                                                       *         * * ***      *** * *         *                                                                                                                                                                                                                * **      * **      * **       *** *                                            *                   *  *
              * *                                     * *                                                   *     *    *                                                                                                                                                                          *      *                                                     *      *                                                              *             *        **   *  *   **         *  * *               **          *   *         *  *   *  *                **    **      *            *        *                    *          * ***               * * *            *****                                                                                                                                                                                                                                                        **         **                                                                                                                                                         * *        **     **                                                  * *         ** * **                * ** *  *       * **  **** **                                                                                              *           * *                                                                                                                                                                                                                                 **             **          **           *        **    **                  *                                                 * *                              **    *                                                                      * *                ** *           * *                                                                                                          *                                                                                                *         *     *      **            *          **                                                                                                *       **        **         *    **                 *                                          **                     ***            **                *     * **           *                                                                                                                                                                                * *                * *                                                                                                                                                                                                                       **    **  **    **  **    **      *   *                                                                *    *
                *        **        **        **         *                                                             **                                                                                                                                                                         **      **                    **  **  **                                                                                                      *           *    *    *    *       * * * *                                         **       **                *     *       * *        * *        * *                * *          * *  *               *  * **       **   *    *                                                                                                                                                                                                                                                   *  *  ***  *  *                    **  *                                                                                                                                          **                                                   ** *  *      ***** *                    ** * * **      ** * * *   * * *                                                                                                    *** * *                                                                                                                                                                                                                                  **         * ***           **          *           * **               *    **                                                 **       **                      *   **                                                                **   *  *       *  **  ***              ** *       **                                                                                                **                                                                                           **   *         *     *     **        *    *       *  *                                                                                                **      *         *       *  *     *       ***      *    *                                     * *                    *   *           **                **  **    **        *                                                                                                                                                                      *****       *                  *       *****                                                                                                                                                                                                            *     *   *     *   *     *        *   *                                                                *****
                         **        **        **                                                                                                                                                                                                                                                                                **  **  **                                                                                         ***         ***   *      *   *      *   *        *  * ***           ******         ***              ***                     *     *       **        **          **                **        ** *  ** *                 * **      *  ***   ** **                                                                                                                                                                                              *                                                  ***  *****  ***                **  **   *                                                                                                                                                                                             * ** * **    *     * ** ** *                    *      * * * *  ** * * *                                                                                           *****    **** *    *  *                                                                                                                                                                                                                                        **                        **          ** *               **   *                                                             *                      *                                                                    **    * *       *   *  **               ** **      * *                                                                                              * *                                                                                            *  **        **    **                   *       *                                                                                                             *         *        *              * *      *         **                               *                      ** **                                 *     *         **                                                                                                                                                                    *    *       **                **       *    *                                                                                                                                                                                                            *     *   *     *   *     *        * ***                                                                                                                                                                                                                                                                                                                    **
                                                                                                                                                       *                                                                                                                                                                                                                                                                           **        *** ***        * *        * *                 *         *     *        *   *            *   *                   **    **                                                          * * * * *                 *         ** *     ** **   **                                                                                                                                                                                        * *                                                    *********                   **       *                                                                                                                                                                                             *    *        ****     **              * ** ** **             * *  * * **                                                                                         *    *        *     *                                                                                                                                                                                                               ***                         *                           * **          **                 *                                                         *    **                                                                                                 * *      *  *                    ** * ***      *                                                                                                                                                                                           *     ** *      ** *                 *   *       *                                                                                                    **      **        **      * * *            ***        ***     * *                             **                                                        **   *     *                                                                                                                                                                             *  *          **                **          *  *                                                                                                                                                                                                          **    **  **    **  **    **         ***                                                                  *                                                                                                                                                                                                                                                  *                 *****
                                                                                                                                                       *                                                                                                                                                                                                                                                                                                     *    **    *        ****   ****         * **                                                      ** *            ******                ******  ******            * * * * **       **     * *            *              *                                                                                                                                                                              **        *                              **                     *         *                       ****                                                                                                                                                                                            ** **** * **    * *   *  * *   *            **   *** ** * *** *  ***   *                                                                                           *  *                *    *                                                                                                                                                                                                           *                                                       ** *           *                                                                           **   *                      *                                                                             *        **                    * *  *  *  *  *       **                                                                                               **                                                                                 **    * **      * **                 * *         *                                                                         *  **    **  *              *  ** *      ** *       * * **                            ** * *                                                                                        *  **    **                                                                                                                                                                          *  * **          **                **          ** *  *                                                                                                                                                                                                         ** *    *     *     ** *            *                                                                  * *                                                                                                                                                                                                                                                  ***             * *** *
                                                                                                                                                       **                                                                                                                                                                                                                                                                       ***  ***       *  *          *    **    *        *                 ** * *                                                      * **                                                             *    *  *       * *    **             **   ** **     * **                                                                                                                                                                            *         *  *                          ** *                   **       **                                                                                                                                                                                                                      * *    * *    ** ** * **  * *   *  **   *   * *  ** * ** **    * *    * *                                                              **    **    ** *          *  * **               * *  **                                                                                                                                                             **     **                                      *                                                          **        *                  *                                                             *                      *   **                                                                                                         *    **      *       **                                                                                               * *                                                                                                                                  *  *     **                                                             *   ***  ***   *            *   * **      * **       * *     ***                       * * *                                                                                        *     ** *          **             **                                                                                                                                                * * *     *                                  *     * * *                                                                                                                                                                                                        * **     *     *    * **                                                                                *                                                                                                                                                                                                                                                     *              *   *
             **                                                                                                                                          * *                                                                                *   *     *      **                                                                                                                                                                                             * *        * *        *** *  *          * *             *   *            *   *                         **       **        **          **                **           **   *          *   **                    ** **   ***  *                                                                                                                                *    *                                      * *        *  *                             *                                                                                                                                                                                                                                                   *   ***  * *** * ** ***   **      *  *  *   * *  *   * *    ** * **** **                                                                *     *    * **         * * *     *          ** *                                                                                                                                                                  **     **                                                       *   *                                      *        **             **   *                                                                                  **    *                                                                                                                   * *                                                                                                           *                                                                                                                                    **     * *                                                           *    **    **  *             **      **  **            **         *                **     *                                **                                                        **    * **          **             **                                                                                                                                                 *  *    * *                                * *    *  *                                                                                                                                                                                                       **    **  **    **  **    **                                                                                                                                                                                                                                                                                                                                                    ***
             *                                                                                                                                        *  * *                                                                           *    *   *    *  *  *   *                                    *                        *                        *                                                                            **         *** ***      *   *      *   *         * * * *         * **  **         ***              ***                          *       * *        * *        * *                * *            ***                *                      *    *   **                                                                                                                               ** **** **                                     **         **                           *                                                                                                                                                                                                                                                   ** * *  * *             ** ** ** *    * *       **     ****        *    *                                                                 *     *         **        *  *    * *                                                                                                                                                                                                                                              *     *         **                         *                        *    **                                                           *                      *                                                                                **                                      **                                                                                                  **        **                                                                                                                                            *                                                          *                                     *   *                   *    *               ***   *  *                                *                      ** **                                                                                                                                                                                                                      **  *  *                                *  *  **                                                                                                                                                                                                          *     *   *     *   *     *                                                 *                                                                                                                                                                                                                                                                                                    *
              * * *               *     * *                                                                                                         ** *    *                             **      *     *   *                   *   *       *   *             *                                   *   *                                                                                                                            ***       *   ***       *    *    *    *         * *  *       ** * **  * *                     **       **                       *      *            *        *                    *        ***             *******                           *****                                                             *    *                       *    *                          *        *    *                                                                                * **                                                                                                                                                                                                                                                * * * **  * * * *      *              *     * ** ** *     *    ** * ** *                                                                 **    **        *            **  *  *                                                                                                                                                                                                                                              *               **                         **                            *                                                        **   *                      **       **                                                                     *               *                                                                                                      **         **        **                                                                                                                                                      **                                                        *   *                          **       *   *                      *               *****     *                                * *                    *   *           **                                                                                                                                                                                                              **                                  **                                                                                                                                                                                                                *     *   *     *   *     *                                               * *                                                                  *
                  * * * * * * * * * * *  *  * * * * * * *                                **                               **                           ** **  ***                        *   *  *  *    *   *    *         *    *   * ** ** *   * ** ** **** *                                                         ** *     * **               **   **                                                                                        *         **   *  *   **           **          ** *       *       *   *         *  *   *  *                      **     **            **      **                    **       *  **           *                                *    *             **    * **                                    ** **** **                   ** **** **                        *                                                                                                **                                                                                                                                                                                                                                                * * *   * * * **      ** * * **                    * *****      *  * **                                                                    * **           *                **       *  *  *                                                                                                                                                                                                                                 **   *                                 * **          **       **       **            **                                           *    **                              * *                                                         *        * *             * *          * *                                                                                         * *         **                                                                                                                                                                                                                         *****                           *      **  **                   **                  ***  *   *                                 **                     ***            **                                                                                                                                                                                                                                                                                                                                                                                                                                                                   **    **  **    **  **    **                                                *
              **    *  *  *  *  * * *  * * *  *  *  *  *  *                              *  ***   *** ***   *** ***   ***  *                        **  ***   *                           *             *   *       *   *       *   *       *   *        **                                                            *     *     *               *******                                                                        *           *               *   **   *                            *       **     **   **         **** ****                   ** *                                                               * *             **                           **  **               *    ** *                                      *    *                       *    *                         * *                                                                                                                                                                                                                                                                                                                                                  ** ****  ** *       *  * ** *                ** * **         * *                                                                          ** *          **                       * *    **                                                                                                                                                                                                  **              **               ***                                  ** *          **      * *                     * *                                               *                                 *                                                         **       **               **          **                                                                                 *** **    ***       *      *                                                                                                                                                                                                                   **   **                         *   ** *      ** *               *                    **  *   *                                                         *                                                                                                                                                                                                                                               **                                                                                                                                                                                                                                   ** *      ** *      ** *                                                                                                                    * ***
                   * * * * * * *  *  * * * * * * * * * * *  *        *                    * **** **** **** **** **** **** *                        *   ***  **                             * **** ** ** *   * ** ** *   * ** ** *   *    *         *                                            *********               ** ** ** **                                                                                               * **         * *            *  *  *  *                            * *            **   **            * *                      * **                                                                *              **                          * * *                *   **                                                                                                       *                                                          ***                           ***                            ***                            ***                                                                                                                                                                                                 **   *        * *    *                 * **   **      **                                                                               **    ** *                          **                                                                                                                                                                                                        **               **                                                                         *                         *                                    **       **            **                    **                                            **           **                             *      *                                                                                 ****  *    ***            * *                                                                                                                                                                                                                   *****                          **  * **      * **               *                            *                                                                                                                                                                                                                                                                                                         **                                                                                                                                                                                 **                                                * **      * **      * **                                                *****                                                                 ** *                                                                                                                                                                                                          *                 **
              *  *               * *     *               * *  *    * *                   **                               **                     ***  ** **                                   **        *   *       *   *       *   *                                                           **     **                                          *     *                                                                          *           *              **    **                              **            *     *       *****   *****                                                                                                                             *  * * *                **   *                                                                                                       *                                                          * *                           * *                            * *                            * *                                                                                                                                                                                               *  *   **        **    **                *    ** *                                                                                        *    * **                                                                                                                                                                                                                                                 *****               ***                                                       **                         **                                  * *                     * *                                                                ***   *       ***         ***               ***                                                                                           **    ***            *   **   **                                                                                                                                                               **                                            ***                                                            *                         *  *                                                                                                                        *                     **                                                                                                                                 **                                              **                                                                                                                                                         **                                                                                                                        *    *                                                                * **                                                                                                                                                                                                         *                  **
                * *                                        * *  *   *  *                    *  * *  * *  * *  * *  * *  *                            *    * **                                       *         *    *   *    *                                                                 **       **                **   **              ** * *   * * **                                                                    * *          **                                                                               *  *       *  *                                                                                                                            **** **                     *                                                                                                        *     **  **                                               ***                           ***                            ***                            ***                                                                                                                                                                                               **                                        *** *                                                                                          *   **                **                                                                                                                                                                                                                                   ****              **   *                                                                                                                     *                         *                                                             * **    ****     **                             * *                                                                                               * *             *   **   **                   **                                                                                                                                          * *                                            *                                                                                 ***     *                                                                                                                          **         **       * *               **                                                                                                                **                                              **                                                                                                                                                                                                                                                                                      *  *                   *                                            *** *                                                                                                                                                                                                       ***
                *                                            * *  *                      ** *  * *  * *  * *  * *  * *  * **                          * *  *                                                        *   *                                                                      *         *          **               **        *    ** **    *             *                                                      * *           * *                                                                             **           **                                                                                                                                *                   **  **             *    *                                                                                    *     **  **     *                                                                                                                                                                                                                                                                                                                                                                                   * *                                                                                          **  *                 **       *    **                                                                                                                                                                                                                                       *               **                                                                                                        **                         **                                                     **     *  *    *    *  **          *   *                   **                                                                                            **              *   **                        * *                                                                                                                                           *                                                                                                                            *       * * *                                                                                                                       **          **       *                 **                                                                                                                **                                              **                                                                                                                                                          *                                                                                                                           ** *  *               * *                                     **
                                                               * *    **                 ** *  * *  * *  * *  * *  * *  * **                          * *                                                                                                                                                           *  *   * * *   *  *     ** * ** ** ** ** * **          **                   *  *                               *             *                                                                                                                                                                                                                           * *                    *    * **       ** **** **                     **  **                          **  **                      * *               *                                                                                                                                                                                                                                                                                                                                                                                    *                                                                                                *                **        *  *  *  **                                                                                                                                                                                                                ****              *     *         **                                                                                                                                                                                          **     * **     *   *  *           *   *               ** *                                                                                                               * *                            *                                                                                                                                           **                                                                                                                           *    *  ** * *                                                                                                                                           ***                                                                                             ** *    **    **    ** *             *                    *    *                    *                                                                                                                                     *  **                * *                                                                                                                       *     * * *               *                                    *  *      *                                                                                                                                                                                   **
                                                                 * *                         *     *   *     *   *     *                                 **                                                                                                                                **  ***     ***  **       *** ********* ***      *  *  *       *  *  *                             * *  * *                                                                                                                                                                                                                                                                       **                    *     ** *         *    *                       **  **                          **  **                       *               * *                                    **  *****  **                 **  *****  **                  **  *****  **                  **  *****  **                                                                                                                                **                                                                                                                                                                                                    **                 *      ***  * *    *  *                                                                                                                                                                                                             *****              *   *                                                                                                                                                                                                                ***   ** *                                  ***                                                                                                                  *                             **                                                                                                                                                                                                                                                          **            *         * *                                                            **                                                                                                                                                                             * **     *     *    * **            * *                    *  *                    * *                                                                                                                                   *   **  **       **  *  *                                                                                                                      * *    *  *                            **                                                                                                                                                                                                                     * *
                                                                   * * *                                                                                  *                                                                                                                                *  * **     ** *  *          *    *    *          *  **         **  *        **  **              ***      ***                                                                                                                                                                                                                                                                                           **        **                                                                                                 *     **  **     *                                     * * *   * * *                 * * *   * * *                  * * *   * * *                  * * *   * * *                                                                                     **                                        * *                                                                                                                                                                                                **    ** *            * *           *     * * *                                                                                                                                                                                               **               **                                                                                                                                                                                                                                   **                       ***               ***                                                                                                                                                                                                                                                                                                                                                                                                            **  **          **      **                                    **                       **                                                                                                                                                                                 **  *     *   **           *** * *                   ***  ***                   * * ***                                                                                                                              *       **       ** *                                                                                                                          *  *  **                 *****     ** *  * **                   *  *                                                                                                                                                                                           ***
                                                                        *                                                                                 *                                                                                                                                 * * *       * * *          **         **          **    *   *    **        * *                 *   * ** *   *                                                                                                                                                                                                                                                                                                     *                                                                                                       **  **     *                                      ***     ***                   ***     ***                    ***     ***                    ***     ***                                                                                     * *                                        *                                                                                                                                                                                                  **    * **       *** * *               ** *  *                                                                                                                                                                                                **              **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            ** *  **           *                                             *                                                                                                                                                                                                          *   **    **  *            **** *                                                * ****                                                                                                                               ****                **                                                                                                                         **                     *    *     *    *  **                    *  *                                                                                                                                                                                           **
                                                                       **                                                                                                                                                                                                                  ** **         ** **         *           *           * ****   **** *         *     **             ** * ** * **                                                                                                                                                                                                                                                                                           **        *                                                                                                                   *                                          * *                           * *                            * *                            * *                                                   **   **                               *                                        ** ****                                                                                                                                                                                                               **** *    *  *        *  *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 ***                *                                          ***                                                                                                       ***                                                                                                  *    * **     *               *                                                  *                                                                                                                                                                                                                                                                                                        *  *            *                          * *                                                                                                                                                                                        **
                                                                                                                                                                                                                                                                                          *  *   *** ***   *  *         *         *            * *         * *        **            **        *      *                                                                                                                                                                                                                                                                                              *        **                                                                                                                  *                                        * * * *                       * * * *                        * * * *                        * * * *                                                *  * *  *                            ** ****                                   * * *  *                                                                                                                                                                                                                   *     *        *    *                                                                                                                                                                                                                                                                                                                                                                                                                                                                       * *         ***                                                                                                                                                                                                                                                                                                                                                                                                                                               *                                          *                     **                                                                                  *                                                                                                   **    ** *    **                                                                                                                                                                                                                              **                                                                                                                                        *  * **         * *                            *                                                                                                                                                                                         ***
                                                                                                                                                                                                                                                                                           * * **       ** * *         **         **         **  *  * * *  *  **             *      *         * **** *                                                                               *           *          **      *              *      **                                                                                                                                                       *     * **                                      *    *                     **   *  *   **                                    * *                                 **    *******    **           **    *******    **            **    *******    **            **    *******    **            ** *      ** *            **   **   **   **                       * * *  *                                   * *                                                                                                                                                                                                                             *    *    *****                                                                                                                                                                                                                                                                                                                                                                                                                                                                         **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       ** *    * **                                                                             * *                                                                                             ** *          **    ** *                             *      **      *                                                                                                                                                                             **                                                                               **                                                      * * *     *                                                                                                                                                                                                                                            ***
                                                                                   **  **        **        **                                                                                                                                                                               *  * *     * *  *                                 * *   * * *   * *                   * *       ** * ** * **                                                         **   **            * *         * *          *    ***             * *     *                                                                                                                                                        **    ** *                                    ** **** **                   *****    *****                                     *                                  *  **    *    **  *           *  **    *    **  *            *  **    *    **  *            *  **    *    **  *            * **      * **            *               *                       * *       **                             **  *                                                                                                                                                                                                                            * *  **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  *         *   *                                                                                                                                                                                                                                                                                                                                                          **                                                                **                                                                            *          *                                                                              **                                                                                             * **           *    * **                           * *      **      * *                                                                                                                                                                                                                                                           * *                                                       *  *    * *                                   **                                                                                                                                                                                                      *
                               * ** **      *      ** ** *                         *  *  * **   *  * **   *  * **    **                                                                                                                                                                           * * *                                      *  ***   *   ***  *              ** ***       *   *    *   *                                                       * *   * *           * *         * *         *    *                * *   * *                                                                                                                                                                                                        *    *                     **   *  *   **                       *    *        *                                   *** *       * ***             *** *       * ***              *** *       * ***              *** *       * ***                 **  **    **       ** *               * **                  **  *       **     **                     *    **      **                                                                                                                                                                                                                 ** *           *                                                                                                                                                                                                                                                                                                  **                         **    **                         **                                                                                                                     *   *                                                                                                                                                                                                                                                                                                                                                          **                                                                **                                                                             **      **                                                                                                                                                                            **              *   **    **      *  *                **              **                *  *                                                                                                                                                                                                                                        *                                           **               **  *  *                                   **                                                                                                                                                                                          **           *
                               ** * *   ** * * **   * * **                          * ** * *  *  * * *  *  * * *  * *  *                                                                                                                                                                      ****  *  ****                                   **  *  ***  *  **                 **          *** *  * ***                            ** **       ***              *     *          *** **       ** ***       **   **            ** * **  **    *                                                                                                                                                                                                                                                                  ** **** **                                                ** **                         ** **                          ** **                          ** **                       *   *     *      *  * **             ** *  *               *    **             *                      *****        **     **                                                                                                                                                                                                                        * *                                                                                                                                                                                                                                                                                                  *                         *      *                         *                                                                                                                                 * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               ***  ******  ***                                                                                                                                                                         *               **  *     *          *                                                  *                                                                                                                                                                                                                                          **    **                                     **                    **                                                                                                                                                                                                                                **
                                  *   *  * * * *  *   *                            **  * *   ** ** *   ** ** *   ** ** *                                                                                                                                                                       * ******* *                                      ** **   ** **                 *  *            * **** *                               * **                                        *                   *                         * **         ***                                                                                                                                                                                                                                                                    *    *                                              **         **                 **         **                  **         **                  **         **                    *   *     *     ** *     ***   ***     * **               *****             * *                    **    *               *                                                                                                                                                                                                                          *                                                                                                                                                                                                                                                                                                   * *                     * *      * *                     * *                                                                                                                       ***       **                 *                             *                                                                                                                                                                                                                                                                                                                                                                                                                                                *  *        *  *                                                                                                                                                                          *                   *     *     *    *                                                *    *                                                                                                                                                                                                                                             *         **  *
                                  *  ***   * *   ***  *                           *  *    *    *    *    *    *    *   **                                                                                                                                                                    * *         * *                                    *  *     *  *                  **                                                 **            **  ** *                          *** **       ** ***       **          **         **      *                                                                                             **                **      **                **                                                                                                                                                                                *           *                 *           *                  *           *                  *           *                   **  **    **        *     * *   * *     *                **    *             **                    *  **     ***        * *                                                                                                                                                                                                           *  *                                                                                                                                                                                                                                                                                                                **            **       **        **       **            **                                                                                                                                   *               *   *                         *   *                         ** *      ** *                                                                                                                                                                                                                                                                                                                                                                                                        **          **                                                                                                                                                                          **                  **    **     **  * *                                              * *  **                                                                                                                                                                                                                                          ***      **  **   *                                                                                                                                                                                                                                                                                       *
                                 ** *     * * *     * **                          **  *** * **  *** * **  *** * **  ***  *                                                                                                                                                                 *** *  ** **  * ***                               ** * **     ** * **                                                                     * **       *    * *          ** **             * **       ** *         * *  *      *          *  *    **                                                                                             *       **       *        *       **       *                                                                                                                                                                                  *         *                   *         *                    *         *                    *         *                ** *      ** *          **    ***   ***    **               *  **     ***   ***                        ** *      * *        **                                                                                                                                                                                                              **                                                                                                                                                                                                                                                                                                                             *                              *                                                                                                                                 *                                   *                             *                        * **      * **                                                                                                                                                                                                **                                                                                                                                                                                                                                                                                                                                                                                                ** *          **    ** *            * **                                          ** *                                                                                                                                                                                                                                               *        **       *   **                **                                                                                                                                                                                                                                                          ** * * *
                                    *  ** *   * **  *                               **  * ** ***  * ** ***  * ** ***  * *  *                                                                                                                                                              *     *  * *  *     *                              * * ** ** ** ** * *                                                                 *   *  *              *       **  * *  **                                   *  **    * *           ***                                                                                                   * *   *    *   * *        * *   *    *   * *                                                                                                                                                                                 **         **                 **         **                  **         **                  **         **               * **      * **                                              ** *      * *   * *                           *      ***   ***                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                **    *                    *    **                                                                                                                                 **                            *    *                        *    *                      **    **        **                      **                               **                                                                                                                                     * *                                                                                                                                                                                                                                                                                                                                                                                               * **          **    * **                                                                                                                                                                                                                                                                                                                           ****     *                ** *                                                                                                                                                                                                                                                        * ** **          **
                                 **  ***  ** **  ***  **                          ** **  * * * **  * * * **  * * * **   * **                                                                                                                                                               * ** * *   * * ** *                                 *    *   *    *                                                                      ** *      *              *** * * * * ***            **   **           ***     **  **               **                                                                                                  **  *      *  **          **  *      *  **                                                                                                                                                                                                                                                                                                        **              **                                               *      ***   ***                           **           * *                                                                                                                                                                                                                                                                                                                                                                                **     **                                              **     **                                                                                                 *   **                    **   *                                                                                                                                 **   **                         *****                         *****                      *     *         *      **               * *       **           **       * *               **                                                                                                                       *           * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         ***                    *                                                                                                                                                                                                                                                                   **    * *
                             ** * **   ** ***** **   ** * **                      *                                     *                                                                                                                                                                   ** * *     * * **                                  ** * *   * * **                                                                    *           * *    *      *    **   **    *          * *   * *          *       *                 ** *   *                                                                                                  *        *                *        *                                                                                                                                                                                                                                                                                                           *               *                                                **                                                      ***                                                                                                                                                                                                                                                                                                                                                                                **     **                                              **     **                                                                                                  *           *    *           *                                                                                                                                        **                                                                   **             *     *         *     **                 *       **           **       *                 **                                                                                                        **          *  *          *  *    *                                                                                                                                                                                                                                                                                                                                                                                                               *  *                                          *  *                                                                                                                                                                    **                                                                                             *                      *                                                                                                                                                                                                                                                                    **   *
                             ** **    *           *    ** **                       ** * * * * * * * * * * * * * * * * * *                                                                                                                                                                       *       *                                           ** **                                                                       * *           * **  **       ****       ****         ***       ***                                  ** * * ***                                                                                                *        *                *        *                                                                                                                                                                                                                                                                                                            *               *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                      ** **** **                                                                                                                                                 *                                                                     * *           **    **        **                      ***                             ***                                                                                                                        ***             *         **     **                                                                                                                                                                                                                                                                                                                                                                                                                **                                              **                                                                                                                                                                    * *                                                                                                                *  *                                                                                                                                                                                                                                                                   *
                                *  ** * *       * * **  *                           * **********************************                                          **                **                                       **      **      **   * **                                                                                        * ** *     * ** *                                                                 **                              *       *           *   *******   *                *                    **    *                           **                **      **                                        *        *                *        *                                                                                                                            *                                                                                                                                                                              **              **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          **     **                                         **                                                                              *           *    *           *                                                                                                                                                                                                               *             ** *      ** *                                                                                                                                                                       *        * **            * *        **   *        **                                                                                                              **                                                                                                                                                                                                                                                                                                                   **                                                                                            ** *      ** *      ** *                                                                          *                                                                                                                 **
                             **  ***  ** ******* **  ***  **                      *  * * * * * * * * * * * * * * * * *                                       **   **   **      **   **   **                        *        *  *    *  *    *  *  ** *                                                                                        ** * *     * * **                                                                                    ***         *         *          **  *     *  **               * * * **                ****                             *                *        *                           **        **  *      *  **          **  *      *  **                                                                                                                        ***                                                                                                                                                                               ** *      ** *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            **     **                               **       * *               **                                                            *   **                    **   *                                                                                                                                                                                                              **            * **      * **                                                                                                                                                                       * *      *  *     *      **           **          **                                                                                                              **                                                                                                                                                                                                                                                                                                                   **                                                                                            * **      * **      * **                                                                          **                                                                                          **
                     **  ** * **   ** ************* **   ** * **  **              ** *                                 ***                          **   **  *          *  **  *          *  **   **           *  * *    *   **  *   **  *   * *     * **                                                                                         *       *                                                                                                    **       **                 *                     * ** ** *                *                                * *            * *        * *                         *        * *   *    *   * *        * *   *    *   * *                                                                                                                      *****                                                                                                                                                                              * **      * **                *       *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           **      ** *               **                                                           **    *                    *    **                                                                                                                       *                                                                                                       **  **                                                                                                                                                                            * *     * **     *           *        *  *                                                                                                   *    *                              *    *                                                                                                                                                                                                                                                                                                                                                                                                 **  **        **    **                                                                                                                                                                   *  *
                  *  *   ** **    *                   *    ** **   *  *             * * * * * * * * * * * * * * * * * *   *                       *   * *  * *  ******  * *  * *  ******  * *  * *   *         **** *  ******  ******  ******  ****** * *                                                                                                                                                                                                                                 * *                    *                         *                                **            **          **                       * *        *       **       *        *       **       *                                                                                                                                                                                                                                                                                                                                      * *     * *                                                                         *                                                                                                                                                                                                                                                                                                                                                                                                                                                                         **                                                                              *                              *                                                                                                                     ****   * **                                                                                                *   *                             ***              **             ***                                                                                                **           *  *       ***             **          * *                                                                                                 ** **** **                          ** **** **                                                                                                                                                                                                                                                                           **                                  **                                                                              *   *         *     *                                                                                                                                                                    *                                                                                                                                                                                                                                                                                                                     **
                 * * *      *  ** * *               * * **  *      * * *            * ********************************* *  *                     *  * * **** * *      * * **** * *      * * **** * *  *             * *     * *     * *     * *     * *      **                                                                                                                                                                                                                            *                    **                        **                                     *    *                    *    *              **        **                **      **                **                                                                                                                                                                                                                                                                                                                                      *       *                               *       *                                 * *                                                                                                                                                                                                                                                                                                                                                                                       ***   ***                       ***   ***                                         *                                                                 **            **       **        **       **            **                                                                                                **     ****    * * **  **                                                                                           *   *           **                 *             *  *            *                 **                                                                               **           * *         **              **                                                                                                               *    *                              *    *                                                                                                                                                                                                                                                                        **  *  *                                *  *  **                                                                          *   *         *     *                    *                                                                                                                                              *                                                       **                                                                                                                                                                                                                            *                   ***  *     *   *
                *  * **  **  ***  ** *************** **  ***  **  ** *  *         ** * * * * * * * * * * * * * * * * * *** *                     **   *  **  *  **  **  *  **  *  **  **  *  **  *   **          ** * * * *   * * *   * * *   * * *   * *     *                                                                                                                                                                                                                                                                                                                ** **** **                ** **** **   *    *                    **  **                       **  **                                                                                                                                                                                                                                                                                                                                                                                 * *     * *                                 *       *                                                                                                                                                                                                                                                                                                                                                                               *  *   *  *                      *  * *  *                                                                                                          * *                     * *      * *                     * *                                                                                               **     *  *   ** * **  * *                                                                                         **  **           **               * *              **             * *               **                                                                                           * *                                                                                                                                                                                                                                                                                                    *   *   *                                                                                                                                             *  *    * *                                * *    *  *                                                                      **  **        **    **                    ***                                                                                                                                            * **                                                    * *         * *                                                                                                                                                                                                               **              *   *         *     *
                * **    * **   ** ********************* **   ** *    ** *         *  *                                    *                              **     **  **     **     **  **     **                 *     * *   * * *   * * *   * * *   * * * * **                                                                                                                                                                                                                                                                                                                   *    *                    *    *   ** **** **                  **  **                       **  **                                                                        **   *                                                                                                          *                  *                                                                                                                                                                      *       *                                         * *                                                                                                                                                                                                                                                                                                                                                                              *   * *   *                        ** **                                           *                                                                *                         *      *                         *                                                                                                      ****   **        ***       **                                                                           ** *      ** *                        **                               **                                                                                                            *         *                      **         **                                                                                                                                                                                                                                                       ***  * *  ***                                                                                                                                          * * *     *                                  *     * * *                                                                 ** *      ** *    *     *                        *                               **                                                                                                            **                                                      *        *                                                                                                                                                                                                      * *        * *            * *    *        *   *  *
             ** **   ** **    *                           *    ** **   ** **       *  * * * * * * * * * * * * * * * * * *                        **   *  **  *  **  **  *  **  *  **  **  *  **  *   **         **      * *     * *     * *     * *     * *                                                                                                                    *                                                                                                                                                                                            **            **          **              *    *             **                **        **                **                                                                  * * * *                                                                                                        * *                * *                                                                                                                                                                                                                        *                                                                                                                                                                                                                                                                                                                                                                              ** * * * * **                                                                      **                                                               **                         **    **                         **                                                                                                      ****   **        ***      **                                                                           * **      * **                                                                                                                                                                                  **                   *  *       *  *                                                                **  ** *      * **                                                                                                                                                                   *     * *     *                                                                                                                                          *  * **          **                **          ** *  *                                                                  * **      * **     *     *                      **                               *                                                                                                                                                                     **  **  *    *                                                                                                                                                                                                  *   *                   **                *
             * *   ** * *  ** * *                       * * **  * * **   * *        ** ******************************** **                       *  * * **** * *      * * **** * *      * * **** * *  *               * * ******  ******  ******  ******  * ****                                  **                    **                        **                           *  *                                                                                                                                                                                        * *            * *        * *                       **         *       **       *          *                *                                         **                          * * *                                                                                                          *                *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         ** **   ** **                   *           *                                     ** *               **                                                                                                                                                                                                                    *            ***                                                                                                                                                                                                                                                                                   **                    ***         ***                                                                 *  * **      ** *                                                                                                                                                                  * ***** * ***** *                                                                                                                                            *  *        *  *                *  *        *  *                                                                         **  **    **  **    **                                                        ***                                                                                                                                                                      ** *  * **                                                                                                                                                                                        **            *          **       **                 *   *   *
               * ** * *  ***  ** *********************** **  ***  * * ** *           * * * * * * * * * * * * * * * * * *                          *   * *  * *  ******  * *  * *  ******  * *  * *   *                ** *     * *   *  **   *  **   *    * *  *                                *    *                *    *                    *    *                         *  *                                                                                                                                                                                        *                *        *                         * *        * *   *    *   * *          * *            * *                                       *    *                       ** * **                                         *****                                                       *  *        **        *  *                                   **      *                      *      **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           ***     ***                     *         *                                       * *               **                                                                                                                                                                                                                                * *                                                                                                                                                                                                                                                                                                             *********                                                                   *       **  **                                    *  *                                                                                                                              *     *   *     *                                                      *                                                                                      *    *                                  *    *                                                                          *   *     *   *     *                                                           *                                                                                                         **                                                    **         **                                                                                                                                                                                            **        *    *       *  *       **                  **   ** *
               * *  ****   ** ***************************** **   ****  * *          *                                   **                          **   **  *          *  **  *          *  **   **                     * **  *  *    *  *    *  *        *                                                                                                                    * *                                                 *          *                         **                                **                                                             **                **      **                           *         **  *      *  **            **            **                                       *      *                     *   **   *                                        ***                                                       *  *       *    *       *  *                                 * *      ***                  ***      * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * * * *                                          **                                                                                                                                                                                                                                                 **                                                                                                                                                                                                                                                                                                * *          *  *****  *                                                                  **      *    *                                  * *  * *                                                                                                                             *  * * *  * * *                                          *       **   ***                                                                                     *****                                  *****                                                                            *   *     *   *     *                                                                                                                                                                    **                                                    **                                                                                                                                                                                                                     *       *       **    * *                       *
              **  *       *                                   *       *  **        * ** * * * * * * * * * * * * * * * * *                                    **   **   **      **   **   **                              ** *   **      **      **                                             * *  * *                                                                         * *                                                * *        * *                        *      **                         *                                                                                                                     **           *        *                   ********                                          *        *                   * **  **                                            *                                                         **                      **                                  *           *                *           *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * * * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               **           **  ***  **                                                                           *  *                                    **  **                                                                                                                               * ** ***   **                                           ***     **      *    **       *                                                                                ** *                * **                                                                                     **  **    **  **    **                                                                                                                                                                                                                                                                                                                                                                                                                                             *   *       *      *  *     *                       **       **
             *  * *    ** * *                               * * **    * *  *        *  ********************************  *                                        **                **                                                                                                       **** ** ****           **********                **********                          **                                               * *        * *                     ** *      *  *                    *   *                    **   **   *                                                                                                  *        *                   * **** *                                          *        *                   * *  * *   *                                                                                                                                                         * ** **    **   **                **   **    ** ** *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ** **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 *                                                                                        **      **  **             *  *    *  *                          *  *    *  *                                                                                                          ** *                                             *        *           **    **     ***                                                                        *         * *  **      **  * *         *                                                                         ** *      ** *      ** *       **                                                                                                                                                                                                                    *                                                                                                                                                                                                                 * *         *       **                                       * *
              * *  *****  ** ******************************* **  *****  * *          * * * * * * * * * * * * * * * * * ** *                                                                                                                                                               * *    *  *    * *        **      **                **      **                 *        **                                             *** **      ** ***                   * * ** ** * **  *                 **** *                   * *  **  * *                                                                                                 *        *                   ********                                          *        *                    ***  **     ** **                     *      *                                                                        *      *                                      ** *  *   * *            **            * *   *  * **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     *  *   *  *                                                            **     **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   *  ** *      * **       ***  ******  ***                      ***  ******  ***                                                                                                         ** ***                                          ***     **                       *        *                                                                 * *         *    *      *    *         * *                                                                        * **      * **      * **        *                                                                                                                                                                                                                   * *                               **                                                                                                                                                                                            *  *                                              *
               * ***  *** ************************************* ***  *** *          **                                   *                                                                                                                                                                ** ** *    * ** **       **        **              **        **               *  *    * *                                             *    *             *            *       *  * *  *  * * *                   * *                     *      *  *                                                                                             **  *      *  **            **            **                                       *      *                         **   *  ** **                    **      **                                                                          **                                              *    **           *    *           **    *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           **     **             ** *   * **            *                        **     **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    * *                                                        *  *                               *   * **      ** *         *  *    *  *            **            *  *    *  *                                                                                                           *    ****                                          *                             **     ***                                                                  *           *              *           *                                                                                                         * *                                                                                                                                                                                                                *  *                               *                                                                                                                                                                                               **                                              **
                 * *  *                                           *  * *              * * * * * * * * * * * * * * * * * *                                                                                                                                                                    * *      * *          *          *              *          *                * *    *                                                ***  *      ** ***           **  *   *  **  * * *   *  *               **    **               **** ****** * *                                                                                            * *   *    *   * *          * *            * *                                       *    *                    ***** * **                            ***      ***     *                                                            ***          ***                                         ** *                              * **                                                                                                                                                                                                                                                         *                                                                                                                                                                                                                                                                                                                         *  *   *  *           *                                                                                                                                                                                                                                                                                                                                                                                      **                               *                                                                                                                               **            ****                                            *                              **      **        **                               **                                                                                                                                   * **    *                                         **                                   *                                                                                 *  *        *  *                                                                                                                      **                                                                                                                                                                                                               *  *                                 ***
               * * *  * *                                       * *  * * *          ** ******************************** **                                                                                                                                                                ** * *      * * **                                                             *  *  * **                                                *  *      ** *                 *   *  **  * * *  * **            ** *  *     * *           *   *      * * **                                                                                           *       **       *          *                *                                         **                      *  *  * *                              **      **     * *                                                           * *  **  **  * *                                      *  *   **  ***                ***  **   *  *                                                                                                                                                                                                                                                      *                                                                                                                                                                                                                                                                                                                          ***   ***            ***                                                                                                                                                                                                                                     **                                                                                                                            **               * *       **          **        **               **                                                                                                              *            *   *                                        *   *                                      *          *                                                                                                                                                                                      **                                      *                   ***      **                                                                                                                                                                                                                                                       *                                                                                                                                                                                                                      *
               **   * ** *************************************** ** *   **           * * * * * * * * * * * * * * * * * *                                                                                                                                                                  ** *          * **      * *        * *         **  ***      ***  **             * *  * * **                                                      *                    *   **** ** *   ** **                * *      ** **           **   *  **  **                                                                                             **                **        **                **                              ***                                    *  *                               *      *     *  *  *  **    **  *                                           ***          ***                                      *  ***  *  * *    *      *    * *  *  ***  *                                                                                                                                                                                                                                                      ***                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     **                                                                                                                            **                 *       **          **       **                **                                                                                                                  **           *                                         ****                              **       *        *                                                                                                                                                                                       *                   **                 * *                 *   *                                                                                                                                                                                                                                                            **  *                                                                                                                                                                             *  *
                      *********************************************                 *                                   **                                                                                                                                                                   * * **** * *           *  *  *  *         ***  * **      ** *  ***           * *  * ****                                                   ****                           *        * **                 *  *   *  *                 *    *    *                                                                                                                                                                          *   *      *                             **                                              **  *   ***  ***   *                                                                                                  **    *  ***       **       ***  *    **                                                                                                                                     **   **                                                                                                    **       **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    ***                             **  **                                                                                                                              * *       *  *                                                            **               *      **        **                                                                                                                                                                                    * *                  *  *                * **               *     *                **                                                                                                                                                                                                                                          *   *                                                                                                                                                                              **
                                                                                   * ** * * * * * * * * * * * * * * * * *                                                                                                                                                                    * *      * *        **  ***  ***  **     *    ** *        * **    *                     **                                                 *                      * * *  ** * * * ** *** **          ** **      * *            **** **** * ***                                                                                                                                                                          *     *    * *                                **  **                                           *  **    **  *                                                                                                 *  ***  *                          *  ***  *                                            *       *                                                                             *  * *  *                                                                                                   **  ***  **                                             **                                                                                                                                                                                                                                                                                                            *                                                               *                         *                                                                                                                  **                                                                                                                                                                                                                                                                                                                    *           *                                                                       * *             *   ** *      * **                            *          *                                                                                                                                              **                  * *  *                **   * *          *     *               *  *                                                                                                                                                                                                                                          *
                                                                                    *  ********************************  *                                                                                                                                                                  ** * **** * **         ***      ***        *** *   *      *   * ***                      **                                            * **      *  *              * *        **   *    * *           * *     *  * **           *  **    * *                                                                                                                                                                                       * *                             ***** ** ***                                      *                                                     **  *****  **  **  *****  **                                *  *   **          **  **          **   *  *                                           * *     * *                               *       *                                **   **   **   **                                                                                                     ***                                          ** *    * **                                                                                                                                                                                                                                                                                                      **                                                              * *                       * *                                                                                                                 **                            **                                                                                                                                                                                                                                                                                      * *                             **                                                    *             **  * **      ** *                            *          *                                                                                                                                                                  * * **                      **          *     *              * ** *
                      *********************************************                  * * * * * * * * * * * * * * * * * ** *                                                                                                                                                                 *  ***  ***  *             *  *              * * *          * * *                        **                                          *** **      *  ***            *          ******    * *              **    **                     ** *  *                                                                                                                                                                           *       * * *                             *            *                                    * *                                                    * * *   * * *  * * *   * * *                                   ** *                              * **                                               *       *                               * *     * *                               *               *                                              **                                                     ***                                          *          *                                                                                                                                                                                                                                                                                                      * *                                                              *                         *                                                                                                                                                **                                                                                                                                                                                                                                                                           **            **         **               ***                                                    **                                                         * *        * *                                                                                             **    ** *      ** *                                               ** * **  **                  **           *   *            *   * * *                                                                                                                                                                                                                                          ***                                                                                                                                          *  **
               **   * ** *************************************** ** *   **          **                                   *                                                                                                                                                                    *  ****  *           * *      * *            *   *      *   *                          **                                         *             *    *                  * **    *  *   *                 * *                     *** **  **                                                                                                                                                                           *       *  *                               ******  ****                                                                                             ***     ***    ***     ***                                  *    **     **              **     **    *                                                                                      *       *                             ** *               * **                                           *                                                 **                                                 **      **                                                                                                                                                                                                                                                                                                                                                                             *               *                                                                                                                                                                                                                                                                                   ***                             **  **                                                                                                         **            **         **              * *  *  **                                                                                                          *          *                                                                                               *    * **      * **       **                                         *    **                                 ***             *   * * **                                                                                                                                                                                                                                                                                                                                                                                     *   **  **
               * * *  * *                                       * *  * * *            * * * * * * * * * * * * * * * * * *                                                                                                                                                                    ** *    * **         ** * **** * **          *  * **    ** *  *                           ****                                      *** **      ** ***                   **      *  *                     * ****                  *                                                                                                                                                                                                                                    *  *                                                                                                    * *            * *                                 ** *  *   * *                          * *   *  * **                                                                                                                     *  * **             ** *  *                                 * ** ** *     **                              ***        *  *                                             ***  ******  ***                                                                                                                                                                                                                                                                                                                                                                   *****  ***           ***  *****                                                                                                                                                           **                                                                                              **                 *            ***             **                **                                                                                                          **      **      *   **     **  **  **                                                                                                          *          *                                                                                              *   **    **  **    **     **     ***                                 ***   **                                               *      *                                                                                                                                                                                                                                                                                                                                                                                        *       **
                 * *  *                                           *  * *            ** ******************************** **                                                                                                                                                                   *  *    *  *            **    **              ** *        * ** *                          ****                                        * *        * *                        **** ***                       *   *                                                                                                                                                                                                        *     *                                     **      **                                     ***                                                       * * * *        * * * *                               * ** **    **   *   *          *   *   **    ** ** *                                                                                                                     ** *     ***   ***     * **                                 ** * * *      *                               ***        * *                                              *  *        *  *                                                                                                                                                                                                                                                                                                                                                                  *    *     *         *     *    *                                                                                                                                                          **                                                                                              **               * *                             **               **                                                                                                       * *       ***     *   * *         **                                                                                                              *          *                                                                                              **  *     *   *     *            *   *            **                **   * **                                                  *  ***                                                                                                                                                                                                                  **                                                                                                                                                                     ****                              **
               * ***  *** ************************************* ***  *** *           * * * * * * * * * * * * * * * * * *                                                                                                                                                                      *  *  *  *          **    **    **            *  **    **  *  *                              **                                      * *        * *                     ***    *                           *                                                                                                                                                                                                            *   *                                      *  *  *  *                                     ***                                                 **    *******        *******    **                              *         *    *          *    *         *                                                                                                                             *     * *   * *     *             ** *      ** *               *        *                            ***  **   *   *    ***                                     ** * *          * * **                                                                                                                                                                                                               *                                                                                               *     *               * **      * **           *  *       **         **       *  *                                                                                                                                                                                                                                                                          **                               *                                                                                                                        *          **      *****                                                                                                                          *          *                                                                                                   *     *   *     *          *     *           *                *  * ** *                                                   *     **                                                                                                                                                                                                                **                                                                                                                                                                                                       * *
              * *  *****  ** ******************************* **  *****  * *         *                                   **                                                             ***   ***                                                                                               **    **             ****  ****              *   *    *   * *                               **      **                               *          *                      *  *  *  **                       **                                                                                                                                                                                                             ***                                        ***  ***                                       *                                                  *  **    *    **  **    *    **  *                              * *      * * *              * * *      * *                                                                                                                             **    ***   ***    **             * **      * **                       **                                 **   *                                                * * *            * * *                                                                                                                                                                                                                **                                                                      *                     ***   ***              ** *      ** *        *  * **                           ** *  *                                                                                                                      ** * **                                                                                                                                                                                                                                                                                                                  **    ***                                                                                                                          * *        * *                                                                                             **  **    **  **    **          *     *         * *                 **     *                                                   * ** *  *                                                                                                                                                                                                                                                                                                                                                                                                 ***                      *
             *  * *    ** * *                               * * **    * *  *       * ** * * * * * * * * * * * * * * * * *                                                                                                                                                                                           *  *  *  *             ** * *    * * * **                              **      *                                                                    **   ** *                                                                                                                                                                                                                                                                                                                                                                                    *** *       * **** *       * ***                                **     * * *                * * *     **                                                                                                                                                                    **        **                                                       ***   *                                                  *                *                                                                                                                                                                                                                 **                                                      ***   ***         **                  ** ** ** **           **        **           * * *     *                     *     * * *                                                                                                                                                                                                                                                                                                                                                                                                                                              **                                                                                                                                  *          *                                                                                               *    ** *      ** *            *     *         **                    ***  *                                                  ** *   **                                                                                                                                                                                                                    **            *  **                                                                                                                                                           ***                      **
              **  *       *                                   *       *  **         *  ********************************  *                                                           *    * *    *                                                                                                                 ***  **  ***           *  ** *    * **                                  **        *                                                                                                                                                                                                                                                                                                                                                          **** ** ****                                                                                               ** **          ** **                                           *    *                  *    *                                                   ***   ***                                                                                                             *         *                      **                                *                 **   **                              *  *              *  *                                                                                                                                                                                                                                                                      *  *   *  *       **                  ***       ***           *         *            *  *    * *                   * *    *  *                                                                                                          ***         *     *                                                                                                                                                                                                                                                                                                                                                                                                                                                      *          *                                                                                              *     * **      * **         **  *   *                                *      *                                               **   ***                                                                                                                                                                                                                        * **       *   **  **                                                                                                                    **                                 ***                 **
               * *  ****   ** ***************************** **   ****  * *           * * * * * * * * * * * * * * * * * ** *                                                          *    * *    *                                                                                                                 *  **  **  *            *                                                 ****   ****                                                                                                                                                                                                                                                                                                                                                        *  **  **  *                                     *                                                     **         **  **         **                                       *   *                    *   *                                                   * *   * *                                ***   ***                                                                     *         *     *         ***  * *                                *           ***  *  *  **                                 *       ***    *                                                                                                                                          **      **                                                                                                                     ** *   * **    *                                             *         *                **  *  *     ***   ***     *  *  **                                                                                                            *   *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               **  **    **  **    **      * *   ***                              ** * *   *                                                 **    *                                                                                                                                                                                                                    *  *  **       *       **                                                                                                                   * *                              ***                    *
               * ** * *  ***  ** *********************** **  ***  * * ** *          **                                   *                                                           *    * *    *                                         ***   ***                                                                ** **** **            ** ***      ***                                    ** *  *    *                                                                                                                                                                                                                                                                                                                                                                                                       ***                                                    *           *  *           *                                                                                                                        ***   ***    **                    ***   * *   * *   ***                                                              **        **     ***       * *   *                                     *       * *   * *                                 *   *       * *    *   *                                                                                                                                      **      **                                                                                     * *                                          * *                        *       *            **        **                    **      * *   * *      **                                                                                                                *     *        ** **          ** * **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    *     *   *     *       *                                       * * *   *                                                **  ** * **                                                                                                                                                                                                                 * *             ****                                                                                                                        *                                ***                     ***
             * *   ** * *  ** * *                       * * **  * * **   * *          * * * * * * * * * * * * * * * * * *                                                              ***   ***                                                                                                                                            *    *  *    *                                     ***** ** *                                                                                                                    **                                                                                                                                                                                                                                                                                 ***                                                     *         *    *         *                                          **                      **                                                 **             *  *                          ***   ***                                                                ** *      ** *          *      * *    ***                                 * *      * *    *                                  *   *       * *    *   *                                                                                                                                                                                                                                     **                                            **                    *                          * **      * **                        ***   ***                                                                                                                        ** * **          *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   **   *     *   *     *     **                                       * ** *                **                                     ** * *                                                                                                                                                                                                                   *                                                                                                                                         **                                ***                       *
             ** **   ** **    *                           *    ** **   ** **        ** ******************************** **                                                                                                               *    * *    *                                                              **  **  **              * *  *  *  * *                                        * * **                                                                                                                    ****                                                                                                                                                                                                                                                                                                                                       **         **  **         **                                                                                                                   * *             ***                  **                       **                                                       * **      * **         * *              *                             **  *  *                *                                  *              *                                                                                                                                                                                                        *       *                         *                                                                  **                         ** *      ** *                                                                                                                                                                                       *     *         ***                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     *  **    **  **    **                            **                 *  *                 *         *          **                *  * *
                * **    * **   ** ********************* **   ** *    ** *            * * * * * * * * * * * * * * * * * *  *                                                          ***       ***                                       *    * *    *                                                              *  *  *  *             ** * *    * * **                                       * *                                                                                                                      *  * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     *                                   * *                       * *                                                          **  **             **                                             **   **                 *                               *  *              *  *                                                                                                                                       ***    ***                                                  ** **   ** **                                                                                         * *                             **        **                                                                                                                                                                                                    *   *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                   *     ** *      ** *                              **                  **            **     ***       **         *                 *  *                                                                                                                                                                                                                    **
                *  * **  **  ***  ** *************** **  ***  **  ** *  *          *                                    *  *                        ***   ***                  ***  *    *   *    *  ***                                 *    * *    *                                                                **  **                  *        *                                   **    *   ***                                     *                                                                            * *  **                                                                                                                                     *                                                                                                                                         * *                                                                                                                                                                                                  ** *             ***                 *                           *                                                          *   *                                                                               *   ***                                 *                *                                                                                                                                           *    *                                                                                            **     **                                                                                      *         *              **                     **                                                                                                                   *                           ** **        *     *                                                                                                            **                                                                                                                                                                                                                                                                                                                                                                                                                    **    * **      * **                                                                **       *      **       ***     **            **                                                                                                                                                                                                                     **
                 * * *      *  ** * *               * * **  *      * * *          * *** * * * * * * * * * * * * * * * * * **                                                        *    *   *    *                                        ***   ***                                                                                          **      **                                   *  * ***     *                                    *                                                                           * *                                                                                                                                         * *                                                                                                                                         *                                                                                                                                                                                                  *  **             *  *               **                           **                                                          *   *             **                                                               *   **                                * * *            * * *                                                                                                                                       **      **                                                     * * * *                              * ** ** *                                                                                     *         *          **  *  *                   *  *  **                                                                                                             * *                            *          ** * **                                                                                           **               * *                           **                                                                                                                                                     *                                                                                                                                                                                                                                                                                                                                             *       **
                  *  *   ** **    *                   *    ** **   *  *           *  * ********************************* *                        *    * *    *              *    * *    *   *    * *    *                                                 *                                                                                                                                 ** *  * ***                                    ***                                                                         **                                                                                                                                           * ***                                                                                                                                                                                                                                                                                                                                          **     ***   ***    **                          ***   ***                                                                    **  **             *        *                                            ***        *   **  ***                           ** * *          * * **                                                                                                                       **                                      **                                   *   * *   *                             * * * *                                                                                      **        **      *  *    * *                   * *    *  *                                                                                                          * *                                                                                                                                         **                 *                 **       * *               **                                                                                                                                    * *                                                                                                 **              *                                                                                                                                         **
                     **  ** * **   ** ************* **   ** * **  **               *   * * * * * * * * * * * * * * * * * *                        *    * *    *              *    *                 *    *                               ***       ***   *****                                                                                                                                * ** * *                                                                            ***                ***                ***                                                                                                                                       * **    *                                                                                                                                                                                                                                                                                                                                                * *   * *                          ***   * *   * *   ***                                                          ** *      ** *          *      * * * **                                             **        ***                                *  *        *  *                                              **          **                                                             * *                                      * *                                  *  ** **  *           * *               * * * *                                                                                  * **      * **       * * *     *                     *     * * *                                                                                                         **          *                                                                                                                                                ***                 **       *                 **                                                                                                                   **                  **                                                                                               **   **        **               **                                                                                                                       * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              **
                             **  ***  ** ******* **  ***  **                        ***                                 * **                      *    * *    *              *    *  ***       ***  *    *                         ***  *    *   *    * *     *                                                                                                                               *  * * *                                      ***                       *           **                  **                 * *                                                                                                                              **      **   ** *                                                                                                                                                                                                                                                                                                                                                ***   ***                                ***   ***                                                                * **      * **         **     * ** ** *                                            *  *       ***                                ***  ******  ***                                             *  *        *  *                                                            * * **   **                      **   ** * *                                   ***   ***             **              *       *                                               * *                               ** *      ** *        *  * **                           ** *  *                                                                                                         *          **    ***                          *                                                                                                                              **            ***                                                                                                                                  *   *                 **          *                                                                                         **       **                **                                                                                                                       *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    *                            *
                                *  ** * *       * * **  *                               * * * * * * * * * * * * * * * * *  *                        ***   ***                  ***                   ***                                *    *   *    * *  * * *                                                                                                                               **   *                                       ***                       *            **                **                   **                             **    ** *                                                       **                             * *         ** * **                                                                                                                                                                                                                                                                                                                                                                               **                       **                     **    ***   ***    **                                           *                                                    * *                                              **      **                                                ***  ******  ***                                                             * * *   **                      **   * * *                                     *     *              *                                                                        **                                                        *  *                           *  *                                                                                                           ***          **  *   *                        * *                                                                                                                            *  *                                                                                                                                          **   *     *                **         **                                                                                                   **  **                                                                                                                                   **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                               **  * *                         ***
                             ** **    *           *    ** **                          ********************************** *                                                                                                       *    * *    *   *    * *    * *                                                                                                                                                                          ** * **                    ***           *                  *               **                                  *    * **            **                  *                     * *                       ** *  *      ***** *                                                                                                                                                                                                                                                                                                                                                                                   * *                       * *                    *     * *   * *     *                                          **                                              ***    *                                              *          *                                                  **      **                                                                  *                                    *                                                                                                                                 *   *         **     **                                        *    *   **           **   *    *                                                                                                           *   *                                          * *            **                                                                                                              * *                                                                                                                                           **  ** *   *        *    * *          **           **                                                                                                                                                                                                                                            *    * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                            *  *** * *                      *
                             ** * **   ** ***** **   ** * **                         * * * * * * * * * * * * * * * * * * **                         ***   ***                  ***                   ***                         *    *                   **  *                                                                                                                                                                            ** **                                      **          **                 *  *                                *   **    **         *  *                 ***                   *                        * ** * **    *     * ** ** *                                                                                                                                                                                                                                                                                                                                                                            *                           *                 ** *     ***   ***     * **                                                                                       ***                                                   ** *    * **                                                 *          *                                                               *  *                                  *  *                                                  **                                                                            *            **     **                                         *****    *           *    *****                                                                                                           * *** *           *     *             *          **           * *                                                                                                ***            *                                                                                                                                                 *     *         *   *           ***       *   ***                                                                                                                                                                                                                                         **    ****                                                                                                                                                                                                                                                                                                                                                                                                                                                                             ******  *                      **
                                 **  ***  ** **  ***  **                             *                                     *                      *    * *    *              *    *  ***       ***  *    *                       *    *  ***       ***                                                                                                                                                                                   *       *                   ***           ** *            * **               *                                  **  *     *         *  *                **   *               ** *                        *    *        ****     **                                                                                                                                                                                                                                                                                                                                                                              **                           **                *  * **             ** *  *                                                                                     **  ***  **                                                  **                                                      ** *    * **                                                                  *                                  *                                                     **            *           ** **                                        **   ***                                                                     * * *       * * *                                                                                                                   *****    *       **   **       ***    **          *         ***                                                                                **                 *       **                 ***                                                                                                                                  *   *     *  ***                **     ****    ** *                                                                    **                                                                                                                                                                   **** *                                                                                                                                                                                                                                                                                                                                                                                                                                                                               ** **
                                    *  ** *   * **  *                             ** *   ** * * *  ** * * *  ** * * *  ** **                      *    * *    *              *    *                 *    *                         ***                                                                                                                                                                                                  *  ** **  *                                 *                *                 *                                      *     *       * ** ***            *   ** *              ** *                      ** **** * **    * *   *  * *   * ***                                                                                                                                                                                                                                                                                                                                                                                                                      ** *               * **                                                                                       **       **                                                                                                               **                                                                   *   *     *       **    **       *     *   *                                                                *        *  * *  *                                     *  *                                                                     *   * * **       ** * *   *                                                                                                                        **                  *   *  **          ***        **                                                                                 **               * *       **                 *                 **                                                                                                                   **                             **  *    *    *  *     **                                                            *  *            **  **                                                                                                                                                                                                                       **                                                                                                                                                                                                                                                                                                                                                                                                         *  ******
                                 ** *     * * *     * **                          *  * *  *** ** *  *** ** *  *** ** *  **                        *    * *    *              *    * *    *   *    * *    *                 *                                                                                                                                                                                                          *     * *     *            **  ***  **        *                *         **       *  *                             **  **    **       *    *  * *          *** * *                 * **                  * *    * *    ** ** * **  * *   *                                                                                                                                                                                                                                                                                                                                                                                                                             *               *                                                                                          ***                                                                                                                                                                                            *   *   ** **     ***  ***     ** **   *   *                                   **     **                  ***        ***   ***                                     *       *                                                               * *  * *             * *  * *                                                                                                                      **                                     *   *       **                                                                                                  **                           * *               **                                                                                                                                                   *  *   *     ** *     **                                                            *  *           **                **                                                                                                                               *     **  ***                                                              * *                                                                                  **                                                                                                                                                                                                                                                                                                                    * * ***  *
                                  *  ***   * *   ***  *                             *  ***  ** * ***  ** * ***  ** * ***  **                                                        *    *   *    *                      *****   ***                                                               *                                *                                                                                                 ** *  * *  * **            * *  *  * *               ****                  * **    *                 **             *  *     *         *** * * **                 **            ** *                     *   ***  * *** * ** ***   **                                                                                                                                                                                                                                                                                                                                                *       *                                *       *                                **   **   **   **                                                                                            *                                                                                                                                                                            **          **      *     *       **    **       *     *                                       **     **                              *     *                    **     **         *  *   * *                                                               *    **             **    *                                                                                                                                           *     *           * *** *       * *                                                                                                                              **                                                                                                                                                                        * **   ***                                                                       **             **               **                                                                                                                              * ** * * * ** *                                                               *                                                                 **               * *                                                                                                                                                                                                                                                                                                                     * *  **
                                  *   *  * * * *  *   *                              **   *    *    *    *    *    *    *  *                        ***   ***                  ***  *    *   *    *  ***                *     * *    *                                                            * *                            *   **                                                                                           * ** * ***   *** * ** *         *       *         * *  *      *  * *       *  *  **     *                * *           *    *     *     ***    * *             ****     *           * *  *  *             ** * *  * *             ** ** ** *                                                                                                                                                                                                                                                                                                                                            * *     * *                              * *     * *                                   *  * *  *                                                                                                *                                                                                                                            **                                             *  *        *  *  *  *                                  *  *                                                                                                      **     **         ** ** ** **                                                                                                                                                                                                                                    **   **       *    *****         *                                                                                                                                                                                                                                                                  **                                            **                                             **  ** *      ** *                         *                                                                                                                                              * *   *   *     *                                                              **                                                                **                 *                                                                                                                                                                                                                                                                                                                      *
                               ** * *   ** * * **   * * **                            * ** **   * ** **   * ** **   * *  **                                                          ***       ***                     * * *  * *    *                                                                                          * **                         **         **                                                      *** ***             *** ***                         *   *  ****  *   *       * *           *  *             ***          **  **    **     *  ***** *             *      ** *             ** * *   **         * * * **  * * * *      *            ***                                                                                                                          *           *                                                                                                                                                                                                *       *                                *       *                                     **   **                                                                                                                                                                                                                              **                                             ***  ******  ***    *                                    *                                                                            **     **                                         * *                                                                                                                                                                                                                                                    **                                                                                                                                                                                                                                                                                        *                                                                                           *  * **      * **                                                                                                                                                                        * ***** * ***** *                                                                                                                                                 ***                                                                                                                                                                                                                                                                                                                         **
                               * ** **      *      ** ** *                            *  * *  * * *  *  * * *  *  * * ** *                                                                                             * *    * *    *                                                          *   **                           * * **                     *  * **     *                  *    **                                * ** * ***   *** * ** *         *       *         * *  *      *  * *        *             *                **              *     *         *    *               **  *  * *               *       *         * * *   * * * **      ** * * **    *****                                                                                                                        * *         * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             **      **     * * *                                * * *                                                                     *    **     **                                        ** **                                                                                                                                                                                                                                **                  **                                                                                                                                                                                                                                                                          **            *        **         *                                                                     *       **  **    **               *                                                                                                                                                       *     * *     *
                                                                                       **    ** *  *   ** *  *   ** *  *  *                                                            ***   ***                        *  **                                                                  *     *                           **  **                     **** *  *    ***               *** *  *                                   ** *  * *  * **            * *  *  * *               *  *                              *             * *           **   *     *         ****                  * * *  **              * ******           ** ****  ** *       *  * ** *    * *** *                                                                                                                        *           *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             *          *   * * **                                ** * *                                                                     **                                                                      *                                                                                                                                                                                                                 *                                    **   **                                                                                                                                                                                                                                                    **    *       *        **       * *  * *   * *                                                          **      *   *     *               **                                                                                                                                                        ***  * *  ***
                                                                                                 **        **        **  **                                                          *    * *    *                               ***                                                            * *                            *     *                    * *  *  *  **     *                 **  *                                   *     * *     *            **  ***  **        *      *  *      *        **              *  *    **  * *             *  **    **                               * * * *                 *                        **   *        * *    *  ***     ***                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                ** *    * **   * *                                      * *                                                  *     *           **                                                                        **                                                                                                                                                                                                                ***                                 **   **                                                                                                                                                                                                                                                 **     **        *             **   ** *   *  **                                                                    *   *     *              * *        *                                                                                                                                                *   *   *                                                                                                       ** *    * **      ** *
                                                                                                                                                                                     *    * *    *                                                                                                **      *                     * ***    * **             **                *              **     * ** **                               *  ** **  *                                 *                *        **               *      * *  *             *     ** *             **                   ** * *                  * **                  *  *   **        **    * *   *   *   *                                                                                                                   *****       *****                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                **         **                                      **                                                  ***   ***                                                                                   **                                                                                                                                                                                                                   *                                                                                                                                                                                                                                                                                 **     ***     *  **    *              **      *       *                                                           **      **  **    **                       * *                                                                                                                                                                                                                                                                * **    ** *      * **                        ***
                                                                                                                                                                                     *    * *    *                                                                                                        *                     * **     * ***                  **  *    ***               * **** *  * *                                 *       *                   ***           ** *            * **                         *      ****              **    * **             **                       *                  ** **                  **                    ** * *** * ****           **    ** *                                              **            **                                *    *       *    *                                                           *                                                                                                                                                                                                                                                                                                                                                                                                                  **    **  **    **                                                                                                                                                                                     ** *   * **                                                                                                                                                                                                                                                                                                           **                              ***                    **                                                                          **                                 **                                                                                                      **      **      ***** **                       ** * *                                                               *  ** *      ** *                          **                                                                                                                                                                                                                                                                    **      **  **           **                 *       **
                                                                                                                                                                                                                                                                                            *     **    ***                             *     *                 **   * ***                   *  **  *  *                                   ** **                                      **          **                             *  *   **                                                                                                                                   *   ***                *    * **                                          ** *  * **    ** *  * **                           *  *             *  *                                                        ***                                                                                                                                                                                                                                                                                                                                                                                                                   *     *   *     *                    *                                                                                    ***      ***                                                                                                                                        ***   ***                                                                                                                                                                                                          **                          *                              ***                    **                                                         **               * *       **             **       * *               **                                                                                                **    *                     *        * *                                                                *   * **      * **                                                                                                                                                                                                                                                                                                *        *  *            **               * *       **
                          **    **                                                                                                                                                     ***   ***                                                                                            *           **                 *              **  **            *** *   *  ** **             ***** * *  * *                                   ** * **                    ***           *                  *                           *  *                                                                                                                                         * * * ** *          *   **                  **                          **  *    *    *    *  **                        *  * **             ** *  *                                                    *        *  **                                                                                                                                                                                                                                                                                                                                                                                                        *     *   *     *      **            ***            **                                      **                            *   **  **   *                                                                                          *                                           *         *                                                                                                                                                                                                         **                       ***                                *                                                                                **                 *       **             **       *                 **                                                                                                **                         * *           *                                                              **      **  **    **                                                                                                                                                                                                                                                                                               *      *    *                            **
                         *  *   **                           **                                  *       *       *                                                                                                                                                                        ***       **  **  ***          **   *    *** *  * * **                * *        *            * *    * ** * **                                    ***                       *            **                **                            * *                                                                                                                                        **  *  * **          **  *                   * *                              *            *                            * * *     *       *     * * *                                          **       **      * *  *                                                      **   **                                                                                                                                                                                                                                                                                                                                           **    **  **    **     **           *   *           **                                      **              **            *            *                                                                  *   *                 * *                                           *   * *   *                 **                                                                                                                                                                                                               *                                                                                                                                    ***                               ***                                                                                                                                            *  *        *                                                                        *   *     *                                                                                                                                                                                                                                                                                               **      **  **                                                                                                                                                                                                                                                                                                                                                                                              *
                         *  *                        ** **    *   *                              * *     * *     * *                                                                                                                                                                      **      * **    ***               ** *         * **               *      **     *             *  **    *  **  *                                   ***                       *           **                  **                            *                                                                                                                                          * *  *                   *             *    * **                              * *      * *                              *  *    * *     * *    *  *             ** *      * **                 *               * * *                                                       * * * *                                                                                                                                                                                                                                                                                                                                             * **      * **                    ** **                                                                   **            **          **                                                                  *   *                  **                                            ***   ***                  * *                                                                                                                                                                                                                                                                          *                                                                                                                                                                                                                                            *             *  *                                                                        **       *   *     *                                                                                                                                                                                                                                                                                          ** *      **      ** *                                                                                                                                                                                                                                                                                                                                                                                        ***
                      ** **** ******                 ** * *   * ***          **  **            *       *       *                                                                                                                                                                          **  *** * *     ***            ** * *  * ***    *   **           *          *                  ** * * **    * *                                                                         ***                ***                       **                                                                                                                                              *  **               **  **            **     *                                       *                                     **  *  *     *  *  **                * **      ** *                 * *            ** * **                                       **  *            * *            *  **                                                                                                                                                                                                                                                                                                                              ** *      ** *                                                                                                            *  *  *  *                                                                                                                                          *     *                     *                                                                                        **             **                    **             **                                                             *                         **                                  *                                                                                                                                                                                                                                              *                                                                                         *      **  **    **                                                                                                                                                                                                                                                                                          * **       *      * **                                                                                                                                                                                                                                                                                                                                                                                       *
                      * *    *      *                   *      *            * *  **             *****   *****   *****                                                                                                                                                                       ***                          **  **              *             ** **  *   * ***               * *  *   *****                                    ***                                                                                **                                                                                                                                             **                    *    ** *       *  *                                           * *                                         **       **                         **  **                      **          *   **   *                                      *  * *          ** **          * *  *                                                                                                                             *       *                                                                                                                                                                                            **        **                                                                                                          ***    ***                                                                                               **                                                                     **                                                                                      ***             ***                  ***             ***                                                             **                       **                                  *                                                                                         ** **                                                                                                                                              ***            *  *                                                                        *   ** *      ** *                                                                                                                                                                                                                                                                                          **          *     **    **                                                                                                                                                                                                                                                                                                                       **                                                            **
                        *  *  *  *  *                   * **     ****       *                  *       *       *                                                                                                                                                                            ***      *                    *     *                            *** *   **                  *  * ***                                            *                                                                                                                                                                                                                                                     *     * **       ***                                         *     *                                            **                              *    *                          ***        **  ** *                                      * * *                         * * *                                                                                                                             * *     * *                                                                                                                                                                                            *         *                                                                                                                                                                                                                   * *                                                                                                                                                           * **             ** *                * **             ** *                                               **          **                                                                                                                                      ***             ** **             ***                                                                                                                    **                       **                                                                          **  * **      * **                               *                                                                                                                                                                                                                                                          *           **    *     *                                                    *                     **                                                                                                                                                                                                                                             *
                        *** **  *** **               ** *       **  *     ** ******              * *     * *     * *                                                                                                                                                                                * *                    *** *     ** *                  ***    *  **                  * *  * **** *                                       *                                                                                  *                                                                                                                                                                  **  **    **                                                *     *                                             * *                              *  *                  **       * *    *   * *  * *                                     ** * **                       ** * **                                                                                                                             *       *                                                                                                                                                                                            *         *                                                                                                                                                                                                                      *                                                                                                                                                          * *                 * *              * *                 * *                                              **                                                  *                                                                              **                 *                               *                 **                                                                                                     *                                                                                                                                      *          *****                                                                                                                                                                                                                                                         *        **       *     *                                                    **         **       * *               **                                                                                                                                                                                                                            * *
                      **  **  *** **  *              *  ***    *   *     *   *    *            *   *   *   *   *   *                                                                                                                                                                                                        ** *    *** *                 *                **           ** ** *     **                                                                                                                         * *                                                                                                                                                                     *     *                ***                               * *                                           *  *  *                              **  **                *  *      ***        **  ***                                     *   **   *                   *   **   *                                                 *                            *       *                                                                                                                                                                                                                                          **        **                  ** **                                                         *                                                                                                                                    **                                                                                                                                                         *  *               *  *              *  *               *  *                                                                                                   **               **   **                                                      **               * *                               * *               **                                                                                        **            *                                                                                                                          **        **         ** *  *                                                                                                                                                                                                                                                       **         *      **    **                                                   **          **       *                 **                                                                                                                                                                                                                             **        **
                     *   *   *   *   * *              **       *         *   * * *         *     *   *   *   *   *   * * *                                                                                                                                                                        *   **                           *     *                *     **  *  *  * *                 *  **                                                                                                                       **  *  *                                                                                                                                                                 **   *     *              *  *                                *                                           *                                 ** *      * **       *  *  * *              *   **                                        * **  **        ***   ***        **  ** *                                               * *                          * *     * *                                                                                                                                                                                                   **       **                                            **           *   *           **                             **            ***                                                                                                                                                                                                                                                                           ** ** *             **    ***   ***    **                **    ***   ***    **                                               *               * *                                 **                   *         **                                                               **                                 **                                                                                                         **    *       *                                                                                                                          **       **         *       *                                                                                                                                                                                                                                                        ** *    *         ** *                                                                          ***                                                                                    **                                                **           *               *                                                                                    **
                **  * *   *   *   *   * *               *  * *   * * * *   *   *         * * **   *   *   *   *   *     *                                                                                                                                                                        *     *                          **  **                   ***    *  * ****                   *  * ***                                                                                                                    ** *                                                                                                                                                                      *  **    **         *     **                             * *      * *                                  **          ***                     * **      ** *       ***** * **               ** * *****                                  * *  * *   *    * *   * *    *   * *  * *                                        *       *                            *       *                                                                                                                   **                                                                              *  *     *  *                                           **            ***            **                             **           *   *                                       **                                                                                                                                                                                                                                **  ** **                                                                                                                    * *              *                                                     *     *      *  *                                                                                                                                                                                                        **     **        *                                                                                                                                    **  **     ** *  *                                                                                                                                                                                                                                                         * **    **        * **                                                                                                                                                                  *                                                *            ***           ***
                *   *** *** *** *** **  ***             *                                  *    *   *   *   *   *   * * * **                                                                                                                                                                      * *                             ** * *                      *     ** *  *                    **    *                                                                                                                        **                                                                                                                                                                   *     ** *         ** *    *                             *            *                              *      ** *    ***                   **              **           **   *              * *  *  *                                   ***  **        ***   ***        **  ***                                        * *                                                                                                                                                               *                                                                        *     * * *     * * *     *                   **        **                    *                                                         ** **          *                            * *                                                                                                                                                                                                                                       *                     * *                                  * *                                                       * *     **      **  *                           ***                     ** **                                                                                                                                                                                                           **     ***     *  **    *       **       *     * *                                                 *                                                                      *****                                                                                                                                                                                                                                                                                                                                                                                                                                                  * *                     **                     * *               *         *
                 ***  ** *** *** *** ***   *             **  * * * *   * * *       *    ** * * *   *   *   *   *   *    *                                                                                                                                                                           **                               ** *                    **         **                                                                                                                                                                                                                                                                                                                         **    * **          * *                             **  *    *    *    *  **                            *   *  *    ***                   *                *       ***  **        ***      *  *                                            **   *                   *   **                                             *                                                                                                                                                        * ** ** *     **                                                                **    *** *       * ***    **                  **        **                                                                                              *                             *                                                                                                                                                                           * **      ** *                     **               **                   **       * *       **                **       * *       **                                               *     * *      ** **                          *   *                     * *            *                                                                                                                                                                                               **      **      ***** **        * *    * *     **                                                *   *                                                                      *                                                                                                                                                           **    **                                                                                                                                                                                                                                                                                  **       **            **            *        **               **         **                                                                                   ***                        **
              ***    *   *   *   *   *   * *                                     ***       *     *   *   *   *   *   ** * *                                                                                                                                                                                                       **   *                                                                                                                                                                                                                                                                                                                                                                                **                             ** *  * **    ** *  * **                            *** *   *      ***                 *              *       * *  * *   *    * *       **                                       ***** * **                       ** * *****                                                                                                                                                                                         **     ** * * *      *                                                                * **   ***           ***   ** *                                                                                                                         ***                             **                                                                                                                                                                          ** *      * **                     **               **     **           *  *   *  * *  *   *  *              *  *   *  * *  *   *  *                                                    * * **   **                            *     *                     *                                                                                                                                                                                                                        **    *                *     **      *                                                     *                                                                                                                                                                                                                                 * *  * *                                                                                                                                                                                         ***                                                                                              * *                          **                                                                                              **                          *                        **
             *  * *   *   *   *   *   *  * * **            * * *   * * * *  **  *         * * *   *   *   *   *   *     *                                                                                                                                                                                                           *                                                                                                                                                                                                                                                                                                                                                                                                                      **            **                             *           *     ***                **              **      * **  **        ***                                                *  *  * *                         * *  *  *                                                                                                                          ***   ***                                                      *            *        *                                                              ***  *                     *  ***                                                                                                                                      **                                                                                                                                                                                          **        **                                                 **           * * *             * * *              * * *             * * *                                                     * * *                                 *     *                     *           **                                                                                                                                                                                                           **                     **                                                             *    *                                                       **  **                                                                                                                                                                      ****                                                                                                                                                                                           *                 **                                                                             *                             **                                                                                              *                        ***                                                                                                                                                                                                                                                                                                                                            **     **
             *  * * *** *** *** *** ***  * * **                               *  *              *   *   *   *   *   *                                                                     *  *                                                                                                                                                                                                                                                                                                                                                                                                                                                       **                                                                                                                                                  *   * ***        ***                  ** *      * **         *   **   *          **                                                 *  *        *       *        *  *                                                                                                                               * *   * *                                              * ** ** *                    **                                                                * * *                   * * *                                                                                                                                        *                                                                           **     **                                                                                                        *        *                                           *                    * ***  **   **  *** *                * ***  **   **  *** *                                            ** * **     *                                      *          * *                      *                                                                                                                                                                                                                                                                                                    *****                                             **       **                **                                                                                                                                                       *  **  *                                                                                                                                                                                         * *               **                                                                             ***                      **  **                                                                                               * *                                                                                                                                                                                                                                                                                                                                                                     **     **
              ***  *  ** *** *** *** * *   *               *   * * * *   * *  ** *             *   *   *   *   *   *                                                                      *  *                                                                                                                                                                                                                                                                                                                                                                                                                                                   **  *                                                                                                                                                    *  *   *                             * **      ** *          ** * **            * *                                                 **        * *     * *        **                                                                                                                                ***   ***                                              ** * * *                                                                                        * * *                 * * *                                                                                                             ** **                        ***       **                                                               **     **                                                              **     **                                *          *                                          ** **  **              ***           ***                    ***           ***                                              *     *   *  *                                   *   *         **                                                                                                                                                                                                                                                  *           **                                                                    **                                       **        **               **   **                                                                                                                                                  *  **  *                                                                                                                                                                                          **                                                                                                                                                                                                                             **
                 * * *   *   *   *   * * * *           **                      * **        *     *   *   *   *   *   * * *                                                               **  **                                               *  *                                                                                                                                                                                                                                                     **                                                                                                                                       *  * *                                                                                                                                                    * **      *                                                   * * *               *                                                            *       *                                                              ***                            ***   ***                         *                               *                                        *    ***               **                                                                  *  ***             ***  *                                                         **                                      **           *   *                          *       **                                                                                                                                      **     **                                **        **              *  *                 ** *    * ** **                        *                                 *                                                         *   *       *                                    ***          *                                                                                                                     **                                                                                                                             *         * *                                                                    * *                                                 *                    **                                                                                                                                                    *  *                  **    **
                * * * *   *   *   *   * * *            * * * * * *   * * * * * *         * * **   *   *   *   *   *     *                                                              ***    ***                                             *  *                                                                                                                                                                                    *                                                                **                                                                                                                                   ** *  *  **                                                                                                                                                         **                                                     *  * *      **       **                                                                                                                                  * *                            * *   * *                        * *      ***           ***      * *                                                        ***  * *                                                                   ** *               * **                                                          **                                      **            ***                                                                                                                                                                                                                      * **      ** *              *                *   *                                 *  *                              *  *                                                        ***    *   *                                     *                                **   **                                                                                          *                                                                                                                            ***           *                                                                      *                                                                                                                                                                                                                                                  * *  * *
                *   * * *** *** *** **  *  ***      ** *                      **           *    *   *   *   *   *   * * * **                                                                                                                 **  **                                                                                                                                                                                  * *                                                               **                                                                                                                                   * ** * * *                                                                                                                                                         *                                                       **  *        *                                                                                                                                     ***   ***                            ***   ***                         *       * *           * *       *                                                         * *   *                                                                     **                 **                                                                                                                  *            **                                                                                                                                                                                                         ** *      * **               **               ***                                  *  *                              *  *                                                                   *                *                                                     **   **                                                                                        * *                                                                                                                                                                                                                 **                                                                                                                                                                                                                                  ***              ****                                                                                                                                                                                                                                                                    ***                      **  **                          ***   ***
             ** * *  *** *** *** *** *** * *  *      * **  * *   * * * *   *            ** * * *   *   *   *   *   *    *                                                                                                                  ***    ***                                                                                                                                                                               * * *                                                               *                                                                                                                                        ***   *                                                                                                                                                   *  *                                                                  ***                                                                                                                                      * *                 *            **                      *                     ***           ***                                                        **       * *    ***                                                                  *                   *                                                                                                                               * *                                                                                                                                                                                                            **  **    **       * **      *                                                   *                                 *                                                                 *  *                 **                                        *           *****                                                                           *             **                                                                                                                                                     **                                                                                                                                                                                                                                                                                               *** *          *  **  *                                                                                                                                                                                                                                                                  *                             **                        *  *   *  *
             ** * *  *   *   *   *   *   * *  *      *  *                                  *     *   *   *   *   *   ** * *                                                           ***      ***                                                                                                                                                                                                                                  *   ***                                                            * *                                                                                                                            *      **** * *** * **                    **                                                                                                                                                                                               *                                                                                                                                        ***       ***      * *          * *            ***      * *                                                                             *         ***  *  *               *                                                                                                                                             **                                                                         *                                                                                                                                                                                                             *  *     *        *  *   *                                             ***           ***                ***           ***                                                             *                 **                   **                                 * *                                                                           **                                                                                                                                                                    *                                                                                                                                                                                                                                                                                                 * * *         *  **  *                                                                                                                                                                                                                                                                  * *                          **                         ** *   * **
                * *   *   *   *   *   *    ***        *  **  * * * *   * * *       *      * * *   *   *   *   *   *     *                                                            **          **                                                                                                                                                                                                                              ** **                                                            *** * *                                                                      **      **                                            * *    *   *   *   * *    **        **   *  *                                                                                                                                                                                                                                                                                                                                    **            * *       *           *              * *       *                                                                              ***       * *   * *                                                                                                                                                        ** *    * **                                                                    **       *                                                                                                                                  **     **                                                        *    *     *      *   * ***                                           * ***  **   **  *** *            * ***  **   **  *** *                                                         * * *                                    **                        ***                                                                                   **                                                                                                                                                                      ***                                                                                                                                                                                                                                                                                        ***    *  *           *  *                                                                                                                                                                                                                                                            **       **            **            *        **                                                                                                                                                                                       *  *
                *   *** *** *** *** **  ***        ***                           ***            *   *   *   *   *   *                                  *  *                       *  *            *  *                                    ***      ***                                                                                                                                                                          * *   * *            **       **              **       **         **** *                                                                       **      **                                            * ***   ***     ***  *    * *        *   **                                                                                                                                                                                                                                                                                                                                     * *            ***                  **     **       ***                                                                                         *      * *    *                                                                                   *     ***   ***     *                                                 *          *                                                                              *                                                                                                                                 **     **                                                        **  **    **     *           *             **                        * * *             * * *          * * *             * * *                                                       * * **                           **                   **     **    *   *     ***                                                                           **  **                                                                                                                                               **                  *                                                                                                                                                                                                                                                                                                **                    * *                                                                                                                                                                                                                                                    * *                     **                     * *                                                                                                                                                                                     *                                                                                                                                                                                                                                                                        *     *
                 ***  ** *** *** *** ***   *       *       * * *   * * * *  **  *              *   *   *   *   *   *                                   *  *                       *  *            *  *                                   **          **                                                                                                                                                                         *  **   *            ***     ***              ***     ***             *                                                                                                                           * **    *    * *** *    * ** *  *       * **  **** **                                                                                                                                                                                                                                                                                                                              *                                          **                                       ***           ***                                          * *                                                                                                **    * *   * *    **                                                  **      **                                                                             ***                                                                                                                                                                                              * **      ** *          *** *   *              **                        *  *   *  * *  *   *  *          *  *   *  * *  *   *  *                                                       * *       *    *          *       *                   *      **   *     *                                                    **              ***                                      **                                                                                                                        **                                                                                                                                                                                                                                                                                           **            *     *                        *                                                                                                                                                                                                                                                       *                                                *                                                                                                                                                                                   **                                                                                                                                                                                                                                                                        ***   ***
              ***    *   *   *   *   *   * *                                  *  *         *     *   *   *   *   *   * * *                            **  **                     **                  **                               *  *            *  *                                                                                                                                             **                        **  *   **       *               *        *               *                                                                                                                              **      **   ** *     *****    ** * * **      ** * * *   * * *                                                                                                                                                                                                                                                                                                                            **      **                                                                   *       * *           * *       *                                  **               ***    *                                                                         ** *   ***   ***   * **                                              ***  ******  ***                                             **                                                                                                                                                                                                                            ** *      * **          *   *  *                                          **       * *       **            **       * *       **                                                    *    **      ***   ***         **     * *      * *      * *           ** * **                                                    **            *   *                                      * *       **                                                                                                                                                                                                                                                                                                                      **                        **                                                        *  *           *     *                         *  *                                                                                                                                                                                                                                                  **                                                **                                                                                                                                                                               *      ** *                                                                                                                                                                                                                                                                 ** *   * **
             *  * *   *   *   *   *   *  * * **            *   * * * *   * *  ** *       * * **   *   *   *   *   *     *                           ***    ***                 ***                    ***                             *  *            *  *                                              *      *      *                                * *                              ** **** **  ** **                          **   *    **  * * * ******* * * * *  * * * * ******* * * *  **                                                                               *      *                                 * *         ** * **     ***            *      * * * *  ** * * *                                **      **                                                                                                                                                                                                                                                                                          * *                                                                 * *      ***           ***      * *                                                        * * * **                                                                  *  ***             ***  *                                             *  *        *  *                                             **                                                                                                                                                                                                                                                 *      ** *                                                   * *                              * *                                                              *           * **     *       **       **     *  *      **                                                                                    *    *                                        *       **                                                                                                   *                                                                                                                                                                                                                  **                        **                                                       * * *           *     *                    *    * * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       *   *  *
             *  * * *** *** *** *** ***  * * **        **                      * **        *    *   *   *   *   *   * * * **                                                                                                         **                  **                                     **      **     **     **     ** *   *    ** *    *   *  *                               *  *  *  *  *  *                           *  * *   *  *         * *         *  *         * *         *  *                                                                        **  ** **  ** **  **                     ** *  *      ***** *                * ** ** **             * *  * * **                              *  *    *  *                                                                           **             **                                                                                                                                                                                              **   ***                               **   ***                     *                               *                                  **                    * ** ** *                                                                 * * *                 * * *                                             **          **                                                                                                                                                                                                                                                                                                    **                                                                                                                                                         ***            ***    **                      **              *                                                                                *   *            **  **                     ***                                                                                                           * *                                                                                                                                                                                                                         **                                                                         *  *                                       *     *  *                                                                                                                                                                                                                                                                                                                                                                                                                                                 **                                    *** *   *
              ***  *  ** *** *** *** * *   *           * * * * * *   * * * * * *        ** * * *   *   *   *   *   *    *                                                                                                          ***                    * *                                       * * ** * * ** * * ** *      *   **      *   **    * * **                           ** **  ** **** **                         * *        *  * *     *** ***     *  **  *     *** ***     * *  *                                                                        **    *      *    **                    * ** * **    *     * ** ** *            **   *** ** * *** *  ***   *                                 * *      * *                                                                       ** *  * **     ** *  * **                                                                                                                                                                                               * *       *                       **   * *       *                         ***   ***                                              *        *            *                                                                        * * *                   * * *                                                                                                                                                                                                                                                                                                                                                                *                                               **    ***   ***    **            **    ***   ***    **                                                                  **                           **   *          **                                                                                                 **                                                                                                                            **          ** *        * *                                                                                                                                                                                                            *  *                                                                       *                  ***                      *      **                                                                                                                                                                                                                                                                                                                                                                                                                                       **         **                                 *           *                                                                                                                                                                                                                                                                  *   *
                 * * *   *   *   *   * * * *        ** *                      **           *     *   *   *   *   *   ** * *                         ***    ***                 ***                    ***                                                    *                              ** *  * *    * *    * *    * * * *    **** * *    * **** ** *             ** **** **  ** **                                          **     ***       **  **     **  **        **  **     **  **       *  *                                                                                                           *    *        ****     **          *   * *  ** * ** **    * *    * *                               **  ***  ***  **                              **                                     **  *    *     *    *  **                                                                                                                                                                                               ***      * *                           ***      * *                        * *   * *                                               *      * * * **     **                                                                      ***  *                     *  ***                                                                                                           **                                                                                                                                                                                                                                                  *  *                                          *  *               *  *          *  *               *  *                                                                                                **       * *   **                 *                                                              *   *            **                                                                                                                           **          ** **      *  *                                                                                                                                                                                                             **                                                                         * *   *                                                                                                                                                                                                                                                                                                                                                                                                       ** *      * **      ** *                                                 ****    **                                         *   * ***                                                                                                                                                                                                                                                                     *   *
                * * * *   *   *   *   * * *          * **  * *   * * * *   *              * * *   *   *   *   *   *     *                             **  **                     **                  **                                                     **                            *  * ****                           **     *    **    *       * *           *  *  *  *  *  *                                               ** *            **  ***  **              **  ***  **             *                                                                                                         ** **** * **    * *   *  * *   * *** *   * *  *   * *    ** * **** **                               *      *  *      *                         ** *  * **                                      *             *                                                                                                                                                                                                              *                                      *                         ***   ***                                              **     * ** ** *                                                                              * **   ***           ***   ** *                                                                                                       ** *    * **                                                                                                                                                                                                                                                                                           * *                 * *          * *                 * *                                                                                                 *  *    *                       *                                                               *    *            *                                                                                                                                       ** *      **          **                                                                                                                                                                                                         *                                                                           *                                ***   ***                                                                                                                                                                                                                                                                                                                                                              * **      ** *      * **                                                 *** **  **                                          *  *   *
                *   * * *** *** *** **  *  ***       *  *                                       *   *   *   *   *   *                                  *  *                       *  *            *  *                            ***                                                     ** *                                                          **           ** **  ** **** **                                              * *                                                           *    *                                                                                                       * *    * *    ** ** * **  * *   *          **     ****        *    *                                 * **          ** *                         **  *    *                                       * *       * *                                                         **   **                                                                                                                                                                                                                                                                              *                                                                                       **    *** *       * ***    **                                                                                                        *          *                                                                                                                                                                                                                                                                                            * **             ** *            * **             ** *                                                                                                   * *    **              **      ***                                                **            *   *                                      ***                                                                                                           * *     **   *        **                                                                                                                                                                                                        ***                                                             ** **        *                                                                                                                                                                                                                                                                                                                                                                                                     **    **  **        **                                                          *         ***                                  * **      *
             ** * *  *** *** *** *** *** * *  *       *  **  * * * *   * * *                   *   *   *   *   *   *                                   *  *                       *  *            *  *                           **                                                          *                                                                       **                                                             *                                                             **  * *                                                                 **    *      *    **                 *   ***  * *** * ** ***   **            * ** ** *     *    ** * ** *                                  * *          * *                               *                                                                                                                 * * * *                                                                                                                                   **                                     **                                                                                                 **                                                                                        *     * * *     * * *     *                                                                                                          **      **                            **                                                                                                                                                                                                                                                                ***             ***              ***             ***                                               *****                                                                        *            *                                            **              ***                                        *       **                                                                                                   *        **     **                                                                                                              **                        **                                                                  *****                                                            *                                                 *                                                                                                                                                                                                                                                                                                                                                                *     *    *        *                                                                      **                                        **
             ** * *  *   *   *   *   *   * *  *    ***                                     *     *   *   *   *   *   * * *                                                           **          **                           *  *                                                           **                                                                                                                                    **                                                                  * **                                                               **  ** **  ** **  **              ** * *  * *             ** ** ** *                * *****      *  * **                                     **   **   **                                  * *    ***                              **    **   **    **                                          **            * *            **                                                                                                                        *                                      *                                                                                                                                                                                                  *  *     *  *                                                                                                              ***  ******  ***                         * *                                                                                                                       *       *                                                                                                                                **             **                **             **                                               * *** *        *                                                           ***            ***                                                                                                    * *       **                                                                                                             *  *    *                                                                                                             **                        **                                         **                                                                                         **  *   ***   ***       *                        *                                                                                                                                                                                                                                                                                                                                                                 *     *  *          *                                      **                          **                                          *
                * *   *   *   *   *   *    ***     *       * * *   * * * *  **           * * **   *   *   *   *   *     *                                                             ***      ***                            *  *                                                                                                                                                                                                                                                                                                                                              *      *                     * * * **  * * * *      *            ***     ** * **         * *                                               * *                                              *** *                            **    **   **    **                                         *  *          ** **          *  *                                                                                                                    ***                                    ***                                                                                                                                                                                                    **       **                                                                                                               *  *        *  *                           *                                                                                                                                                                                                                                                                                                                                                                  *   *       * *            **   **            *                           *             *****                                                                                                   **                                                                                                                        * *                                                                                       **  **    **  **    **             **                                                          *  **                                                                                        ***                    *        *               *                                                                                                                                                                                                                                                                                                                           **         **                        **    **  **        **                                      **                          ***                                     *  *                                                                                                                                                                                                                                                                       *
                *   *** *** *** *** **  ***                                   *            *    *   *   *   *   *   * * * **                                                                                                 **                                                                                                                                                                                                                                                                                                                                                                              * * *   * * * **      ** * * **    *****     * **   **      **                                                **                                           **   * * *                           **               **                                    *  *  * *                         * *  *  *                                                                                                               *                                      *                                                                                                                                                                                                                                                                                                                                 **          **                            **                                                                                                                    ***       ***                                                                                                                                                                                                                                 ***     *   **        **   *****              **                                      **   **                                                                           *                                                                                                                                                                                                                                           *   *     *   *     *            *  *                                                           ****                                                                                       ***        *           *        *                                                                                                                                         **       **                                                                                                                                                                                       **         **                          ** *      * **      ** *                                                               * *                                                                                                                                                                                                                                                                                                              * *
                 ***  ** *** *** *** ***   *           *   *   * * * *   * *  *         ** * * *   *   *   *   *   *    *                                                                                                  * *                                                                                            *             *             *                                                                                                                                                *  *                                                                                                   ** ****  ** *       *  * ** *    * *** *    *    ** *                                                    **        **                                     **    *  *                            *    **   **    *                                     ***** * **                       ** * *****                          **   **          **   **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       ** ** ** **                                                                                                                                                                                                                                   *    ***            **    ** **             **                              *                                                                                        * *                                                                                                                                                                                                                                          *   *     *   *     *              **                                                         *     **                    *****                                                            **  *       *                    *                                                                                                                                          *        *                                                                                                                                                                                                                              * **      ** *      * **                                                   **           **                                                                                                                                                                                             *                                                                                                               ** **
                   * *   *   *   *   * *  **         * * *   *         *       **          *     *   *   *   *   *   ** * *                                                            ***    ***                         *                                                                        * **  * **  * **      * *           * *           * *    **                                                                                                                                         **                                                                      **      **                            **   *        * *    *  ***     ***   *** *                                                     * *          * *                                          **                            * *   **   **   * *                                          **   *                   *   **                                * * * *          * * * *                                                                                                                                            *       *                                                                                                                                                                                                                                                                                                                                                                                                                                                   ***   ***                                                                                                                                                                                                                                        *                 *   ** **                                               *                                                                                       **                                                                                                                                                                                                                                          **  **    **  **    **                                                                          ***   *                    ***                                                            *            *       ***   ***                                                                                                                                               * *      * *                                                                                                                    *               *                                                                                     **    **        **  **    **                                                 **                                                                                                                                                                                                         **        **                                                                                                     *   *
                    * *   *   *   *   *             *    *   *     *   *    ***  *        * * *   *   *   *   *   *     *                                                                **  **                           **                                                                       ** *  ** *  ** *       *             *             *     *                                                                                                                                                                                                                  **      **                          *  *   **        **    * *   *   *   *    * *                                                    * **          ** *                                  **                                  ** *             * **                                     ***  **        ***   ***        **  ***             **  *            * *              * *            *  **                                                                                                                            * *     * *                                                                                                                                                                                                                                                                                                                                                                                                                                                   *     *                                                                                                                                                                                                                                  **     **                     ***                                                                                                                                                    **                                                                                                                                                                                                                                    * **      * **                   ***                                                       *****             *        *                                                             ** **                         ***   ***       *                    ** **                                                                                                      **       **                                                                                                                    ***           ***                                                                                     *     *          *  *     *                                                                                **                                                                                                                                                             **           *** *     *  *                                                                                                   *** ***
                     *  ** ***  **  **              ****** **     *  **       * **              *   *   *   *   *   *                                                                     *  *                                                                                            *                            *     *       *     *       *     *   *                 **  **  **  **  **  **                                                                                                                                                                                                              **                    ** * *** * ****      *                                                     *      *  *      *                                  **                                                                                           * *  * *   *    * *   * *    *   * *  * *            *  * *          ** **            ** **          * *  *                                                                                                                             *       *                                                                                                                                                                                                                                                                                                                                                                              **        ***              **                                                                                                                                                                                                                                                                                   *                **                                *                            *        ***                                                                                        * *                                                                                                                                                                                                                             **    ** *      ** *                   * *                                                          *            * *            **                                                                                 *                    *                        *                                                                                                                                                                                                                                        *         *                                                                                         *     *        *    *     *                                                                               **                                                                                                                                                             **          **        ** ***                                                                                                   *   *
                      ** ***  ** ***                      *       ****     ** *                 * *     * *     * *                                                                       *  *                                                                                            ***      ***   ***   ***   ***********   ***********   ************ *                **  **  **  **  **  **                                                                                                                                                                                                                                        *   ***                                                                 **  ***  ***  **                                                                                                                                * **  **        ***   ***        **  ** *             * * *                                          * * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     **        *   *            **                                                                                                                                                                                                                                                                                ***                * *                                 **                       ***         ***                                                                                          *                                                                                                                                                                                                                              *        **        **                 ***                                                                  **    **           *  *                                                                                *        *           *          ***      *  **                                                                                                                                                                                                                                        **         **                                                                                       **    **        **  **    **      * ** **                                    ***                                                                                                                                                                                                       **        ** *                                                                                                    *   *
                       *  *  *  *  *                **  * *            *      *                     *       *       *                                                                                                                                                                        *    *   * *   * *   * *           * *           * *           * *                                                                   **                                                                                                    **                                                                                                     * * * ** *                                                              * *      * *                                                                          **               **                                      *   **   *                   *   **   *             ** * **                                        ** * **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              *    *                                                                                                                                                                                                                                                                                             *                    *                                **                                                                                                                                 **                                                                                                                                                    **                                                                      *          *         *                  **                                                                  **                  **                                                                                 *        *                                ***                                                                                                                                                                                                                                                                                                                                               ** *      * **      ** *       ** **  **                                    **        **                                                                                                                                                                                              *          *                                                                                                      * *    **
                       *      *    * *              **  **          *** *   * * **             *****   *****   *****                                                                                                                                                                        *     *   * *   * *   * *  **   **  * *  **   **  * *  **   **  * * **           **************************                         *  *                                                                                                    **                                                                                                    **  *  * **                                                              *  *    *  *                                                                          **               **                                       ** * **                       ** * **             *   **   *                                    *   **   *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              *   *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             *                                                                      **        *         *                   ***                                                                                             **                                                                                  *       ***   ***    *     *     ***                                                                                                                                                                                                      **    **    ** *      ** *                                                                                                               * **      ** *      * **       *                                         **       ****    **                                                                                                                                                                                                                                                                                                             *     **
                        ****** **** **                              *   *    ** **                  *       *       *                                                                                                                                                                       *   * *   * *   * *   * *   *   *   * *   *   *   * *   *   *   * * **          *  *     *     *     *     *                                                                                                                                                                                                                                       * *  *                                                                   **      **                                                                                                                                      * * *                         * * *             * **  **        ***   ***        ***   ***        **  ** *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             ***                                                         *                                                                                                                                                                                                                                        **           * *     **                                                                       **        **                  * *                                                                                             **            ** *      ** *      ** *                                ***                                *     *    *  **                                                                                  * **                                                                                                                *     *    * **      * **                                                                                                                                                     **                                 ***      *** **  **                                                                                                                                                                                          *
                               *  *                                     **                      * *     * *     * *                                                                                                                                                                             *                       *   *         *   *         *   *     *            * ** *   * *   * *   * *   * *                                                                                                                                *                                                                                                     *  **                                                                                                                                                                                                                    * * *                         * * *             * *  * *   *    * *   * *        * *   * *    *   * *  * *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             *   *       ***                                                                                                                                                                                                                                                                                       **   **                   ***                          *                    *         *                                                                                                                                                                                                                                        *             **     *  *                                                           **                                      ***                                                  **                                                       * **      * **      * **                                                          *        *     *         *                                                                           **   *  **  ***            **                                                                                            *     *   **    **  **    **                                                                          *   *                                                             **     **                                  * *          *                                                                                                         **    **    ** *      ** *      ** *    **    **                                    **
                          **   *  *                                                               *       *       *                                                                                                                                                                          *  * *   * *   * *   * *   *   *   * *   *   *   * *   *   *   * * **          *  *     *     *     *     *                        ** *                                                                                                    * *                                                                                                   **                                                                                                                                                                                                                       ** * **                       ** * **             ***  **        ***   ***        ***   ***        **  ***                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             *    *     ** * **                                                                                                                                     **                                  **                                                                                                          **   **                  *   *                    *     **                 **        * *                                                                                                                                                                                                                           *         * *                        *         * *                                               *                                                                                           ***               **                                         **  **    **  **    **                            *     *                     *                    ** **                                                                           **   *      **             **                                                                                            **    **  *     *   *     *                                                                           *   *                                                             **                                          **                                                                                                                     *     *    * **      * **      * **     *     *                       **          **             **                              **
                          **    **                                                                                                                                                                                                                                                           ** * *   * *   * *   * *  **   **  * *  **   **  * *  **   **  * * **           **************************                           * *  **                                                                                          **  *  *                                                                                                                                                                                                                                                                                                                           *   **   *                   *   **   *                **   *                                    *   **                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                       **        *   *     *     **                                                                                                                                    * *                                  * *                                                                                                                                 *     *                 ***    **                  * *      ** **                                                                                                                                                                                                                         * *        **                         *       *   *                                              *         **        **                       **                                        **  *  * *          **  **  **                                     *   *     *   *     *                             *     *                     *          ***                                                                                            **   ***                                                                                                              * **     *     *   *     *                                                                                                                                                    *                                                                                                                                                         *     *   **    **  **    **  **    **  *     *                        **           *** *         **                              **
                                                                                                                                                                                                                                                                                                * *   * *   * *   * *           * *           * *           * *                                                                    *    *                                                                                          ** *                                                                                                                                                                                                                                                                                                                              * **  **        ***   ***        **  ** *         ***** * **                                        ** * *****                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                 **        ***        ** * **                                                                                                                                    *                                      *                                                                                                           ***   ***              *   *         ***     *                                   *     *                                                                                         **                                                                                                                   **       * **                                   *       *                                                  **        **        **                      *  *                                       **  **  **          **  *  * *                                      *   *     *   *     *                            *     *                                                                                                                                 *   *                                                                                                               ** *    **    **  **    **          *     *                                                                                                                           **  ** **                                                                                                                                                         **    **  *     *   *     *   *     *   **    **      **                             **
                                                                                                                                                                                                                                                                                                *  ***   ***   ***   ***********   ***********   ************ *                **  **  **  **  **  **                               *                                                                                                  **                                                                                                                                                                                                                                                                                                                            * *  * *   *    * *   * *    *   * *  * *         *  *  * *                                          * *  *  *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                        ***                                                                                                                                    ** ****                              **** **                                                                                                         ***     *               ***            *     **                                     *                                                                                            * *                                                                                                                 * *      ** **                       **      *  *       *    *        **                                                                                 **                                            **                    ***                                      **  **    **  **    **              **                                                         ***                                                                                                      *     *                                                                                                   **  *     *   *     *          ***   ***                                                     ** *   * **                                                           ** ** *                                                                                                                                                            * **     *     *   *     *   *     *    * **        **                              *
                                                          * **    * **    * **                                                                                                                                                                                                                 **                      *     *       *     *       *     *   *                 **  **  **  **  **  **                               *  *   **      **      **                              **      **                                                                                                                                                                                                                                                                 *               *                                                                               ***  **        ***   ***        **  ***               *  *        *       *        *       *        *  *                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  **                                                                               * * *  *                              *  * * *                                                                                                         *     *                              *                   *                      **   **                                                                                           *                                                                                                                *      *** * **                       **      **          *            **                                                               **                        **                                                          **                                   ** *    *     *   *     *              *  *             ***                                      * ***                                                                                        *   *         *     *                                                                                                    *   *     *   *     *        ** *   * **                                                     ***   ***                                                                                                                                                                                                                               ** *    **    **  **    **  **    **    ** *
                                                          ** *    ** *    ** *                                                                                                                                                                                                                     ** *  ** *  ** *       *             *             *     *                                                                            *    *  *    *  *    *  *    *  *    *  *    *  *    *  *    *  *  * *  * ** *  * ** *  *                                                                                                                                                                                                                                    **             **                                                                                   **   *                   *   **                    **        * *     * *      * *     * *        **                                                                                                                               **   **                                                                                                                                                                                                                                                                                                                                                                                                                              ****                           **                                                                               * *       **                      **       * *                                                                                                                                                                   **                                                                                                                      **                                                                                                      **       *  *  *  *  * *         **                                *   *                                                                         **                        **                                                                                               * **     *     *   *     *            * * *                                                     * * *                                                                                       **   ***                                                                                                                  *   **    **  **    **                                                                         *     *                                                                                                                                                                                                                                    **  *     *     ** *      ** *          **
                                                                                                                                                                                                                                                                                                   * **  * **  * **      * *           * *           * *    **                                                                           *    *  *    *  *    *  *    *  *    *  *    *  *    *  *    *  *    *  *    *  *    *  * **                                                                                                                                                                                        *               *                        **             **                                                                             ***** * **                       ** * *****                         *       *        *       *                                                                                                                                         *  * *  *                                                                                                                                                                                                                                                                                                                                                                                                                            *   *                                                                                                          **  *       **     **        **     **       *  **                                                                                                                                                ***             **                                                                                                                                                                                                                               **       *      **    *          **            *          * *        * *                                                                                                                                                                             **                   **        **    **  **    **           *** *                                      ***             *  *                                                                                   **   *      **   **           **                                                                                               **  *     *   *     *                                                                                                                                                                                                                                                                                                                      *   *     *    * **      * **           *                                              *  *
                                                          ***     ***     ***                              * *                                                                                                                                                                                                            *             *             *                                                                                  *    *  *    *  *    *  *    *  *    *  *    *  *    *  *    *  *  * *  * ** *  * ** *  *                                                                                                                                                                                           **             **                         *             *                                                                              *  *  * *                         * *  *  *                                                                                                                                                                                        **   **   **   **                                                                                                                                                                                                                                                                                                                                                                                                                            *              * *                                                                                        *    **             *          *             **    *                                                                                                                                     **        ***                                   ***                                                                                                                                                                                                                  * *                                 * *         **                                                                                                                                                                                         * *                  *         *     *   *     *            ***                                                         **                                                                                    **   *  **  ***                                                                                                                     *     *   *     *           *   *                                                                                                                                                                                                                                                                                                    *   **    **  **    **        **        *                         ****                      *                   ****
                                                         *  *    *  *    *  *                            *  *  *                                                                                                                                                                                                                                                                                                                     **    **      **      **      **      **      **      **      **      *                                                                                                                                                                                                                 **             **                            **     **                                                                                      *  *          ** **          *  *                                                                                                                                                                                             *               *                                                                                                                                                                                                                                                                                                                                                                                                                        *  *                  *                                                                                       *****             * *          * *             *****                                                                                                                   **                **       *   *                                 ** *                                                                                                                                                                                                                   **                     *           *  *         *                                                                                                                                                                                           *                   *         *     *   *     *                                                    *     *                                                                                                        * **           *     *                                                                                                       **    **  **    **           *   *                                                                                                                                                                                                                                                                                                    **  *     *   *     *         *         **                       *   *                  *   *                  *   *                                                          **
                                                         *       *       *                             *  * * *  *                                                                       *   *                                                                                                                                                                                                                                      ****                                                                                               *                                                                                                                                                                                      *             *                                                            *               *                                                **            * *            **                                                                                                                                                                                           ** *               * **                                                                                                                                                                                                                                                                                                                                                                                                     ***                                   *                                                                                     **    *             **            **             *    **                                                                                                                 **                                               *               **                                                                                                                                                                                                                                           * *           *  *                                                                                                                                                                                                    **                 **        **    **  **    **                 ***          *                     *     *                                                                                                                       *     *                                              **                                                   **    ** *      ** *                                                                                                                                                                                                                                                                                                                           *     *   *     *         *                                     *                   ****                      *                                                           **
                                                           *       *       *                         *  * * * * *  *                                                                     *   *                                                                                                                                                                                                                                     *  * *                                                                                          **** *                                                                                                                                                                                        **     **                              *           *                    **             **                                                            * * * *                                                                                                                                                                                                      * * **             ** * *                                                                                                                                                                                                                                                                                                                                                                                                    *  *                               *  *                                                                                    *  **                       **                       **  *                                                                                                    ***                                   **   **                 **              **                                                                                                                                                                                                                                * *      *  *                                                                                                                                                                                                                                        ** *      ** *      ** *       ** **                    *                     *     *                                                                                                                                                                  **      ** **              **                                  **    * **      * **                                                                                                                                                                                                                                                                                                                          **    **  **    **        **                                 *  *                                          *  *                                                           *                        **
                                                       **      **      **                             * *  *  * * *  *                                                                   *   *                                                                                                    **                     **                                                                                                       * *  **                                                                                          *** * *                                                                                                                                                                                                                              *           *                    **             **                                                            **   **                                                                                                                                                                                                      * *     ***   ***     * *                                                                                                                                                                                                                                                                                                                                                                                                    *                                   ***                                                                                    ** *       *     *        *    *        *     *       * **                                                                                                    ***                 **                                       **                * *                                                                                                                                                                                                                               **     *  *            *  *                                                                                                       *                                                                                                                 * **      * **      * **       *         *     *        *                                                                                                                                                                                              **      *  *               **                                                                                                                                                                                                                                                                                                       **                                                                   **    ** *      ** *      ** *          **      ***   ***                                                                                                                                              * *
                      **  **                  **           **      **      **                       *** *     **  * *                                                                   **   **                                                                                              **  * *                     * *  **                                                                                                 * *                                                                                                    * *                                                                                                                                                                                    *           *                             **       **                      *             *                                                                                                                                                                                                                                                                        **  *     * *   * *     *  **                                                                                                                                                                                                                                                                                                                                                                                                  *                  *  *                                                                                                       *      ***   ***      *      *      ***   ***      *                                                                                                      *   *                 *                                                         *  **                                                                                                                                                                                                                             *                      **                                                                                                         *     *                                                                                                                                           **  *    *     *                                ***                                                                                                                                                                            *  *                                                                                                                                               **         **                                                                                                                                                            * *                                                                  **    * **      * **      * **          **     *  *   *  *                                                                                                                                               *
                      * *  *                  *  **   *  *    *  *    *  *    *                        *          * ***                                                                * *   * *                                             *                                               *   *    * *  *  *  *  * *    *   *                                                                                                **                                                                                                       *                                                                                                                                                                                     *           *                 ***                             ***             **     **                                                                                                                                                                                                        *       *                    *       *                            *    **    ***   ***    **    *                                                                                                                                                                                                                                                                                                                                                                                                  * *              *                                                                                                           **    * * * * * *    *        *    * * * * * *    **                                                                                                                         ***                                                                                                                                                                                                                                                                                                   *  *                                                                                                                       *     ***                                                                                                                                          ***     *     *    ***   ***                                                                                                                                                                                                   **                                                                                                                                                 *         *                                                                                                                                                               *                                                                                                                 ** *   * **                                                                     *                                                                         **
                          *                    * *  * *  *    *  *    *  *    *                    ****            *                                                                *****     *****                                          *                                                *** ***** ************* ***** ***                                                                                                 ***                                                                                                     **                                                                                                                                                                                      **       **                   ***          **   **          ***                                                                                                                                                                                                                              * *     * *                  * *     * *                           *****                     *****                                                                                                                                                                                                                                                                                                                                                                                                                   *   *                                                                                                            *** ** ** ***   *        *   *** ** ** ***                                                                                                          **   **             *                  **                           *                                                                                                                                                                                                                                         *             **                             *          *                                                                      **      **       *                                                                                                                                         ***                            ***          *                                                                                                                           **                                                                                                                                                                                                     ***           ***                                                                                                       **                                                   **                                                                                                                                                                         *     *     **        **               **
                   **  *     **               ** *         **      **      **   **                                  ****                                                                                                                     *   *                                              *                         *                                             *               *                                        * *                                                                                                    **                                                                                                                                                                          ***                             ***            **     *       *     **                 *           *                                                                                                                                                                                                      *       *                    *       *                                *                     *                                                                                                                                                                                                                                                                                                                                                                                          **                           ****                                                                                * **      ** *                * * * * * *    *        *    * * * * * *                                                                                                                                                  * *                           **                                                                         **                                                                                                                                                            **                                          **         **                                                                     * *         *    **                                                                                                                                        **  *      ***          *                    *                                                                                                          **              ** **                   ***                             **                                                                                                                                              *               *                                                                                                       **                                                                                                                                                                                          **                   * **           *     *     **       **                **
                   * *   * *  *                   **   **      **      **         * **            ***                                                                                                                                       **   *                                            **  ************************  ***                               *   *    * *    *   *    * *    *   *                               **                                                                                                    **                                                                                                                                                                           ***          **   **          ***               *                 *                   *           *                                                                                                                                                                                                                                                                      ****                           ****                                                                                                                                                                                                                                                                                                                                                                                    **                                                                                                               ** *      * **                 ***   ***      *      *      ***   ***                                                                                                                                                   *                            **                                                                          ** *               *                                                                                                                              * *        * *                                     *    * *       **    **  **                                                            * * **  *    *                                                                                                                                            *                        *     *     *        *                                                                                                          **               *  *                    *                             *  *                                                                                                                                                                                                                                                                                                                                                                                                                                                                **              **   *  **  ***                            **  **
                       *     *                       *    *  *    *  *    *  * *  * *                *                ***                                                                                                                  * *   *                                           * *     *    *    *    *    *     * **                           *****    * *    *****    * *    *****                                                                                                                                                                                                                                                                         **                                            **     *       *     **                *   *  *           *  *   *                **       **                                                                                                                                                                                                                                                                       *  *          **   **          *  *                                                                                                                                                                                                                                                                                                                                                                                                                                        ***                                                        **        **    **                *     *        *    *        *     *                                                                                                                          ***      ***                                                                                                                           *             * *                                                                                                                             *   *                                            * *             ***    **  **                                                             * * *       *                                                                                                                                            ** **                    *     *     *                             ** **                                                                                                  *  *                  ***                             *  *               **                                                               **         **                                                                                                                                                                                                                                                                                                                                                                     *             **   *      **   **           **
                **  *     *     **                   *    *  *    *  *    *  *   **  *           ****                *                                                              *****     *****                                     *****    **                                          * **     *    *    *    *   **    * **                           *   *   ** **   *   *   ** **   *   *                                                                                                                                                                                                                                                                        * *                                              *                 *                  *     *      *      *     *    ***                             ***                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    ** * **        ***        **                                  *        *     *                                  **                                                                                                                                          *   *       *                                                       *****                                                       *    *           *                                                                                                                          **            *          **                               * *               **    **                                                                   *     ***                                                                                                                                                                             *     *    ***   ***       *            *                                                                                                   **                                                   ** **              **                                                               **         **                                                                                                                                                                                                                                                                                                                                                                                        **   ***
                * *   * *   * *  *                     **      **      **           **                                ****                            *   *                    *   * *           * *   *                                         * *                                      ** *    **   *    *    *    *     ** *                          **  ** **   *   *   ** **   *   *   ** **  **                                                                                                                                                                                                                    **                                              *                                            *   *  *           *  *   *                    *    ** *     *           ***          **   **          ***                                                                                                                                                                                                           ********                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                  **     *     *   *        **                                 *          *     *               *       *                    *       *                                                                                                                       *     *     *               *                                 *     * *** *                                                     * *    * **     ***    *       **                                                                                                            **        *    *       *  *                              *  *                **                                                                      *  *                          *                                                                                                                                                                                    *       *  **                                                                                                                                                           **                                                                                                                                                                                                                                                                                                       **                                                                                                                                                                              *   *         *     *                                                    *
                    *     *     *             **           **      **      **                   ***                                                   *   *                    *   **             **   *                                          *****                                   ** *     *    *    *    *    *     * *                         * *   * *    *****    * *    *****    * *   * *                                                                                                                                                                                                                   **                                            ** ****                                        *     *             *     *                             *                     **     *       *     **                                                                                                                                                                                                                * **** *                                        *    ***                     ***    *                                                                   **    **                                                                                                                                                                                                                                                                                                                                                          ** * **     *    *                                           **        **    **              * *     * *          *       * *     * *                                                                                                                      ** * **                                                        **    *   *                                                               **    *       **      * *                                                                                                                         *       *                                   * *                 *                                                                         *                          *                                                                                                                                                           ***          *           *        ***                                                                                                     **                                                                                                                                                                                                                                                                                                                                                              * *                                                                                                                                                                                           *     *               **  **                               **
             **  *     *     *     **         *  **   *  *    *  *    *  *    *                    *                    ***                           *   *                    *   *               *   *                                                                                      ***  ************************  **                          *     * *    *   *    * *    *   *    * *     *                                                                                                                                                                                                              *          *                                      *   *  *                                              *             *                                    *                      *                 *                                                                                 *     **   **                                                                                              **                    ********                    **                 * *   * *   *             *   * *   * *                                                                  * *  * *                           **                                                                                                                                                                                                                                                                                                                               ***       *   *                                              * **      ** *                 *       *          *  *      *       *                                                                                                                                                                                     **      ***                                                         *            **   *****   ** * *                                                                                                                     *   *       *                       * *     **   * *                                                                                      *   *                          *                                                                                                                                               *                        *                    ***                                                                                                    *  *                                                                                                                                                                                                                                                                                                                                                               *                                                                                                                                                                             *   *                     **       **                **                 * *
             * *   * *   * *   * *  *          * *  * *  *    *  *    *  *    *                ****                    *                             **   **                  **   *               *   **                               *****                                                     *                         *                           **      *               *               *      **                                   * **                                                                                                                                                                     * *        * *                                     * * *                                                                                                   *              *    *   *  *           *  *   *                                                                           ***     * * * *                                                                                              *      ***   ***                    ***   ***      *                 * *   ***   *             *   ***   * *                                                                    *  *      **    **        **   *  *                                                                                                                                                                                                                                                                                                                                                                                            ** *      * **                    *       *       *  *         *       *                                                                                                                                                                                           *                            ** *      ** *               **                 ** **   * * *                                                                                                                      * *         *                       **     * *     *                                                                                      *   *     *                   **                                                                                                                                               *                        *       ***   ***   *  **                                                                                  **               *  *      **                                                                                                                                                              *                                                                                                                          **                                                            **                                                                                                                                                                          **   ***                    **        **               **
                 *     *     *     *          ** *         **      **      **   **                                     *****                        * *   * *                * *   *               *   * *                         *   * *                *                                   *** ***** ************* ***** ***                                                                                                             ** *         *           *           *           *                                                                 **  **                                               * *   *  *   * *                                  ** ***                                                                                           *        *    *         ** * *     *             *     *                                                                          *          * *            *  **                                                                            ** *      * *   * *                    * *   * *      * **               *                                   *                                                                    **  **      *    * *        *   **                                                                                                                                                                                                                                                                                                                                           *   *                                                  **  **    **                 * *     * *        *         * *     * *                                                                                                                         *                                                                                             * **      * **               *****                 *      *                                                                                                                                     *  *     **             *     *                                                                                                  *    **                 *                                                                                                                                                  *                                                 *                                                                                 **              ** **      **                                                                                                                                                            * *                                                                                                                           *                                                                                                                                                                                                                                   **   *      **             **               *
              *     *     *     *                 **   **      **      **         * **        *****                                              *****     *****          *****                         *****                      *   **       *****    * *                                 *   *    * *  *  *  *  * *    *   *                                                                                                                        * *         * *         * *         * *                                                                 *   *       ** **                                  * *    *  *    * *                                *  *                                                                                        *     *             *     * * **         *             *                                                                       **       **        ** **          * *  *                                                                            *  **     ***   ***                    ***   ***     **  *                                                                                                              *        ***  ***     * ** *  *       * **  **** **                                                                                            **                                                                                                                                                                                                                                      *    *                                                  *  *     *                   *       *                    *       *                                                                                                            **           **                      ***                                   *     **                       **    **  **            **     ** **                      *  *                                                                                                                                      **     * *                 **                                                                                               *  *     *       ***      *    *                                                                                                                                                                                   *        ** **                                                                                                  **                                              *     *                                                                                                                  **                                                                                                                        ***                                                                                                                                                                                                                                    **   *  **  ***            **
             *  * *   * *   * *   * *                *    *  *    *  *    *  * *  * *             *                    ****                                                                                                        *   *           * *   **                                  **  * *                     * *  **                                                                                                       **   ***   **    * *         * *         * *         * *    **                                                          *   *         * * *                                  *     *  *     *                                 * **           **                                        *             *                    *   *  *           *  *   *    *                                                                                                *                                * * *                                                                              **    *             **            **             *    **                *                                   *           ** *      * **                                * *         *  *      ** * * **      ** * * *   * * *                                                                                         *    *                                                                                                                                                                                                                       **            *   *        **                                       *    *     *                                    **                                                                                                                              **                                  *   *                                   **   *                        *     *   *            * *      *                            *                                                                                                                                               *      * *                                                                                                           *              * *      *         **                                                                                                                                    ***   ***                                *                                                                                                                                                               *     *           ** *                                                                                                                                                                                                                             *                                                                                                                                                                                                                                            * **
             **     *     *     *  **                *    *  *    *  *    *  *   **  *         ***                    *                                                                                                           **   *            **   **                                       **                     **                                                                                                             *    *    *    ** **       ** **       ** **       ** **    *                                                          **  **        *    *                                                                                **   *           *                                   *     *             *     *                  *                 *                                                                                                         * *                             ** * **                                                                               *****             * *          * *             *****                 * *   ***   *             *   ***   * *          * **      ** *                                * ***                *   * *          *   *  ** * * *                                                                                        *      *                                                                                                                                                                                                                      **              ***        **                                       **  **    **                   *     *        *    *        *     *                                                                                                                         * **                   *     *                                 **     ***                      *     *   *           * * **                            *   *                                                                                                                                               **      **                                                                                                         * * *            ***        ***     * *                                                                                                                                                                            *   * *                                                                                                                                                                      ***  **  *   **                                                                                                                                                                                                                                                                                                                                                                                                                                                           *
                 *     *     *                         **      **      **           **                                 ***                                                                                                       * *   *             *  **                                                                                                                                                                            *    *   *    *    *    * *    *    * *    *    * *    *    *    *                                                                  ** *     *                                                                              *  ***          * *                                   *   *  *           *  *   *                **     *       *     **                                                                                                        **                           *   **   *                                                                              *    **             *          *             **    *                 * *   * *   *             *   * *   * *              **  **                                 * **    *                ** * *        *   ****      * **                                                           **    **    * **           *        *                                                                                                                                                                     *     *                                                                                                         * **      ** *                    ***   ***      *      *      ***   ***                                                                                                                       *  **                   *     *                                          *                     **    **  **            * * *            ***        * *  *   *                                                                                                                                                       *                                                  **             ***                                     * * **                            ** * *                                                                                                                               **      *                      ***                  *                                                                                                                                **                  **           **   **      *   **                                                                                        **                                                **                                                                                                                                                                                                                                                                                                              **                                                          **
                *  * *   * *   * *            **           **      **      **                   ****                                             *****     *****          *****                         *****                 *****                  *  *   *                                                                                                                                                                         **   *****   *****   **** ****   **** ****   **** ****   *****   ***                                                     **  **     ** *      *                                ***        ***                               ** *      ***   **                                        *                 *               ***          **   **          ***           *             *                                                            *       *        ***        ***   ***        **  ** *                                                                              **  *       **     **        **     **       *  **                   *    ***                     ***    *               *    *                         **      **   ** *               *    *   * ** * ** *  * ***  *                                                               *     *    ** *           *        *                                                                                                                                                                    ***   ***                                                                                                        ** *      * **                   * * * * * *    *        *    * * * * * *                                                                                                                      ****                       *                                                                     ** *      ** *          *              * *        *  *     *                                                                                                                                                                                                        *    *          ***                                      * *     ***                       * * *                                                                                                                               *  *     *                                       *  *                                                                                                                                 **                                     ***   **                                                                                              *                                                *                                                                                                                                                                                                                                                                                                               * *                 *                                      *
                **     *     *  **            *  **   *  *    *  *    *  *    *                     *                ****                           * *   * *                * *   *               *   * *                                           *   ****                                                                                                                            *                                               **     **     * * *       * * *       * * *       * * *     **   *                                                     *   *        * *     *                           **                  **                              *     *   *        *                                 **     *       *     **            ***                             ***    *     *             *     *                                        **  *        * *     * *       * *        * *   * *    *   * *  * *                                                                                * *       **                      **       * *                                                                          *  *                         * *         ** * **               * ** *  *    **    * *    * *                                                              *     *   **               *        *                                                                                                                                                                   ** ** ** **                                                                                                                                       *** ** ** ***   *        *   *** ** ** ***                                                                                                                                              *   *                                       *                           * **      * **         *  *   * *      ***        * *   *  *                                                                                                                                                                                                              *                                                   **         *                       *                                                                                                                                 * * *    *                    *     *           * * *                                                                                                                                                         *     *         *   *                                                                                                * *                     **                     * *                                                                                                                                                                                                                                                                                **     **                                         **                         **          *  **
                    *     *                    * *  * *  *    *  *    *  *    *                  ***                *                                **   **                  **   *               *   **             **                                                                                                                                                             *****                                            ***  *****  ***   ***   ***   ***   ***   ***   ***   ***   ***  *** * **                                                *   *         * **   **                           **                  **                           ***     *     *     ***                            ***          **   **          ***                   **       **                *   *  *           *  *   *                                        *  * *        *       *        ***        ***   ***        **  ***                                                                                 * * *  *                              *  * * *                                                                         **  **                  ** *  *      ***** *                    * ** ***          ** **** **                                                               **    **   *                *      *                                                                                                                                                                   ***       ***                                                                                                                                 **    * * * * * *    *        *    * * * * * *    **                                                                                                                                          ***                                         **                             **  **    **       *     *  *                         *                                                                                                                                                                                                         *     *                                                         *    *                *     *  *                                                                                                                                *  *                         *     *           *  *                                                                                                                                                          *     *                                                                                                               **        *            **            **       **                                                                                                                                                                                                                                                                                 **     **                                        *** *         **            **          *  *                  *
                   *  * *   * *               ** *         **      **      **   **                                   ***                              *   *                    *   *               *   *              **                                   **                                                                                                                       *  *        *                                 ** *    *     *    *   *   *   *   *   *   *   *   *   *   *   *    *    * *                                                 **  **         *                                      ***        ***                               *        *   *     *                              ***                             ***                 *           *                   *                 *                                             * * *                                                  *   **                                                                                      ** ****                              **** **                       *  *          **   **          *  *            ** *      * **             * ** * **    *     * ** ** *    **      *    **  ** **   *   *    *                                                                   * **    *                  *    *                                                                                                                                                                                                                                                                                                                  *      ***   ***      *      *      ***   ***      *                                                                                                               **   **                     *                                         **                              *   *     *        *   *  * *                       * * *                                                                                                                                            ****** **                                                   ******                                                             *                 **    *                                                                                                                                       *                        *     *            **                                                                                                                                                                           *   *                                                                      ** *   * **                         **                          * *                                                                                                                                                                                                                                                                                                                      **                 **             **                        * *           **    *  *
                   **     *  **                   **   **      **      **         * **            ****                                                *   *                    *   **             **   *                      *****                        **                                *                                                         *                            *  * **     * *                                * *     *   *     *   *   *   *   *   *   *   *   *   *   *   *     *  ** *                                                                 *******                                                                                 **   ***      * **                                       **       **                             *           *                 **     *       *     **                                          ** * **                                                   ** * *****                                                                                  *                                      *                         ****                           ****            * **      ** *             *    *        ****     **      *  *      ** ****     *    ** * ** *                                                                   ** *    **                   **                                                                                                                                                                        *       *                                                                                                                                ** *       *     *        *    *        *     *       * **                                                                                                               *                                                                                                   *   *     *       *   *                            ** * *                                                                                                                                           ****** **                                                                  ***                                              **                   *     *   *                                                                                                                                * *                    **                                                                                                                                                                                                  ***   **                                                                    *  *   *  *                        **                             *                                                                                                                                                                                                                                                                                                                        *                 **                                       **            **   *****          **
                       *                             *    *  *    *  *    *  * *  * *                 *            ****                               *   *                    *   * *           * *   *              ****   * *                                                             ***                                           **        ***                            ***        * *                                 * *    **   **    * *   * *   * *   * *   * *   * *   * *   * *    **     * **                                              **  **                *                                                                                * *          ***  *                                      *           *                                                     ***          **   **          ***                                    *   **   *                                                  * *  *  *                                                                                  * *                                  * *                               *                     *                      **        **         ** **** * **    * *   *  * *   *  **      *   *   *****      *  * **                                                                        **    * **       **                **                                                                                                                                                                                                                                                                                                       *  **                       **                       **  *                                                                                                            *     *                                                                                               **  **    **       *                            *      * *                                                                                                                                                  **                                                                   ***                                             *                          *   *                                                                                                                                       *  *           *  *    ***                                                                                                                                                                          **             **      *   **                                                                ***   ***                          **  **                      ***                                                                                                                            ****                                                                                                                                                                         **          **  *                 *                                                    *     *** **         **
                      *  * *                         *    *  *    *  *    *  *   **  *             *** *          *                                                                 *****     *****                   *   *  **                                                                 * **     ** **     ** **     ** **     ** * *    ** *                               *    **      *                              ** *    **       **    *   *   *   *   *   *   *   *   *   *   *    **       * *                                                *   *            **                                 *     *  *     *                                  *           *   **                                       *           *                              **     **             ***                             ***                                  * **  **        ***   ***        ***        *       *        *  *                                                                                        **                                  **                            *****                     *****                  *          *        * *    * *    ** ** * **  * *   *           ** * **         * *                                                                               *    ** *        *       **       *                                                                                                                                                                                                                                                                                                         **    *             **            **             *    **                                                                                                              ** **                     **                                                                     ** *      ** *         *  *                      ** **     **                                                                                                                                            **     **                                                                                                                   *                          *                                                                                                                                         *  **  *         * * *                                                                                                                                                                  *             **            ***  **  *   **                                                                                                                                                                                                                                                          ** *    *                                                                                                                                                                        **           *  *                                                         **                  ** *
                      **  **                           **      **      **           **               * *  **     * ***                                                                                                   **  *                                                             **** * *       * *       * *       * *       * *       * * ****                         ** * *   * *                                 ** **                  *   *   *   *   *   *   *   *   *   *   *            **  *                                              *   *             **                                * *    *  *    * *                                **           ** *                                                                                 *             *                      **       **                                              * *  * *   *    * *   * *        * *       * *     * *        **                                                                                                                                                           *    **    ***   ***    **    *                   *        *         *   ***  * *** * ** ***   **                 * **   **      **                                                                               *         **      * *   *    *   * *                                                                                                                                                                                                                                                                                                           *****             * *          * *             *****                                                                                                                 * *                      **                                               **                    * **      * **          *      *                 *****                                                                                                                                                   **     **                                                                                                                   *                          *  *                                                                                                                                      *  **  *          * ***                                                                                                                                                               * *                                ** *                                                                                                                                                                                                                                                               *   *    *                                                                                                                                                                                      * *                 *                                      * *                   **
                                                           **      **      **                       *  * * *  *  * *                                                                                                    **   *                                                            *     * *       * *       * *       * * *     * **      * *     *                           * *   *  *   * *                                                  ***   ***   ***   ***   ***   ***   ***                **                                              **  **                                               * *   *  *   * *                                              *  *                                           **     **                            **             **                    *           *                                              ***  **        ***   ***        ***        *       *                                                                                                                                                                       **  *     * *   * *     *  **                   **        **     ** * *  * *             ** ** ** *              *    ** *                                                                                       **         *       **  *      *  **                                                                                                                                                                                                                                                                                                            *    **             *          *             **    *                                                                                                                  *                                                                        * *                                         * * *   ** **                 **                                                                                                                                                   **     **      *                                                                                                                                ***     *                                                                                                                                          ****              ***                                                                                                                                                                **                                                                                                                                                                                                                                                                                                   *    **                                                                                                                                                                                         **                 **                          **          *  *
                                                        *       *       *                             *  * * * * *  *                                                                                                   **   *                                                            ** *     *** ***   *** ***   *** ***  * *  ***    *  ***     * **                                  * *   * * **                                                    * * *       * * *       * * *                                                                                                                           * *        * *                                            *** **                                         *             *                         **             **                    *           *                                                  **   *                           **                                                                                                                                                                                      * *     ***   ***     * *                 ** *      * **        * * * **  * * * *      *              **        *** *                                                                                                    *           *        *                                                                                                                                                                                                                                                                                                                **  *       **     **        **     **       *  **                                                                                                                   *                                                                          *                                        * * **   *****   **            *                                                                                                                                                    **            * *                                                                                                                             *       * * *                                                                                                                                      * *  * *                                                                                                                                                                                                                                                                                                                              **  **                      ***                                                                                                                       *  *    **                                                                                                                                                                                                        **             **            **          *  **                 **
                                                          *       *       *                             *  * * *  *                                                                 *****     *****                    * *                                                                    **   *     *   *     *   *     *  *  *   *   ***   *   **                                   *      **    *                                                  ****   **** ****   **** ****   ****                                                                                                                         *          *                                            * * *                                          **             **                        *               *                                                                             ***** * **                             * *                                                                                                                                                                                     * * **             ** * *                 * **      ** *        * * *   * * * **      ** * * **     *    *        * *                                                                                                    **          *        *                                                                                                                                                                                                                                                                                                                  * *       **                      **       * *                                                                                                                                                                                                **                                       * *      **       *    **                                                                                                                                                           ** ******    *   *                                                                                                                            *    *  ** * *                                                                                                                                     **    **                  *  *                                                                                                                                                                                                                                                                                                       **                             *                                                                                                                       *  *   *  *                                                                                                                                                                                     **                 *** *         **                         *                   ** *
                                                       *  *    *  *    *  *                               *  *  *                                                                      * *   * *                        *                                                                           ** **     ** **     ** **     ** **    * * **                                         * *        ***                                                  *    *    * *    *    * *    *    *                                                                                                                              **                                              *  *   *                                          **             **                                                               **     **                                              *  *  * *                                *                                                                                                                                                                                      ** *               * **                                         ** ****  ** *       *  * ** *      *    *         *                                                                                           **    * **            *        *                                                                                                                                                                                                                                                                                                                  * * *  *                              *  * * *                                                                                                                                                                                                                                          **       *    ***     ** *    * *                                                                                                                                                  ** ******     *   *                                                                                                                      **    *         * *                                                                                                                                                             *  **  *                                                                                                                                                                                                                                                                                                      **                          * *                                                                                               **                       **    *  *                                                                                                                                                                                     * *                 **                                       **                *** **         **
                                                       ***     ***     ***                                  * *                                                                         **   **                                                                                                      * *       * *       * *       * *       * *                                         * *     ** *  *                                                     ** **       ** **       ** **                                                                                                                                 **                                              **** **                                           *               *                                                            *             *                                                *  *          ** **        **       **                                                                                                                                                                                        *               *                                                   **   *        * *    *      *    *                                                                                                     **    ** *         **  *      *  **                                                                                                                                                                                                                                                                                                                ** ****                              **** **                                                                                                                                                                                                                                                         *           *    *                                                                                                                                                                  *   *                                                                                                                     *       **      **                                                                                                                                                              *  **  *                                                                                                                                                             **       **                                                                                         **         **               **        *            **            **       **                                                                                        *                          **    *                                                                                                                                                                       **           *  *                  *                                                         *****          **
                                                                                                                                                                                         *   *                                                                                                     * * * *   * * * *   * * * *   * * * *    ** * *                                         *        *  *                                                      * *         * *         * *                                                                                                                                                                                      *                                                                                                                         **             **                                                **            * *          *                                                                                                                                                                                                 **   **   **   **                                                 *  *   **        **    **      *  *                                                                                                                        * *   *    *   * *                                                                                                                                                                                                                                                                                                                 *                                      *                                                                                                                                                                                                                                                    * *             *                                                                                                                                                                           *   *                                                                                                                     ***     *                                                                                                                                                                        ****                                                                                                                                                               * *      * *                                                                                         *         *               * *                     **                     * *                                                                                    ***                        *    *   *                                                                                                                                                                       **          **  *                                                                            *  *
                                                      * **    * **    * **                                                                                                               *   *                                                                                                     **   **   **   **   **   **   **   **        **                                                *****                                                       * *         * *         * *                                                                                                                                                                                    * *                                                                                                                         **             **                                                            * * * *     ***                                                                                                                                                                                                      *  * *  *                                                     **                           * *  * *                                                                                                                      *       **       *                                                                                                                                                               **     **                                                                                                                                         * *                                  * *                                                                                                                        **                                                                                                                           *               * **                                                                                                                                                                        * *                                                                                                                        *     *                                                                                                                                                                      * *  * *                                                                                                                                                               *        *                                                                                      ***           ***            *                                                *                                                                                    *                          *    * **                                                                                                                                                                                       *                                                                               *
                                                      ** *    ** *    ** *                                                                                                               *   *                                                                                                                                                                                                    *                                                            *           *           *                                                                                                                                                                                     **                                                                                                                          *               *                                                            **   **     *                                                                                                                                                                                                         **   **                                                                                   **    **                                                                                                                     **                **                                                                                                                                                              **     **                                                                                                                                          **                                  **                                                                                                                         **                                                                                                                                             **                                                                                                                                                                         *                                                                                                                               *                                                                                                                                                                      **    **                                                                                                                                                               **       **                                                                                     *               *           **                                                **                                                                                                               ****                                                                                                                                                                                         **
